@@ -1,7 +1,7 @@
 use criterion::{Criterion, black_box, criterion_group, criterion_main};
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::*;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::*;
 
 /// Generate test content with various markdown issues that need fixing
 fn generate_problematic_content(size: usize) -> String {
@@ -202,7 +202,7 @@ fn generate_problematic_content(size: usize) -> String {
 /// Benchmark fix performance for rules that support fixing
 fn bench_fix_performance(c: &mut Criterion) {
     let content = generate_problematic_content(100);
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // MD001 - Heading increment
     c.bench_function("MD001 fix", |b| {
@@ -224,13 +224,13 @@ fn bench_fix_performance(c: &mut Criterion) {
 
     // MD004 - Unordered list style
     c.bench_function("MD004 fix", |b| {
-        let rule = MD004UnorderedListStyle::new(rumdl::rules::UnorderedListStyle::Consistent);
+        let rule = MD004UnorderedListStyle::new(rumdl_lib::rules::UnorderedListStyle::Consistent);
         b.iter(|| rule.fix(black_box(&ctx)))
     });
 
     // MD005 - List indentation
     c.bench_function("MD005 fix", |b| {
-        let rule = MD005ListIndent;
+        let rule = MD005ListIndent::default();
         b.iter(|| rule.fix(black_box(&ctx)))
     });
 
@@ -387,7 +387,7 @@ fn bench_fix_performance(c: &mut Criterion) {
 
     // MD050 - Strong style (skip - requires enum parameter)
     // c.bench_function("MD050 fix", |b| {
-    //     let rule = MD050StrongStyle::new(rumdl::rules::StrongStyle::Consistent);
+    //     let rule = MD050StrongStyle::new(rumdl_lib::rules::StrongStyle::Consistent);
     //     b.iter(|| rule.fix(black_box(&ctx)))
     // });
 
@@ -401,7 +401,7 @@ fn bench_fix_performance(c: &mut Criterion) {
 /// Benchmark fix performance with large content
 fn bench_fix_performance_large(c: &mut Criterion) {
     let content = generate_problematic_content(1000); // 10x larger
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Test the most commonly used fix rules with large content
     c.bench_function("MD009 fix large", |b| {
