@@ -52,7 +52,7 @@ impl FileParallelProcessor {
             return Ok(files
                 .iter()
                 .map(|(path, content)| {
-                    let result = crate::lint(content, rules, false);
+                    let result = crate::lint(content, rules, false, crate::config::MarkdownFlavor::Standard);
                     (path.clone(), result)
                 })
                 .collect());
@@ -70,7 +70,7 @@ impl FileParallelProcessor {
             .par_iter()
             .map(|(path, content)| {
                 let start = Instant::now();
-                let result = crate::lint(content, rules, false);
+                let result = crate::lint(content, rules, false, crate::config::MarkdownFlavor::Standard);
                 let duration = start.elapsed();
 
                 if duration.as_millis() > 1000 {
