@@ -16,21 +16,28 @@ use crate::utils::regex_cache::UNORDERED_LIST_MARKER_REGEX;
 pub struct MD006StartBullets;
 
 impl MD006StartBullets {
-    /// Check if a bullet is nested under an ordered list item
+    /// Check if a bullet is nested under an ordered list item (anywhere in the hierarchy)
     fn is_nested_under_ordered_item(
         &self,
         ctx: &crate::lint_context::LintContext,
         current_line: usize,
         current_indent: usize,
     ) -> bool {
-        // Look backward from current line to find parent item
+        // Look backward from current line to find any ordered ancestor
+        let mut check_indent = current_indent;
+
         for line_idx in (1..current_line).rev() {
             if let Some(line_info) = ctx.line_info(line_idx) {
                 if let Some(list_item) = &line_info.list_item {
-                    // Found a list item - check if it's at a lower indentation (parent level)
-                    if list_item.marker_column < current_indent {
-                        // This is a parent item - check if it's ordered
-                        return list_item.is_ordered;
+                    // Found a list item - check if it's at a lower indentation (ancestor level)
+                    if list_item.marker_column < check_indent {
+                        // This is an ancestor item
+                        if list_item.is_ordered {
+                            // Found an ordered ancestor
+                            return true;
+                        }
+                        // Continue looking for higher-level ancestors
+                        check_indent = list_item.marker_column;
                     }
                 }
                 // If we encounter non-blank, non-list content at column 0, stop looking
@@ -52,90 +59,114 @@ impl MD006StartBullets {
         // Track which lines contain valid bullet items
         let mut valid_bullet_lines = vec![false; lines.len()];
 
-        // Process each unordered list block
+        // Process each list block
         for list_block in &ctx.list_blocks {
-            // Skip ordered lists
-            if list_block.is_ordered {
-                continue;
-            }
-
             // Check each list item in this block
+            // We need to check unordered items even in mixed lists
             for &item_line in &list_block.item_lines {
-                if let Some(line_info) = ctx.line_info(item_line) {
-                    if let Some(list_item) = &line_info.list_item {
-                        let line_idx = item_line - 1;
-                        let indent = list_item.marker_column;
-                        let line = &lines[line_idx];
+                if let Some(line_info) = ctx.line_info(item_line)
+                    && let Some(list_item) = &line_info.list_item
+                {
+                    // Skip ordered list items - we only care about unordered ones
+                    if list_item.is_ordered {
+                        continue;
+                    }
 
-                        let mut is_valid = false;
+                    // Skip list items inside blockquotes - they're supposed to be indented
+                    if line_info.blockquote.is_some() {
+                        continue;
+                    }
 
-                        if indent == 0 {
-                            // Top-level items are always valid
-                            is_valid = true;
-                        } else {
-                            // Check if this is nested under an ordered item with correct indentation (3 spaces)
-                            if indent == 3 && self.is_nested_under_ordered_item(ctx, item_line, indent) {
+                    let line_idx = item_line - 1;
+                    let indent = list_item.marker_column;
+                    let line = &lines[line_idx];
+
+                    let mut is_valid = false;
+
+                    if indent == 0 {
+                        // Top-level items are always valid
+                        is_valid = true;
+                    } else {
+                        // Check if this is nested under an ordered item with correct indentation
+                        // For single-digit ordered lists (1.), need at least 3 spaces for proper nesting
+                        // For double-digit (10.), need at least 4 spaces, etc.
+                        // But MD006's purpose is to flag top-level indented lists, not validate nesting depth
+                        if self.is_nested_under_ordered_item(ctx, item_line, indent) {
+                            // It's nested under an ordered item
+                            // Only flag if indentation is less than 3 (won't nest properly in CommonMark)
+                            if indent >= 3 {
                                 is_valid = true;
-                            } else {
-                                // Check if this is a valid nested item under another bullet
-                                match Self::find_relevant_previous_bullet(&lines, line_idx) {
-                                    Some((prev_idx, prev_indent)) => {
-                                        match prev_indent.cmp(&indent) {
-                                            std::cmp::Ordering::Less | std::cmp::Ordering::Equal => {
-                                                // Valid nesting or sibling if previous item was valid
-                                                is_valid = valid_bullet_lines[prev_idx];
-                                            }
-                                            std::cmp::Ordering::Greater => {
-                                                // remains invalid
-                                            }
+                            }
+                        } else {
+                            // Check if this is a valid nested item under another bullet
+                            match Self::find_relevant_previous_bullet(&lines, line_idx) {
+                                Some((prev_idx, prev_indent)) => {
+                                    match prev_indent.cmp(&indent) {
+                                        std::cmp::Ordering::Less | std::cmp::Ordering::Equal => {
+                                            // Valid nesting or sibling if previous item was valid
+                                            is_valid = valid_bullet_lines[prev_idx];
+                                        }
+                                        std::cmp::Ordering::Greater => {
+                                            // remains invalid
                                         }
                                     }
-                                    None => {
-                                        // Indented item with no previous bullet remains invalid
-                                    }
+                                }
+                                None => {
+                                    // Indented item with no previous bullet remains invalid
                                 }
                             }
                         }
+                    }
 
-                        valid_bullet_lines[line_idx] = is_valid;
+                    valid_bullet_lines[line_idx] = is_valid;
 
-                        if !is_valid {
-                            // Calculate the precise range for the indentation that needs to be removed
-                            let start_col = 1;
-                            let end_col = indent + 3; // Include marker and space after it
+                    if !is_valid {
+                        // Calculate the precise range for the indentation that needs to be removed
+                        let start_col = 1;
+                        let end_col = indent + 3; // Include marker and space after it
 
-                            // For the fix, we need to replace the highlighted part with just the bullet marker
-                            let trimmed = line.trim_start();
-                            let bullet_part = if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(trimmed) {
-                                let marker = captures.get(2).map_or("*", |m| m.as_str());
-                                format!("{marker} ")
-                            } else {
-                                "* ".to_string()
-                            };
+                        // For the fix, we need to replace the highlighted part with just the bullet marker
+                        let trimmed = line.trim_start();
+                        let bullet_part = if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(trimmed) {
+                            let marker = captures.get(2).map_or("*", |m| m.as_str());
+                            format!("{marker} ")
+                        } else {
+                            "* ".to_string()
+                        };
 
-                            // Calculate the byte range for the fix
-                            let fix_range = line_index.line_col_to_byte_range_with_length(
-                                item_line,
-                                start_col,
-                                end_col - start_col,
-                            );
+                        // Calculate the byte range for the fix
+                        let fix_range =
+                            line_index.line_col_to_byte_range_with_length(item_line, start_col, end_col - start_col);
 
-                            result.push(LintWarning {
-                                line: item_line,
-                                column: start_col,
-                                end_line: item_line,
-                                end_column: end_col,
-                                message: format!(
-                                    "Consider starting bulleted lists at the beginning of the line (found {indent} leading spaces)"
-                                ),
-                                severity: Severity::Warning,
-                                rule_name: Some(self.name()),
-                                fix: Some(Fix {
-                                    range: fix_range,
-                                    replacement: bullet_part,
-                                }),
-                            });
-                        }
+                        // Generate appropriate message based on context
+                        let message = if self.is_nested_under_ordered_item(ctx, item_line, indent) {
+                            // It's trying to nest under an ordered item but has insufficient indentation
+                            format!(
+                                "Nested list needs at least 3 spaces of indentation under ordered item (found {indent})"
+                            )
+                        } else if indent > 0 {
+                            // It's indented but not nested under anything - should start at column 0
+                            format!(
+                                "Consider starting bulleted lists at the beginning of the line (found {indent} leading spaces)"
+                            )
+                        } else {
+                            // Shouldn't happen, but just in case
+                            format!("List indentation issue (found {indent} leading spaces)")
+                        };
+
+                        result.push(LintWarning {
+                            line: item_line,
+                            column: start_col,
+                            end_line: item_line,
+                            end_column: end_col,
+                            message,
+                            severity: Severity::Warning,
+                            rule_name: Some(self.name()),
+                            fix: Some(Fix {
+                                range: fix_range,
+                                replacement: bullet_part,
+                            }),
+                        });
                     }
                 }
             }
@@ -145,10 +176,10 @@ impl MD006StartBullets {
     }
     /// Checks if a line is a bullet list item and returns its indentation level
     fn is_bullet_list_item(line: &str) -> Option<usize> {
-        if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(line) {
-            if let Some(indent) = captures.get(1) {
-                return Some(indent.as_str().len());
-            }
+        if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(line)
+            && let Some(indent) = captures.get(1)
+        {
+            return Some(indent.as_str().len());
         }
         None
     }
@@ -443,7 +474,7 @@ mod tests {
         // Test with properly formatted lists
         let content_valid = "* Item 1\n* Item 2\n  * Nested item\n  * Another nested item";
         let structure_valid = DocumentStructure::new(content_valid);
-        let ctx_valid = crate::lint_context::LintContext::new(content_valid);
+        let ctx_valid = crate::lint_context::LintContext::new(content_valid, crate::config::MarkdownFlavor::Standard);
         let result_valid = rule.check_with_structure(&ctx_valid, &structure_valid).unwrap();
         assert!(
             result_valid.is_empty(),
@@ -453,7 +484,8 @@ mod tests {
         // Test with improperly indented list - adjust expectations based on actual implementation
         let content_invalid = "  * Item 1\n  * Item 2\n    * Nested item";
         let structure = DocumentStructure::new(content_invalid);
-        let ctx_invalid = crate::lint_context::LintContext::new(content_invalid);
+        let ctx_invalid =
+            crate::lint_context::LintContext::new(content_invalid, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx_invalid, &structure).unwrap();
 
         // If no warnings are generated, the test should be updated to match implementation behavior
@@ -467,7 +499,7 @@ mod tests {
         // Test with mixed indentation - standard nesting is VALID
         let content = "* Item 1\n  * Item 2 (standard nesting is valid)";
         let structure = DocumentStructure::new(content);
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         // Assert that standard nesting does NOT generate warnings
         assert!(
@@ -486,7 +518,7 @@ mod tests {
 
 2. **Oracle Unified Directory (OUD)**
    - Extended user directory services";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should have no warnings - 3 spaces is valid for bullets under numbered items
         assert!(
@@ -501,14 +533,14 @@ mod tests {
         let content = "\
 1. **Active Directory/LDAP**
   - Wrong: only 2 spaces
-    - Also wrong: 4 spaces";
-        let ctx = crate::lint_context::LintContext::new(content);
+ - Wrong: only 1 space";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        // Should flag the incorrect indentations
+        // Should flag the incorrect indentations (less than 3 spaces)
         assert_eq!(
             result.len(),
             2,
-            "Expected warnings for bullets with incorrect spacing under numbered items"
+            "Expected warnings for bullets with insufficient spacing under numbered items"
         );
         assert!(result.iter().any(|w| w.line == 2));
         assert!(result.iter().any(|w| w.line == 3));
@@ -521,7 +553,7 @@ mod tests {
 * Top level
   * Nested bullet (2 spaces is correct)
     * Deeply nested (4 spaces)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should have no warnings - standard bullet nesting still works
         assert!(
