@@ -28,11 +28,6 @@ impl MD009TrailingSpaces {
         Self { config }
     }
 
-    fn is_empty_blockquote_line(line: &str) -> bool {
-        let trimmed = line.trim_start();
-        trimmed.starts_with('>') && trimmed.trim_end() == ">"
-    }
-
     fn count_trailing_spaces(line: &str) -> usize {
         line.chars().rev().take_while(|&c| c == ' ').count()
     }
@@ -111,10 +106,10 @@ impl Rule for MD009TrailingSpaces {
             // Handle code blocks if not in strict mode
             if !self.config.strict {
                 // Use pre-computed line info
-                if let Some(line_info) = ctx.line_info(line_num + 1) {
-                    if line_info.in_code_block {
-                        continue;
-                    }
+                if let Some(line_info) = ctx.line_info(line_num + 1)
+                    && line_info.in_code_block
+                {
+                    continue;
                 }
             }
 
@@ -126,34 +121,16 @@ impl Rule for MD009TrailingSpaces {
                 continue;
             }
 
-            // Special handling for empty blockquote lines
-            if Self::is_empty_blockquote_line(line) {
-                let trimmed = line.trim_end();
-                // Calculate precise character range for trailing spaces after blockquote marker
-                let (start_line, start_col, end_line, end_col) =
-                    calculate_trailing_range(line_num + 1, line, trimmed.len());
-
-                warnings.push(LintWarning {
-                    rule_name: Some(self.name()),
-                    line: start_line,
-                    column: start_col,
-                    end_line,
-                    end_column: end_col,
-                    message: "Empty blockquote line needs a space after >".to_string(),
-                    severity: Severity::Warning,
-                    fix: Some(Fix {
-                        range: _line_index.line_col_to_byte_range_with_length(
-                            line_num + 1,
-                            trimmed.len() + 1,
-                            line.len() - trimmed.len(),
-                        ),
-                        replacement: " ".to_string(),
-                    }),
-                });
-                continue;
-            }
-
+            // Check if this is an empty blockquote line ("> " or ">> " etc)
+            // These are allowed by MD028 to have a single trailing space
             let trimmed = line.trim_end();
+            let is_empty_blockquote_with_space = trimmed.chars().all(|c| c == '>' || c == ' ' || c == '\t')
+                && trimmed.contains('>')
+                && trailing_spaces == 1;
+
+            if is_empty_blockquote_with_space {
+                continue; // Allow single trailing space for empty blockquote lines
+            }
             // Calculate precise character range for all trailing spaces
             let (start_line, start_col, end_line, end_col) =
                 calculate_trailing_range(line_num + 1, line, trimmed.len());
@@ -222,36 +199,47 @@ impl Rule for MD009TrailingSpaces {
                 if self.config.list_item_empty_lines && Self::is_empty_list_item_line(line, prev_line) {
                     result.push_str(line);
                 } else {
-                    // Remove all trailing spaces
+                    // Remove all trailing spaces - line is empty so don't add anything
                 }
                 result.push('\n');
                 continue;
             }
 
             // Handle code blocks if not in strict mode
-            if let Some(line_info) = ctx.line_info(i + 1) {
-                if line_info.in_code_block {
-                    result.push_str(line);
-                    result.push('\n');
-                    continue;
-                }
-            }
-
-            // Special handling for empty blockquote lines
-            if Self::is_empty_blockquote_line(line) {
-                result.push_str(trimmed);
-                result.push(' '); // Add a space after the blockquote marker
+            if let Some(line_info) = ctx.line_info(i + 1)
+                && line_info.in_code_block
+            {
+                result.push_str(line);
                 result.push('\n');
                 continue;
             }
 
+            // No special handling for empty blockquote lines - treat them like regular lines
+
             // Handle lines with trailing spaces
             let is_truly_last_line = i == lines.len() - 1 && !content.ends_with('\n');
 
             result.push_str(trimmed);
 
+            // Check if this line is a heading - headings should never have trailing spaces
+            let is_heading = if let Some(line_info) = ctx.line_info(i + 1) {
+                line_info.heading.is_some()
+            } else {
+                // Fallback: check if line starts with #
+                trimmed.starts_with('#')
+            };
+
+            // Check if this is an empty blockquote line (just ">")
+            let is_empty_blockquote = if let Some(line_info) = ctx.line_info(i + 1) {
+                line_info.blockquote.as_ref().is_some_and(|bq| bq.content.is_empty())
+            } else {
+                false
+            };
+
             // In non-strict mode, preserve line breaks by normalizing to br_spaces
-            if !self.config.strict && !is_truly_last_line && trailing_spaces > 0 {
+            // BUT: Never preserve trailing spaces in headings or empty blockquotes as they serve no purpose
+            if !self.config.strict && !is_truly_last_line && trailing_spaces > 0 && !is_heading && !is_empty_blockquote
+            {
                 // Optimize for common case of 2 spaces
                 match self.config.br_spaces {
                     0 => {}
@@ -319,7 +307,7 @@ mod tests {
     fn test_no_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "This is a line\nAnother line\nNo trailing spaces";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -328,7 +316,7 @@ mod tests {
     fn test_basic_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with spaces   \nAnother line  \nClean line";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Default br_spaces=2, so line with 2 spaces is OK
         assert_eq!(result.len(), 1);
@@ -340,7 +328,7 @@ mod tests {
     fn test_fix_basic_trailing_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with spaces   \nAnother line  \nClean line";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "Line with spaces  \nAnother line  \nClean line");
     }
@@ -349,7 +337,7 @@ mod tests {
     fn test_strict_mode() {
         let rule = MD009TrailingSpaces::new(2, true);
         let content = "Line with spaces  \nCode block:  \n```  \nCode with spaces  \n```  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // In strict mode, all trailing spaces are flagged
         assert_eq!(result.len(), 5);
@@ -362,7 +350,7 @@ mod tests {
     fn test_non_strict_mode_with_code_blocks() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with spaces  \n```\nCode with spaces  \n```\nOutside code  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // In non-strict mode, code blocks are not checked
         // Line 1 has 2 spaces (= br_spaces), so it's OK
@@ -375,7 +363,7 @@ mod tests {
     fn test_br_spaces_preservation() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with two spaces  \nLine with three spaces   \nLine with one space ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // br_spaces=2, so lines with exactly 2 spaces are OK
         // Line 2 has 3 spaces (will be normalized to 2)
@@ -398,7 +386,7 @@ mod tests {
     fn test_empty_lines_with_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Normal line\n   \n  \nAnother line";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].message, "Empty line has trailing spaces");
@@ -412,14 +400,14 @@ mod tests {
     fn test_empty_blockquote_lines() {
         let rule = MD009TrailingSpaces::default();
         let content = "> Quote\n>   \n> More quote";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 2);
-        assert_eq!(result[0].message, "Empty blockquote line needs a space after >");
+        assert_eq!(result[0].message, "3 trailing spaces found");
 
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "> Quote\n> \n> More quote");
+        assert_eq!(fixed, "> Quote\n>\n> More quote"); // All trailing spaces removed
     }
 
     #[test]
@@ -428,7 +416,7 @@ mod tests {
 
         // Content without final newline
         let content = "First line  \nLast line  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Last line without newline should have trailing spaces removed
         assert_eq!(result.len(), 1);
@@ -439,7 +427,7 @@ mod tests {
 
         // Content with final newline
         let content_with_newline = "First line  \nLast line  \n";
-        let ctx = LintContext::new(content_with_newline);
+        let ctx = LintContext::new(content_with_newline, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Both lines should preserve br_spaces
         assert!(result.is_empty());
@@ -449,7 +437,7 @@ mod tests {
     fn test_single_trailing_space() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "Line with one space ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].message, "Trailing space found");
@@ -459,7 +447,7 @@ mod tests {
     fn test_tabs_not_spaces() {
         let rule = MD009TrailingSpaces::default();
         let content = "Line with tab\t\nLine with spaces  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Only spaces are checked, not tabs
         assert_eq!(result.len(), 1);
@@ -476,7 +464,7 @@ mod tests {
         content.push('\n');
         content.push_str("Normal paragraph\n> Blockquote\n>\n```\nCode block\n```\n- List item\n");
 
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should flag the line with trailing spaces
         assert_eq!(result.len(), 1);
@@ -488,7 +476,7 @@ mod tests {
     fn test_column_positions() {
         let rule = MD009TrailingSpaces::default();
         let content = "Text   ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].column, 5); // After "Text"
@@ -518,7 +506,7 @@ mod tests {
 
         let rule = MD009TrailingSpaces::from_config(&config);
         let content = "Line   ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
 
@@ -538,20 +526,20 @@ mod tests {
 
         // Test unordered list with empty line
         let content = "- First item\n  \n- Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should not flag the empty line with spaces after list item
         assert!(result.is_empty());
 
         // Test ordered list with empty line
         let content = "1. First item\n  \n2. Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test that non-list empty lines are still flagged
         let content = "Normal paragraph\n  \nAnother paragraph";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].line, 2);
@@ -563,7 +551,7 @@ mod tests {
         let rule = MD009TrailingSpaces::default();
 
         let content = "- First item\n  \n- Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Should flag the empty line with spaces
         assert_eq!(result.len(), 1);
@@ -577,7 +565,7 @@ mod tests {
         for i in 0..1000 {
             content.push_str(&format!("Line {i} with spaces  \n"));
         }
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Default br_spaces=2, so all lines with 2 spaces are OK
         assert_eq!(result.len(), 0);
@@ -587,7 +575,7 @@ mod tests {
     fn test_preserve_content_after_fix() {
         let rule = MD009TrailingSpaces::new(2, false);
         let content = "**Bold** text  \n*Italic* text  \n[Link](url)  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "**Bold** text  \n*Italic* text  \n[Link](url)");
     }
@@ -596,7 +584,7 @@ mod tests {
     fn test_nested_blockquotes() {
         let rule = MD009TrailingSpaces::default();
         let content = "> > Nested  \n> >   \n> Normal  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Line 2 has empty blockquote, line 3 is last line without newline
         assert_eq!(result.len(), 2);
@@ -613,7 +601,7 @@ mod tests {
         let rule = MD009TrailingSpaces::default();
         // Note: This test simulates Windows line endings behavior
         let content = "Line with spaces  \r\nAnother line  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Line 1 has 2 spaces (= br_spaces) so it's OK
         // Line 2 is last line without newline, so it's flagged
