@@ -27,10 +27,7 @@ impl MD013LineLength {
                 tables,
                 headings,
                 strict,
-                heading_line_length: None,
-                code_block_line_length: None,
-                stern: false,
-                enable_reflow: false,
+                reflow: false,
             },
         }
     }
@@ -64,7 +61,7 @@ impl MD013LineLength {
         current_line: usize,
         structure: &DocumentStructure,
     ) -> bool {
-        if self.config.strict || self.config.stern {
+        if self.config.strict {
             return false;
         }
 
@@ -185,14 +182,8 @@ impl Rule for MD013LineLength {
                 if let Some(strict) = obj.get("strict").and_then(|v| v.as_bool()) {
                     config.strict = strict;
                 }
-                if let Some(stern) = obj.get("stern").and_then(|v| v.as_bool()) {
-                    config.stern = stern;
-                }
-                if let Some(heading_line_length) = obj.get("heading_line_length").and_then(|v| v.as_u64()) {
-                    config.heading_line_length = Some(heading_line_length as usize);
-                }
-                if let Some(code_block_line_length) = obj.get("code_block_line_length").and_then(|v| v.as_u64()) {
-                    config.code_block_line_length = Some(code_block_line_length as usize);
+                if let Some(reflow) = obj.get("reflow").and_then(|v| v.as_bool()) {
+                    config.reflow = reflow;
                 }
                 config
             } else {
@@ -209,18 +200,14 @@ impl Rule for MD013LineLength {
             content.lines().collect()
         };
 
-        // Pre-compute LineIndex for efficient byte range calculations
-        let line_index = crate::utils::range_utils::LineIndex::new(content.to_string());
-
         // Create a quick lookup set for heading lines
         let heading_lines_set: std::collections::HashSet<usize> = structure.heading_lines.iter().cloned().collect();
 
-        // Pre-compute table lines for efficiency instead of calling is_in_table for each line
-        let table_lines_set: std::collections::HashSet<usize> = if effective_config.tables {
+        // Pre-compute table lines using the same logic as is_in_table function
+        let table_lines_set: std::collections::HashSet<usize> = {
             let mut table_lines = std::collections::HashSet::new();
-            let mut in_table = false;
 
-            for (i, line) in lines.iter().enumerate() {
+            for (i, _line) in lines.iter().enumerate() {
                 let line_number = i + 1;
 
                 // Quick check if in code block using pre-computed blocks from context or structure
@@ -232,18 +219,11 @@ impl Rule for MD013LineLength {
                     structure.is_in_code_block(line_number)
                 };
 
-                if !in_code && line.contains('|') {
-                    in_table = true;
-                    table_lines.insert(line_number);
-                } else if in_table && line.trim().is_empty() {
-                    in_table = false;
-                } else if in_table {
+                if !in_code && Self::is_in_table(&lines, i) {
                     table_lines.insert(line_number);
                 }
             }
             table_lines
-        } else {
-            std::collections::HashSet::new()
         };
 
         for (line_num, line) in lines.iter().enumerate() {
@@ -252,18 +232,8 @@ impl Rule for MD013LineLength {
             // Calculate effective length excluding unbreakable URLs
             let effective_length = self.calculate_effective_length(line);
 
-            // Determine the appropriate line length limit based on line type
-            let line_limit = if heading_lines_set.contains(&line_number) {
-                effective_config
-                    .heading_line_length
-                    .unwrap_or(effective_config.line_length)
-            } else if structure.is_in_code_block(line_number) {
-                effective_config
-                    .code_block_line_length
-                    .unwrap_or(effective_config.line_length)
-            } else {
-                effective_config.line_length
-            };
+            // Use single line length limit for all content
+            let line_limit = effective_config.line_length;
 
             // Skip short lines immediately
             if effective_length <= line_limit {
@@ -271,20 +241,18 @@ impl Rule for MD013LineLength {
             }
 
             // Skip various block types efficiently
-            if !effective_config.strict && !effective_config.stern {
+            if !effective_config.strict {
                 // Skip setext heading underlines
                 if !line.trim().is_empty() && line.trim().chars().all(|c| c == '=' || c == '-') {
                     continue;
                 }
 
-                // Skip block elements according to config flags (optimized checks)
-                if (effective_config.headings
-                    && heading_lines_set.contains(&line_number)
-                    && effective_config.heading_line_length.is_none())
-                    || (!effective_config.code_blocks
-                        && structure.is_in_code_block(line_number)
-                        && effective_config.code_block_line_length.is_none())
-                    || (effective_config.tables && table_lines_set.contains(&line_number))
+                // Skip block elements according to config flags
+                // The flags mean: true = check these elements, false = skip these elements
+                // So we skip when the flag is FALSE and the line is in that element type
+                if (!effective_config.headings && heading_lines_set.contains(&line_number))
+                    || (!effective_config.code_blocks && structure.is_in_code_block(line_number))
+                    || (!effective_config.tables && table_lines_set.contains(&line_number))
                     || structure.is_in_blockquote(line_number)
                     || structure.is_in_html_block(line_number)
                 {
@@ -295,54 +263,21 @@ impl Rule for MD013LineLength {
                 if self.should_ignore_line(line, &lines, line_num, structure) {
                     continue;
                 }
-            } else if effective_config.stern {
-                // In stern mode, only skip if explicitly configured
-                if (effective_config.headings
-                    && heading_lines_set.contains(&line_number)
-                    && effective_config.heading_line_length.is_none())
-                    || (!effective_config.code_blocks
-                        && structure.is_in_code_block(line_number)
-                        && effective_config.code_block_line_length.is_none())
-                    || (effective_config.tables && table_lines_set.contains(&line_number))
-                {
-                    continue;
-                }
             }
 
-            // Generate simplified fix (avoid expensive sentence splitting for now)
-            let fix = if !self.should_skip_line_for_fix(line, line_num, structure) {
-                // First try trimming trailing whitespace
-                let last_char = line.chars().last();
-                if last_char == Some(' ') || last_char == Some('\t') {
-                    let trimmed = line.trim_end();
-                    // Calculate trimmed length to avoid re-scanning
-                    let trimmed_len = self.calculate_effective_length(trimmed);
-                    if trimmed_len <= line_limit {
-                        let line_start = line_index.line_col_to_byte_range(line_number, 1).start;
-                        let line_end = if line_number < lines.len() {
-                            line_index.line_col_to_byte_range(line_number + 1, 1).start - 1
-                        } else {
-                            content.len()
-                        };
-                        Some(crate::rule::Fix {
-                            range: line_start..line_end,
-                            replacement: trimmed.to_string(),
-                        })
-                    } else {
-                        None
-                    }
-                } else {
-                    None // Skip expensive sentence splitting for performance
-                }
+            // Only provide a fix if reflow is enabled
+            let fix = if self.config.reflow && !self.should_skip_line_for_fix(line, line_num, structure) {
+                // Provide a placeholder fix to indicate that reflow will happen
+                // The actual reflow is done in the fix() method
+                Some(crate::rule::Fix {
+                    range: 0..0,                // Placeholder range
+                    replacement: String::new(), // Placeholder replacement
+                })
             } else {
                 None
             };
 
-            let message = if let Some(ref _fix_obj) = fix {
-                format!("Line length {effective_length} exceeds {line_limit} characters (can trim whitespace)")
-            } else {
-                format!("Line length {effective_length} exceeds {line_limit} characters")
-            };
+            let message = format!("Line length {effective_length} exceeds {line_limit} characters");
 
             // Calculate precise character range for the excess portion
             let (start_line, start_col, end_line, end_col) = calculate_excess_range(line_number, line, line_limit);
@@ -362,8 +297,8 @@ impl Rule for MD013LineLength {
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
-        // If reflow is enabled, use the new text reflow functionality
-        if self.config.enable_reflow {
+        // Only fix if reflow is enabled
+        if self.config.reflow {
             let reflow_options = crate::utils::text_reflow::ReflowOptions {
                 line_length: self.config.line_length,
                 break_on_sentences: true,
@@ -373,50 +308,8 @@ impl Rule for MD013LineLength {
             return Ok(crate::utils::text_reflow::reflow_markdown(ctx.content, &reflow_options));
         }
 
-        // Otherwise, use the existing fix logic (trimming whitespace)
-        // Get all warnings with their fixes
-        let warnings = self.check(ctx)?;
-
-        // If no warnings, return original content without allocation
-        if warnings.is_empty() {
-            return Ok(ctx.content.to_string());
-        }
-
-        // Collect all fixes - check if any exist before allocating
-        let mut has_any_fix = false;
-        for w in &warnings {
-            if w.fix.is_some() {
-                has_any_fix = true;
-                break;
-            }
-        }
-
-        if !has_any_fix {
-            return Ok(ctx.content.to_string());
-        }
-
-        // Now collect fixes since we know there's at least one
-        let mut fixes: Vec<_> = warnings
-            .iter()
-            .filter_map(|w| w.fix.as_ref().map(|f| (f.range.start, f.range.end, &f.replacement)))
-            .collect();
-
-        // This should not happen given our check above, but just in case
-        if fixes.is_empty() {
-            return Ok(ctx.content.to_string());
-        }
-
-        fixes.sort_by(|a, b| b.0.cmp(&a.0));
-
-        // Apply fixes from end to beginning to preserve byte offsets
-        let mut result = ctx.content.to_string();
-        for (start, end, replacement) in fixes {
-            if start < result.len() && end <= result.len() && start <= end {
-                result.replace_range(start..end, replacement);
-            }
-        }
-
-        Ok(result)
+        // Without reflow, MD013 has no fixes available
+        Ok(ctx.content.to_string())
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -464,6 +357,12 @@ impl Rule for MD013LineLength {
         }
     }
 
+    fn config_aliases(&self) -> Option<std::collections::HashMap<String, String>> {
+        let mut aliases = std::collections::HashMap::new();
+        aliases.insert("enable_reflow".to_string(), "reflow".to_string());
+        Some(aliases)
+    }
+
     fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
@@ -513,8 +412,8 @@ impl MD013LineLength {
 
     /// Calculate effective line length excluding unbreakable URLs
     fn calculate_effective_length(&self, line: &str) -> usize {
-        if self.config.strict || self.config.stern {
-            // In strict or stern mode, count everything
+        if self.config.strict {
+            // In strict mode, count everything
             return line.chars().count();
         }
 
@@ -529,11 +428,11 @@ impl MD013LineLength {
         // Pattern: [text](very-long-url) -> [text](url)
         if line.contains('[') && line.contains("](") {
             for cap in MARKDOWN_LINK_PATTERN.captures_iter(&effective_line.clone()) {
-                if let (Some(full_match), Some(text), Some(url)) = (cap.get(0), cap.get(1), cap.get(2)) {
-                    if url.as_str().len() > 15 {
-                        let replacement = format!("[{}](url)", text.as_str());
-                        effective_line = effective_line.replacen(full_match.as_str(), &replacement, 1);
-                    }
+                if let (Some(full_match), Some(text), Some(url)) = (cap.get(0), cap.get(1), cap.get(2))
+                    && url.as_str().len() > 15
+                {
+                    let replacement = format!("[{}](url)", text.as_str());
+                    effective_line = effective_line.replacen(full_match.as_str(), &replacement, 1);
                 }
             }
         }
@@ -579,7 +478,7 @@ mod tests {
         assert_eq!(rule.config.line_length, 80);
         assert!(rule.config.code_blocks); // Default is true
         assert!(rule.config.tables); // Default is true
-        assert!(rule.config.headings);
+        assert!(rule.config.headings); // Default is true
         assert!(!rule.config.strict);
     }
 
@@ -597,7 +496,7 @@ mod tests {
     fn test_basic_line_length_violation() {
         let rule = MD013LineLength::new(50, false, false, false, false);
         let content = "This is a line that is definitely longer than fifty characters and should trigger a warning.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -609,7 +508,7 @@ mod tests {
     fn test_no_violation_under_limit() {
         let rule = MD013LineLength::new(100, false, false, false, false);
         let content = "Short line.\nAnother short line.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -619,7 +518,7 @@ mod tests {
     fn test_multiple_violations() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "This line is definitely longer than thirty chars.\nThis is also a line that exceeds the limit.\nShort line.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -629,9 +528,10 @@ mod tests {
 
     #[test]
     fn test_code_blocks_exemption() {
+        // With code_blocks = false, code blocks should be skipped
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "```\nThis is a very long line inside a code block that should be ignored.\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -639,34 +539,35 @@ mod tests {
 
     #[test]
     fn test_code_blocks_not_exempt_when_configured() {
+        // With code_blocks = true, code blocks should be checked
         let rule = MD013LineLength::new(30, true, false, false, false);
         let content = "```\nThis is a very long line inside a code block that should NOT be ignored.\n```";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert!(!result.is_empty());
     }
 
     #[test]
-    fn test_heading_exemption() {
+    fn test_heading_checked_when_enabled() {
         let rule = MD013LineLength::new(30, false, false, true, false);
         let content = "# This is a very long heading that would normally exceed the limit";
-        let ctx = LintContext::new(content);
-        let result = rule.check(&ctx).unwrap();
-
-        assert_eq!(result.len(), 0);
-    }
-
-    #[test]
-    fn test_heading_not_exempt_when_configured() {
-        let rule = MD013LineLength::new(30, false, false, false, false);
-        let content = "# This is a very long heading that should trigger a warning";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
     }
 
+    #[test]
+    fn test_heading_exempt_when_disabled() {
+        let rule = MD013LineLength::new(30, false, false, false, false);
+        let content = "# This is a very long heading that should trigger a warning";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        assert_eq!(result.len(), 0);
+    }
+
     #[test]
     fn test_table_detection() {
         let lines = vec![
@@ -681,20 +582,20 @@ mod tests {
     }
 
     #[test]
-    fn test_table_exemption() {
+    fn test_table_checked_when_enabled() {
         let rule = MD013LineLength::new(30, false, true, false, false);
         let content = "| This is a very long table header | Another long column header |\n|-----------------------------------|-------------------------------|";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        assert_eq!(result.len(), 0);
+        assert_eq!(result.len(), 2); // Both table lines exceed limit
     }
 
     #[test]
     fn test_url_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "https://example.com/this/is/a/very/long/url/that/exceeds/the/limit";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -704,7 +605,7 @@ mod tests {
     fn test_image_reference_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "![This is a very long image alt text that exceeds limit][reference]";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -714,7 +615,7 @@ mod tests {
     fn test_link_reference_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "[reference]: https://example.com/very/long/url/that/exceeds/limit";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -724,7 +625,7 @@ mod tests {
     fn test_strict_mode() {
         let rule = MD013LineLength::new(30, false, false, false, true);
         let content = "https://example.com/this/is/a/very/long/url/that/exceeds/the/limit";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // In strict mode, even URLs trigger warnings
@@ -735,7 +636,7 @@ mod tests {
     fn test_blockquote_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "> This is a very long line inside a blockquote that should be ignored.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -745,7 +646,7 @@ mod tests {
     fn test_setext_heading_underline_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "Heading\n========================================";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // The underline should be exempt
@@ -753,20 +654,19 @@ mod tests {
     }
 
     #[test]
-    fn test_trailing_whitespace_fix() {
+    fn test_no_fix_without_reflow() {
         let rule = MD013LineLength::new(60, false, false, false, false);
         let content = "This line has trailing whitespace that makes it too long      ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
-        // The line without spaces is 56 chars, within limit of 60
-        assert!(result[0].fix.is_some());
-        assert!(result[0].message.contains("can trim whitespace"));
+        // Without reflow, no fix is provided
+        assert!(result[0].fix.is_none());
 
-        // Apply fix
+        // Fix method returns content unchanged
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed.trim(), "This line has trailing whitespace that makes it too long");
+        assert_eq!(fixed, content);
     }
 
     #[test]
@@ -774,7 +674,7 @@ mod tests {
         let rule = MD013LineLength::new(10, false, false, false, false);
         // Unicode characters should count as 1 character each
         let content = "你好世界这是测试文字超过限制"; // 14 characters
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -784,7 +684,7 @@ mod tests {
     #[test]
     fn test_empty_content() {
         let rule = MD013LineLength::default();
-        let ctx = LintContext::new("");
+        let ctx = LintContext::new("", crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -794,7 +694,7 @@ mod tests {
     fn test_excess_range_calculation() {
         let rule = MD013LineLength::new(10, false, false, false, false);
         let content = "12345678901234567890"; // 20 chars, limit is 10
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -807,7 +707,7 @@ mod tests {
     fn test_html_block_exemption() {
         let rule = MD013LineLength::new(30, false, false, false, false);
         let content = "<div>\nThis is a very long line inside an HTML block that should be ignored.\n</div>";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // HTML blocks should be exempt
@@ -816,8 +716,8 @@ mod tests {
 
     #[test]
     fn test_mixed_content() {
-        // code_blocks=false, tables=true, headings=true
-        let rule = MD013LineLength::new(30, false, true, true, false);
+        // code_blocks=false, tables=false, headings=false (all skipped/exempt)
+        let rule = MD013LineLength::new(30, false, false, false, false);
         let content = r#"# This heading is very long but should be exempt
 
 This regular paragraph line is too long and should trigger.
@@ -831,7 +731,7 @@ Code block line that is very long but exempt.
 
 Another long line that should trigger a warning."#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should have warnings for the two regular paragraph lines only
@@ -841,15 +741,14 @@ Another long line that should trigger a warning."#;
     }
 
     #[test]
-    fn test_fix_preserves_content() {
+    fn test_fix_without_reflow_preserves_content() {
         let rule = MD013LineLength::new(50, false, false, false, false);
         let content = "Line 1\nThis line has trailing spaces and is too long      \nLine 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
+        // Without reflow, content is unchanged
         let fixed = rule.fix(&ctx).unwrap();
-        assert!(fixed.contains("Line 1"));
-        assert!(fixed.contains("Line 3"));
-        assert!(!fixed.contains("      \n")); // Trailing spaces removed
+        assert_eq!(fixed, content);
     }
 
     #[test]
@@ -857,10 +756,10 @@ Another long line that should trigger a warning."#;
         let rule = MD013LineLength::default();
         let structure = DocumentStructure::new("test");
 
-        let ctx = LintContext::new("Some content");
+        let ctx = LintContext::new("Some content", crate::config::MarkdownFlavor::Standard);
         assert!(rule.has_relevant_elements(&ctx, &structure));
 
-        let empty_ctx = LintContext::new("");
+        let empty_ctx = LintContext::new("", crate::config::MarkdownFlavor::Standard);
         assert!(!rule.has_relevant_elements(&empty_ctx, &structure));
     }
 
@@ -878,7 +777,7 @@ Another long line that should trigger a warning."#;
 
         // This line would be 85 chars, but only ~45 without the URL
         let content = "Check the docs at https://example.com/very/long/url/that/exceeds/limit for info";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should not flag because effective length (with URL placeholder) is under 50
@@ -891,7 +790,7 @@ Another long line that should trigger a warning."#;
 
         // Line with multiple URLs
         let content = "See https://first-url.com/long and https://second-url.com/also/very/long here";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let result = rule.check(&ctx).unwrap();
 
@@ -905,7 +804,7 @@ Another long line that should trigger a warning."#;
 
         // Markdown link with very long URL
         let content = "Check the [documentation](https://example.com/very/long/path/to/documentation/page) for details";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should not flag because effective length counts link as short
@@ -918,7 +817,7 @@ Another long line that should trigger a warning."#;
 
         // Line that's too long even after URL exclusion
         let content = "This is a very long line with lots of text and https://url.com that still exceeds the limit";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should flag because even with URL placeholder, line is too long
@@ -931,7 +830,7 @@ Another long line that should trigger a warning."#;
 
         // Same line that passes in non-strict mode
         let content = "Check the docs at https://example.com/very/long/url/that/exceeds/limit for info";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // In strict mode, should flag because full URL is counted
@@ -944,7 +843,7 @@ Another long line that should trigger a warning."#;
 
         // This is the actual line from md051.md that was causing issues
         let content = r#"For more information, see the [CommonMark specification](https://spec.commonmark.org/0.30/#link-reference-definitions)."#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should not flag because the URL is in a markdown link
@@ -955,13 +854,13 @@ Another long line that should trigger a warning."#;
     fn test_text_reflow_simple() {
         let config = MD013Config {
             line_length: 30,
-            enable_reflow: true,
+            reflow: true,
             ..Default::default()
         };
         let rule = MD013LineLength::from_config_struct(config);
 
         let content = "This is a very long line that definitely exceeds thirty characters and needs to be wrapped.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let fixed = rule.fix(&ctx).unwrap();
 
@@ -985,13 +884,13 @@ Another long line that should trigger a warning."#;
     fn test_text_reflow_preserves_markdown_elements() {
         let config = MD013Config {
             line_length: 40,
-            enable_reflow: true,
+            reflow: true,
             ..Default::default()
         };
         let rule = MD013LineLength::from_config_struct(config);
 
         let content = "This paragraph has **bold text** and *italic text* and [a link](https://example.com) that should be preserved.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let fixed = rule.fix(&ctx).unwrap();
 
@@ -1013,7 +912,7 @@ Another long line that should trigger a warning."#;
     fn test_text_reflow_preserves_code_blocks() {
         let config = MD013Config {
             line_length: 30,
-            enable_reflow: true,
+            reflow: true,
             ..Default::default()
         };
         let rule = MD013LineLength::from_config_struct(config);
@@ -1026,7 +925,7 @@ def very_long_function_name_that_exceeds_limit():
 ```
 
 More text after code block."#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let fixed = rule.fix(&ctx).unwrap();
 
@@ -1040,7 +939,7 @@ More text after code block."#;
     fn test_text_reflow_preserves_lists() {
         let config = MD013Config {
             line_length: 30,
-            enable_reflow: true,
+            reflow: true,
             ..Default::default()
         };
         let rule = MD013LineLength::from_config_struct(config);
@@ -1055,7 +954,7 @@ And a bullet list:
 
 - Bullet item with very long content that needs wrapping
 - Short bullet"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let fixed = rule.fix(&ctx).unwrap();
 
@@ -1097,7 +996,7 @@ And a bullet list:
         let rule = MD013LineLength::new(30, false, false, false, false);
 
         let content = "This is a very long line that definitely exceeds thirty characters.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let fixed = rule.fix(&ctx).unwrap();
 
@@ -1105,4 +1004,170 @@ And a bullet list:
         // Since there's no trailing whitespace, content should be unchanged
         assert_eq!(fixed, content);
     }
+
+    #[test]
+    fn test_reflow_with_hard_line_breaks() {
+        // Test that lines with exactly 2 trailing spaces are preserved as hard breaks
+        let config = MD013Config {
+            line_length: 40,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        // Test with exactly 2 spaces (hard line break)
+        let content = "This line has a hard break at the end  \nAnd this continues on the next line that is also quite long and needs wrapping";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should preserve the hard line break (2 spaces)
+        assert!(
+            fixed.contains("  \n"),
+            "Hard line break with exactly 2 spaces should be preserved"
+        );
+    }
+
+    #[test]
+    fn test_reflow_preserves_reference_links() {
+        let config = MD013Config {
+            line_length: 40,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This is a very long line with a [reference link][ref] that should not be broken apart when reflowing the text.
+
+[ref]: https://example.com";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Reference link should remain intact
+        assert!(fixed.contains("[reference link][ref]"));
+        assert!(!fixed.contains("[ reference link]"));
+        assert!(!fixed.contains("[ref ]"));
+    }
+
+    #[test]
+    fn test_reflow_with_nested_markdown_elements() {
+        let config = MD013Config {
+            line_length: 35,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This text has **bold with `code` inside** and should handle it properly when wrapping";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Nested elements should be preserved
+        assert!(fixed.contains("**bold with `code` inside**"));
+    }
+
+    #[test]
+    fn test_reflow_with_unbalanced_markdown() {
+        // Test edge case with unbalanced markdown
+        let config = MD013Config {
+            line_length: 30,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This has **unbalanced bold that goes on for a very long time without closing";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should handle gracefully without panic
+        // The text reflow handles unbalanced markdown by treating it as a bold element
+        // Check that the content is properly reflowed without panic
+        assert!(!fixed.is_empty());
+        // Verify the content is wrapped to 30 chars
+        for line in fixed.lines() {
+            assert!(line.len() <= 30 || line.starts_with("**"), "Line exceeds limit: {line}");
+        }
+    }
+
+    #[test]
+    fn test_reflow_fix_indicator() {
+        // Test that reflow provides fix indicators
+        let config = MD013Config {
+            line_length: 30,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This is a very long line that definitely exceeds the thirty character limit";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let warnings = rule.check(&ctx).unwrap();
+
+        // Should have a fix indicator when reflow is true
+        assert!(!warnings.is_empty());
+        assert!(
+            warnings[0].fix.is_some(),
+            "Should provide fix indicator when reflow is true"
+        );
+    }
+
+    #[test]
+    fn test_no_fix_indicator_without_reflow() {
+        // Test that without reflow, no fix is provided
+        let config = MD013Config {
+            line_length: 30,
+            reflow: false,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This is a very long line that definitely exceeds the thirty character limit";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let warnings = rule.check(&ctx).unwrap();
+
+        // Should NOT have a fix indicator when reflow is false
+        assert!(!warnings.is_empty());
+        assert!(warnings[0].fix.is_none(), "Should not provide fix when reflow is false");
+    }
+
+    #[test]
+    fn test_reflow_preserves_all_reference_link_types() {
+        let config = MD013Config {
+            line_length: 40,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "Test [full reference][ref] and [collapsed][] and [shortcut] reference links in a very long line.
+
+[ref]: https://example.com
+[collapsed]: https://example.com
+[shortcut]: https://example.com";
+
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // All reference link types should be preserved
+        assert!(fixed.contains("[full reference][ref]"));
+        assert!(fixed.contains("[collapsed][]"));
+        assert!(fixed.contains("[shortcut]"));
+    }
+
+    #[test]
+    fn test_reflow_handles_images_correctly() {
+        let config = MD013Config {
+            line_length: 40,
+            reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This line has an ![image alt text](https://example.com/image.png) that should not be broken when reflowing.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Image should remain intact
+        assert!(fixed.contains("![image alt text](https://example.com/image.png)"));
+    }
 }
