@@ -211,14 +211,14 @@ impl Rule for MD025SingleTitle {
         // Find all headings at the target level using cached information
         let mut target_level_headings = Vec::new();
         for (line_num, line_info) in ctx.lines.iter().enumerate() {
-            if let Some(heading) = &line_info.heading {
-                if heading.level as usize == self.config.level {
-                    // Ignore if indented 4+ spaces (code block)
-                    if line_info.indent >= 4 {
-                        continue;
-                    }
-                    target_level_headings.push(line_num);
+            if let Some(heading) = &line_info.heading
+                && heading.level as usize == self.config.level
+            {
+                // Ignore if indented 4+ spaces (indented code block) or inside fenced code block
+                if line_info.indent >= 4 || line_info.in_code_block {
+                    continue;
                 }
+                target_level_headings.push(line_num);
             }
         }
 
@@ -305,7 +305,7 @@ impl Rule for MD025SingleTitle {
             }
 
             if let Some(heading) = &line_info.heading {
-                if heading.level as usize == self.config.level {
+                if heading.level as usize == self.config.level && !line_info.in_code_block {
                     if !found_first {
                         found_first = true;
                         // Keep the first heading as-is
@@ -455,19 +455,19 @@ impl Rule for MD025SingleTitle {
         // Fast path: count target level headings efficiently
         let mut target_level_count = 0;
         for line_info in &ctx.lines {
-            if let Some(heading) = &line_info.heading {
-                if heading.level as usize == self.config.level {
-                    // Ignore if indented 4+ spaces (code block)
-                    if line_info.indent >= 4 {
-                        continue;
-                    }
-                    target_level_count += 1;
+            if let Some(heading) = &line_info.heading
+                && heading.level as usize == self.config.level
+            {
+                // Ignore if indented 4+ spaces (indented code block) or inside fenced code block
+                if line_info.indent >= 4 || line_info.in_code_block {
+                    continue;
+                }
+                target_level_count += 1;
 
-                    // If we find more than 1, we need to run the full check
-                    // to determine if they're legitimate document sections
-                    if target_level_count > 1 {
-                        return false;
-                    }
+                // If we find more than 1, we need to run the full check
+                // to determine if they're legitimate document sections
+                if target_level_count > 1 {
+                    return false;
                 }
             }
         }
@@ -511,20 +511,20 @@ mod tests {
 
         // Test with only one level-1 heading
         let content = "# Title\n\n## Section 1\n\n## Section 2";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test with multiple level-1 headings (non-section names) - should flag
         let content = "# Title 1\n\n## Section 1\n\n# Another Title\n\n## Section 2";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1); // Should flag the second level-1 heading
         assert_eq!(result[0].line, 5);
 
         // Test with front matter title and a level-1 heading
         let content = "---\ntitle: Document Title\n---\n\n# Main Heading\n\n## Section 1";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Should not flag a single title after front matter");
     }
@@ -545,7 +545,7 @@ mod tests {
         ];
 
         for case in valid_cases {
-            let ctx = crate::lint_context::LintContext::new(case);
+            let ctx = crate::lint_context::LintContext::new(case, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert!(result.is_empty(), "Should not flag document sections in: {case}");
         }
@@ -557,7 +557,7 @@ mod tests {
         ];
 
         for case in invalid_cases {
-            let ctx = crate::lint_context::LintContext::new(case);
+            let ctx = crate::lint_context::LintContext::new(case, crate::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert!(!result.is_empty(), "Should flag non-section headings in: {case}");
         }
@@ -569,7 +569,7 @@ mod tests {
 
         // Even document sections should be flagged in strict mode
         let content = "# Main Title\n\n## Content\n\n# Appendix A\n\nAppendix content";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Strict mode should flag all multiple H1s");
     }
@@ -582,7 +582,7 @@ mod tests {
 
         // Create content with very short second heading
         let content = "# First\n#";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         // This should not panic
         let result = rule.check(&ctx);
@@ -603,24 +603,24 @@ mod tests {
         // col will be 0, self.config.level is 1, so col + self.config.level = 1
         // This should not exceed bounds for "#" but tests the edge case
         let content = "# First Title\n#";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         // This should not panic and should handle the edge case gracefully
         let result = rule.check(&ctx);
         assert!(result.is_ok());
 
-        if let Ok(warnings) = result {
-            if !warnings.is_empty() {
-                // Check that the fix doesn't cause a panic
-                let fix_result = rule.fix(&ctx);
-                assert!(fix_result.is_ok());
+        if let Ok(warnings) = result
+            && !warnings.is_empty()
+        {
+            // Check that the fix doesn't cause a panic
+            let fix_result = rule.fix(&ctx);
+            assert!(fix_result.is_ok());
 
-                // The fix should produce valid content
-                if let Ok(fixed_content) = fix_result {
-                    assert!(!fixed_content.is_empty());
-                    // Should convert the second "#" to "##" (or "## " if there's content)
-                    assert!(fixed_content.contains("##"));
-                }
+            // The fix should produce valid content
+            if let Ok(fixed_content) = fix_result {
+                assert!(!fixed_content.is_empty());
+                // Should convert the second "#" to "##" (or "## " if there's content)
+                assert!(fixed_content.contains("##"));
             }
         }
     }
@@ -631,7 +631,7 @@ mod tests {
 
         // Test that headings separated by horizontal rules are allowed
         let content = "# First Title\n\nContent here.\n\n---\n\n# Second Title\n\nMore content.\n\n***\n\n# Third Title\n\nFinal content.";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -640,7 +640,7 @@ mod tests {
 
         // Test that headings without separators are still flagged
         let content = "# First Title\n\nContent here.\n\n---\n\n# Second Title\n\nMore content.\n\n# Third Title\n\nNo separator before this one.";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Should flag the heading without separator");
         assert_eq!(result[0].line, 11); // Third title on line 11
@@ -648,7 +648,7 @@ mod tests {
         // Test with allow_with_separators = false
         let strict_rule = MD025SingleTitle::strict();
         let content = "# First Title\n\nContent here.\n\n---\n\n# Second Title\n\nMore content.";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = strict_rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
@@ -656,4 +656,31 @@ mod tests {
             "Strict mode should flag all multiple H1s regardless of separators"
         );
     }
+
+    #[test]
+    fn test_python_comments_in_code_blocks() {
+        let rule = MD025SingleTitle::default();
+
+        // Test that Python comments in code blocks are not treated as headers
+        let content = "# Main Title\n\n```python\n# This is a Python comment, not a heading\nprint('Hello')\n```\n\n## Section\n\nMore content.";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag Python comments in code blocks as headings"
+        );
+
+        // Test the fix method doesn't modify Python comments
+        let content = "# Main Title\n\n```python\n# Python comment\nprint('test')\n```\n\n# Second Title";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let fixed = rule.fix(&ctx).unwrap();
+        assert!(
+            fixed.contains("# Python comment"),
+            "Fix should preserve Python comments in code blocks"
+        );
+        assert!(
+            fixed.contains("## Second Title"),
+            "Fix should demote the actual second heading"
+        );
+    }
 }
