@@ -10,14 +10,14 @@ use std::ops::Range;
 use std::sync::RwLock;
 
 mod md026_config;
-use md026_config::MD026Config;
+use md026_config::{DEFAULT_PUNCTUATION, MD026Config};
 
 lazy_static! {
     // Optimized single regex for all ATX heading types (normal, closed, indented 1-3 spaces)
     static ref ATX_HEADING_UNIFIED: Regex = Regex::new(r"^( {0,3})(#{1,6})(\s+)(.+?)(\s+#{1,6})?$").unwrap();
 
-    // Fast check patterns for early returns - more restrictive
-    static ref QUICK_PUNCTUATION_CHECK: Regex = Regex::new(r"[.,;]").unwrap();
+    // Fast check patterns for early returns - match defaults
+    static ref QUICK_PUNCTUATION_CHECK: Regex = Regex::new(&format!(r"[{}]", regex::escape(DEFAULT_PUNCTUATION))).unwrap();
 
     // Regex cache for punctuation patterns
     static ref PUNCTUATION_REGEX_CACHE: RwLock<HashMap<String, Regex>> = RwLock::new(HashMap::new());
@@ -33,7 +33,7 @@ impl MD026NoTrailingPunctuation {
     pub fn new(punctuation: Option<String>) -> Self {
         Self {
             config: MD026Config {
-                punctuation: punctuation.unwrap_or_else(|| ".,;".to_string()), // More restrictive by default
+                punctuation: punctuation.unwrap_or_else(|| DEFAULT_PUNCTUATION.to_string()),
             },
         }
     }
@@ -67,16 +67,6 @@ impl MD026NoTrailingPunctuation {
     #[inline]
     fn has_trailing_punctuation(&self, text: &str, re: &Regex) -> bool {
         let trimmed = text.trim();
-
-        // Only apply lenient rules for the default punctuation setting
-        // When users specify custom punctuation, they want strict behavior
-        if self.config.punctuation == ".,;" {
-            // Check for common legitimate punctuation patterns before applying the rule
-            if self.is_legitimate_punctuation(trimmed) {
-                return false;
-            }
-        }
-
         re.is_match(trimmed)
     }
 
@@ -101,85 +91,6 @@ impl MD026NoTrailingPunctuation {
         }
     }
 
-    /// Check if punctuation in a heading is legitimate and should be allowed
-    #[inline]
-    fn is_legitimate_punctuation(&self, text: &str) -> bool {
-        let text = text.trim();
-
-        // Allow question marks in question headings
-        if text.ends_with('?') {
-            // Check if it's likely a genuine question
-            let question_words = [
-                "what", "why", "how", "when", "where", "who", "which", "can", "should", "would", "could", "is", "are",
-                "do", "does", "did",
-            ];
-            let lower_text = text.to_lowercase();
-            if question_words.iter().any(|&word| lower_text.starts_with(word)) {
-                return true;
-            }
-        }
-
-        // Allow colons in common categorical/labeling patterns
-        if text.ends_with(':') {
-            // Common patterns that legitimately use colons
-            let colon_patterns = [
-                "faq",
-                "api",
-                "note",
-                "warning",
-                "error",
-                "info",
-                "tip",
-                "chapter",
-                "step",
-                "version",
-                "part",
-                "section",
-                "method",
-                "function",
-                "class",
-                "module",
-                "reference",
-                "guide",
-                "tutorial",
-                "example",
-                "demo",
-                "usage",
-                "syntax",
-            ];
-
-            let lower_text = text.to_lowercase();
-
-            // Check if it starts with any of these patterns
-            if colon_patterns.iter().any(|&pattern| lower_text.starts_with(pattern)) {
-                return true;
-            }
-
-            // Check for numbered items like "Step 1:", "Chapter 2:", "Version 1.0:"
-            if regex::Regex::new(r"^(step|chapter|part|section|version)\s*\d")
-                .unwrap()
-                .is_match(&lower_text)
-            {
-                return true;
-            }
-        }
-
-        // Allow exclamation marks in specific contexts (less common, but sometimes legitimate)
-        if text.ends_with('!') {
-            // Only allow for very specific patterns like "Important!", "New!", "Warning!"
-            let exclamation_patterns = ["important", "new", "warning", "alert", "notice", "attention"];
-            let lower_text = text.to_lowercase();
-            if exclamation_patterns
-                .iter()
-                .any(|&pattern| lower_text.starts_with(pattern))
-            {
-                return true;
-            }
-        }
-
-        false
-    }
-
     // Remove trailing punctuation from text
     #[inline]
     fn remove_trailing_punctuation(&self, text: &str, re: &Regex) -> String {
@@ -195,7 +106,18 @@ impl MD026NoTrailingPunctuation {
             let space = captures.get(3).unwrap().as_str();
             let content = captures.get(4).unwrap().as_str();
 
-            let fixed_content = self.remove_trailing_punctuation(content, re);
+            // Check if content ends with a custom header ID like {#my-id}
+            // If so, we need to fix punctuation before the ID
+            let fixed_content = if let Some(id_pos) = content.rfind(" {#") {
+                // Has a custom ID - fix punctuation before it
+                let before_id = &content[..id_pos];
+                let id_part = &content[id_pos..];
+                let fixed_before = self.remove_trailing_punctuation(before_id, re);
+                format!("{fixed_before}{id_part}")
+            } else {
+                // No custom ID - just remove trailing punctuation
+                self.remove_trailing_punctuation(content, re)
+            };
 
             // Preserve any trailing hashes if present
             if let Some(trailing) = captures.get(5) {
@@ -265,7 +187,7 @@ impl Rule for MD026NoTrailingPunctuation {
 
         // Quick check for any punctuation we care about
         // For custom punctuation, we need to check differently
-        if self.config.punctuation == ".,;" {
+        if self.config.punctuation == DEFAULT_PUNCTUATION {
             if !QUICK_PUNCTUATION_CHECK.is_match(content) {
                 return Ok(Vec::new());
             }
@@ -297,10 +219,14 @@ impl Rule for MD026NoTrailingPunctuation {
                     continue;
                 }
 
-                // Check for trailing punctuation
-                if self.has_trailing_punctuation(&heading.text, &re) {
+                // LintContext already strips Kramdown IDs from heading.text
+                // So we just check the heading text directly for trailing punctuation
+                // This correctly flags "# Heading." even if it has {#id}
+                let text_to_check = heading.text.clone();
+
+                if self.has_trailing_punctuation(&text_to_check, &re) {
                     // Find the trailing punctuation
-                    if let Some(punctuation_match) = re.find(&heading.text) {
+                    if let Some(punctuation_match) = re.find(&text_to_check) {
                         let line = &line_info.content;
 
                         // For ATX headings, find the punctuation position in the line
@@ -316,14 +242,14 @@ impl Rule for MD026NoTrailingPunctuation {
                             punctuation_len,
                         );
 
-                        let last_char = heading.text.chars().last().unwrap_or(' ');
+                        let last_char = text_to_check.chars().last().unwrap_or(' ');
                         warnings.push(LintWarning {
                             rule_name: Some(self.name()),
                             line: start_line,
                             column: start_col,
                             end_line,
                             end_column: end_col,
-                            message: format!("Heading '{}' ends with punctuation '{}'", heading.text, last_char),
+                            message: format!("Heading '{text_to_check}' ends with punctuation '{last_char}'"),
                             severity: Severity::Warning,
                             fix: Some(Fix {
                                 range: self.get_line_byte_range(content, line_num + 1),
@@ -352,7 +278,7 @@ impl Rule for MD026NoTrailingPunctuation {
 
         // Quick check for punctuation
         // For custom punctuation, we need to check differently
-        if self.config.punctuation == ".,;" {
+        if self.config.punctuation == DEFAULT_PUNCTUATION {
             if !QUICK_PUNCTUATION_CHECK.is_match(content) {
                 return Ok(content.to_string());
             }
@@ -386,8 +312,12 @@ impl Rule for MD026NoTrailingPunctuation {
                     continue;
                 }
 
+                // LintContext already strips custom header IDs from heading.text
+                // So we just check the heading text directly for trailing punctuation
+                let text_to_check = heading.text.clone();
+
                 // Check and fix trailing punctuation
-                if self.has_trailing_punctuation(&heading.text, &re) {
+                if self.has_trailing_punctuation(&text_to_check, &re) {
                     fixed_lines[line_num] = if matches!(heading.style, crate::lint_context::HeadingStyle::ATX) {
                         self.fix_atx_heading(&line_info.content, &re)
                     } else {
@@ -439,7 +369,7 @@ mod tests {
     fn test_no_trailing_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# This is a heading\n\n## Another heading";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Headings without punctuation should not be flagged");
     }
@@ -448,7 +378,7 @@ mod tests {
     fn test_trailing_period() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# This is a heading.\n\n## Another one.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert_eq!(result[0].line, 1);
@@ -462,7 +392,7 @@ mod tests {
     fn test_trailing_comma() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Heading,\n## Sub-heading,";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert!(result[0].message.contains("ends with punctuation ','"));
@@ -472,7 +402,7 @@ mod tests {
     fn test_trailing_semicolon() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title;\n## Subtitle;";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         assert!(result[0].message.contains("ends with punctuation ';'"));
@@ -482,7 +412,7 @@ mod tests {
     fn test_custom_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(Some("!".to_string()));
         let content = "# Important!\n## Regular heading.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Only exclamation should be flagged with custom config");
         assert_eq!(result[0].line, 1);
@@ -493,33 +423,31 @@ mod tests {
     fn test_legitimate_question_mark() {
         let rule = MD026NoTrailingPunctuation::new(Some(".,;?".to_string()));
         let content = "# What is this?\n# This is bad.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With custom punctuation, legitimate punctuation exceptions don't apply
         assert_eq!(result.len(), 2, "Both should be flagged with custom punctuation");
     }
 
     #[test]
-    fn test_default_legitimate_question() {
+    fn test_question_marks_not_in_default() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# What is Rust?\n# How does it work?\n# Is it fast?";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert!(
-            result.is_empty(),
-            "Question marks in questions should be allowed by default"
-        );
+        assert!(result.is_empty(), "Question marks are not in default punctuation list");
     }
 
     #[test]
-    fn test_legitimate_colons() {
+    fn test_colons_in_default() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# FAQ:\n# API Reference:\n# Step 1:\n# Version 2.0:";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
-        assert!(
-            result.is_empty(),
-            "Colons in categorical headings should be allowed by default"
+        assert_eq!(
+            result.len(),
+            4,
+            "Colons are in default punctuation list and should be flagged"
         );
     }
 
@@ -527,7 +455,7 @@ mod tests {
     fn test_fix_atx_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.\n## Subtitle,\n### Sub-subtitle;";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title\n## Subtitle\n### Sub-subtitle");
     }
@@ -536,7 +464,7 @@ mod tests {
     fn test_fix_setext_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "Title.\n======\n\nSubtitle,\n---------";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "Title\n======\n\nSubtitle\n---------");
     }
@@ -545,7 +473,7 @@ mod tests {
     fn test_fix_preserves_trailing_hashes() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title. #\n## Subtitle, ##";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title #\n## Subtitle ##");
     }
@@ -554,7 +482,7 @@ mod tests {
     fn test_indented_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "   # Title.\n  ## Subtitle.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Indented headings (< 4 spaces) should be checked");
     }
@@ -563,7 +491,7 @@ mod tests {
     fn test_deeply_indented_ignored() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "    # This is code.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Deeply indented lines (4+ spaces) should be ignored");
     }
@@ -572,7 +500,7 @@ mod tests {
     fn test_multiple_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title...";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         assert_eq!(result[0].column, 8); // Points to first period
@@ -582,7 +510,7 @@ mod tests {
     fn test_empty_content() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -591,7 +519,7 @@ mod tests {
     fn test_no_headings() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "This is just text.\nMore text with punctuation.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Non-heading lines should not be checked");
     }
@@ -630,7 +558,7 @@ mod tests {
 
         let rule = MD026NoTrailingPunctuation::from_config(&config);
         let content = "# Title!\n# Another?";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Custom punctuation from config should be used");
     }
@@ -639,7 +567,7 @@ mod tests {
     fn test_fix_removes_punctuation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.   \n## Subtitle,  ";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // The current implementation doesn't preserve trailing whitespace after punctuation removal
         assert_eq!(fixed, "# Title\n## Subtitle");
@@ -649,12 +577,12 @@ mod tests {
     fn test_final_newline_preservation() {
         let rule = MD026NoTrailingPunctuation::new(None);
         let content = "# Title.\n";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, "# Title\n");
 
         let content_no_newline = "# Title.";
-        let ctx2 = LintContext::new(content_no_newline);
+        let ctx2 = LintContext::new(content_no_newline, crate::config::MarkdownFlavor::Standard);
         let fixed2 = rule.fix(&ctx2).unwrap();
         assert_eq!(fixed2, "# Title");
     }
