@@ -4,6 +4,8 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
+use crate::utils::kramdown_utils::is_kramdown_block_attribute;
+use crate::utils::mkdocs_admonitions;
 use crate::utils::range_utils::{LineIndex, calculate_line_range};
 use serde::{Deserialize, Serialize};
 
@@ -68,10 +70,11 @@ impl MD031BlanksAroundFences {
             // Check for ordered list (number followed by . or ))
             if trimmed.chars().next().is_some_and(|c| c.is_ascii_digit()) {
                 let mut chars = trimmed.chars().skip_while(|c| c.is_ascii_digit());
-                if let Some(next) = chars.next() {
-                    if (next == '.' || next == ')') && chars.next() == Some(' ') {
-                        return true;
-                    }
+                if let Some(next) = chars.next()
+                    && (next == '.' || next == ')')
+                    && chars.next() == Some(' ')
+                {
+                    return true;
                 }
             }
 
@@ -124,12 +127,76 @@ impl Rule for MD031BlanksAroundFences {
 
         let mut in_code_block = false;
         let mut current_fence_marker: Option<String> = None;
+        let mut in_admonition = false;
+        let mut admonition_indent = 0;
+        let is_mkdocs = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
         let mut i = 0;
 
         while i < lines.len() {
             let line = lines[i];
             let trimmed = line.trim_start();
 
+            // Check for MkDocs admonition start
+            if is_mkdocs && mkdocs_admonitions::is_admonition_start(line) {
+                // Check for blank line before admonition (similar to code blocks)
+                if i > 0 && !Self::is_empty_line(lines[i - 1]) && self.should_require_blank_line(i, &lines) {
+                    let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, lines[i]);
+
+                    warnings.push(LintWarning {
+                        rule_name: Some(self.name()),
+                        line: start_line,
+                        column: start_col,
+                        end_line,
+                        end_column: end_col,
+                        message: "No blank line before admonition block".to_string(),
+                        severity: Severity::Warning,
+                        fix: Some(Fix {
+                            range: line_index.line_col_to_byte_range_with_length(i + 1, 1, 0),
+                            replacement: "\n".to_string(),
+                        }),
+                    });
+                }
+
+                in_admonition = true;
+                admonition_indent = mkdocs_admonitions::get_admonition_indent(line).unwrap_or(0);
+                i += 1;
+                continue;
+            }
+
+            // Check if we're exiting an admonition
+            if in_admonition {
+                if !line.trim().is_empty() && !mkdocs_admonitions::is_admonition_content(line, admonition_indent) {
+                    // We've exited the admonition
+                    in_admonition = false;
+
+                    // Check for blank line after admonition (current line should be blank)
+                    if !Self::is_empty_line(line) && self.should_require_blank_line(i - 1, &lines) {
+                        let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, lines[i]);
+
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            line: start_line,
+                            column: start_col,
+                            end_line,
+                            end_column: end_col,
+                            message: "No blank line after admonition block".to_string(),
+                            severity: Severity::Warning,
+                            fix: Some(Fix {
+                                range: line_index.line_col_to_byte_range_with_length(i, 0, 0),
+                                replacement: "\n".to_string(),
+                            }),
+                        });
+                    }
+
+                    admonition_indent = 0;
+                    // Don't continue - process this line normally
+                } else {
+                    // Still in admonition
+                    i += 1;
+                    continue;
+                }
+            }
+
             // Determine fence marker if this is a fence line
             let fence_marker = if trimmed.starts_with("```") {
                 let backtick_count = trimmed.chars().take_while(|&c| c == '`').count();
@@ -169,8 +236,10 @@ impl Rule for MD031BlanksAroundFences {
                             current_fence_marker = None;
 
                             // Check for blank line after closing fence
+                            // Allow Kramdown block attributes if configured
                             if i + 1 < lines.len()
                                 && !Self::is_empty_line(lines[i + 1])
+                                && !is_kramdown_block_attribute(lines[i + 1])
                                 && self.should_require_blank_line(i, &lines)
                             {
                                 let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, lines[i]);
@@ -277,8 +346,10 @@ impl Rule for MD031BlanksAroundFences {
                             current_fence_marker = None;
 
                             // Add blank line after closing fence if needed
+                            // Don't add if next line is a Kramdown block attribute
                             if i + 1 < lines.len()
                                 && !Self::is_empty_line(lines[i + 1])
+                                && !is_kramdown_block_attribute(lines[i + 1])
                                 && self.should_require_blank_line(i, &lines)
                             {
                                 result.push(String::new());
@@ -467,7 +538,7 @@ mod tests {
         // Test with properly formatted code blocks
         let content = "# Test Code Blocks\n\n```rust\nfn main() {}\n```\n\nSome text here.";
         let structure = document_structure_from_str(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check_with_structure(&ctx, &structure).unwrap();
         assert!(
             warnings.is_empty(),
@@ -477,7 +548,7 @@ mod tests {
         // Test with missing blank line before
         let content = "# Test Code Blocks\n```rust\nfn main() {}\n```\n\nSome text here.";
         let structure = document_structure_from_str(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check_with_structure(&ctx, &structure).unwrap();
         assert_eq!(warnings.len(), 1, "Expected 1 warning for missing blank line before");
         assert_eq!(warnings[0].line, 2, "Warning should be on line 2");
@@ -489,7 +560,7 @@ mod tests {
         // Test with missing blank line after
         let content = "# Test Code Blocks\n\n```rust\nfn main() {}\n```\nSome text here.";
         let structure = document_structure_from_str(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check_with_structure(&ctx, &structure).unwrap();
         assert_eq!(warnings.len(), 1, "Expected 1 warning for missing blank line after");
         assert_eq!(warnings[0].line, 5, "Warning should be on line 5");
@@ -501,7 +572,7 @@ mod tests {
         // Test with missing blank lines both before and after
         let content = "# Test Code Blocks\n```rust\nfn main() {}\n```\nSome text here.";
         let structure = document_structure_from_str(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check_with_structure(&ctx, &structure).unwrap();
         assert_eq!(
             warnings.len(),
@@ -520,7 +591,7 @@ mod tests {
 content
 ```
 ````"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(warnings.len(), 0, "Should not flag nested code blocks");
 
@@ -551,7 +622,7 @@ console.log("Hello, world!");
 
 More text here."#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(
             warnings.len(),
@@ -568,7 +639,7 @@ echo "nested"
 ````
 `````"#;
 
-        let ctx_5 = LintContext::new(content_5);
+        let ctx_5 = LintContext::new(content_5, crate::config::MarkdownFlavor::Standard);
         let warnings_5 = rule.check(&ctx_5).unwrap();
         assert_eq!(warnings_5.len(), 0, "Should handle deeply nested code blocks");
     }
@@ -579,7 +650,7 @@ echo "nested"
 
         // Test content with trailing newline
         let content = "Some text\n```\ncode\n```\nMore text\n";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should preserve the trailing newline
@@ -593,7 +664,7 @@ echo "nested"
 
         // Test content without trailing newline
         let content = "Some text\n```\ncode\n```\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should not add trailing newline if original didn't have one
@@ -610,7 +681,7 @@ echo "nested"
         let rule = MD031BlanksAroundFences::new(true);
 
         let content = "1. First item\n   ```python\n   code_in_list()\n   ```\n2. Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should flag missing blank lines before and after code block in list
@@ -625,7 +696,7 @@ echo "nested"
         let rule = MD031BlanksAroundFences::new(false);
 
         let content = "1. First item\n   ```python\n   code_in_list()\n   ```\n2. Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should not flag missing blank lines inside lists
@@ -638,7 +709,7 @@ echo "nested"
         let rule = MD031BlanksAroundFences::new(false);
 
         let content = "Some text\n```python\ncode_outside_list()\n```\nMore text";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let warnings = rule.check(&ctx).unwrap();
 
         // Should still flag missing blank lines outside lists
@@ -671,7 +742,7 @@ echo "nested"
         let rule = MD031BlanksAroundFences::new(false);
 
         let content = "1. First item\n   ```python\n   code()\n   ```\n2. Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should not add blank lines when list_items is false
@@ -684,7 +755,7 @@ echo "nested"
         let rule = MD031BlanksAroundFences::new(true);
 
         let content = "1. First item\n   ```python\n   code()\n   ```\n2. Second item";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         // Should add blank lines when list_items is true
