@@ -23,6 +23,10 @@ lazy_static! {
     static ref URL_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftps?)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
     static ref URL_FIX_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftps?)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
 
+    // Pattern to detect custom protocol patterns that shouldn't be flagged
+    // These are commonly used in documentation but aren't actual browsable URLs
+    static ref CUSTOM_PROTOCOL_PATTERN: Regex = Regex::new(r#"(?:grpc|ws|wss|ssh|git|svn|file|data|javascript|vscode|chrome|about|slack|discord|matrix|irc|redis|mongodb|postgresql|mysql|kafka|nats|amqp|mqtt|custom|app|api|service)://"#).unwrap();
+
     // Pattern to match markdown link format - capture destination in Group 1
     // Updated to handle nested brackets in badge links like [![badge](img)](link)
     static ref MARKDOWN_LINK_PATTERN: Regex = Regex::new(r#"\[(?:[^\[\]]|\[[^\]]*\])*\]\(([^)\s]+)(?:\s+(?:\"[^\"]*\"|\'[^\']*\'))?\)"#).unwrap();
@@ -57,9 +61,6 @@ lazy_static! {
     // Updated to support IPv6 addresses
     static ref REFERENCE_DEF_RE: Regex = Regex::new(r"^\s*\[[^\]]+\]:\s*(?:https?|ftps?)://\S+$").unwrap();
 
-    // Pattern to match URLs inside HTML attributes (src, href, srcset, etc.)
-    static ref HTML_ATTRIBUTE_URL: Regex = Regex::new(r#"(?:src|href|srcset|content|data-\w+)\s*=\s*["']([^"']*)["']"#).unwrap();
-
     // Pattern to match HTML comments
     static ref HTML_COMMENT_PATTERN: Regex = Regex::new(r#"<!--[\s\S]*?-->"#).unwrap();
 }
@@ -81,9 +82,11 @@ impl MD034NoBareUrls {
 
         // Remove trailing punctuation characters
         while end > 0 {
-            if let Some(last_char) = url.chars().nth(end - 1) {
+            // Get the last character of the current substring safely
+            let current_url = &url[..end];
+            if let Some((last_char_pos, last_char)) = current_url.char_indices().next_back() {
                 if trailing_punct.contains(&last_char) {
-                    end -= last_char.len_utf8();
+                    end = last_char_pos;
                 } else {
                     break;
                 }
@@ -114,14 +117,18 @@ impl MD034NoBareUrls {
         // First, find all markdown link ranges across the entire content
         let mut excluded_ranges: Vec<(usize, usize)> = Vec::new();
 
-        // Markdown links: [text](url) - handle multi-line
+        // Markdown links: [text](url) - exclude both destination and entire link text
         for cap in MARKDOWN_LINK_PATTERN.captures_iter(content) {
             if let Some(dest) = cap.get(1) {
                 excluded_ranges.push((dest.start(), dest.end()));
             }
+            // Also exclude the entire link to handle URLs in link text
+            if let Some(full_match) = cap.get(0) {
+                excluded_ranges.push((full_match.start(), full_match.end()));
+            }
         }
 
-        // Markdown images: ![alt](url) - handle multi-line
+        // Markdown images: ![alt](url)
         for cap in MARKDOWN_IMAGE_PATTERN.captures_iter(content) {
             if let Some(dest) = cap.get(2) {
                 excluded_ranges.push((dest.start(), dest.end()));
@@ -135,11 +142,9 @@ impl MD034NoBareUrls {
             }
         }
 
-        // HTML attribute URLs: src="url", href="url", etc.
-        for cap in HTML_ATTRIBUTE_URL.captures_iter(content) {
-            if let Some(url_attr) = cap.get(1) {
-                excluded_ranges.push((url_attr.start(), url_attr.end()));
-            }
+        // HTML tags: exclude everything inside them
+        for html_tag in ctx.html_tags().iter() {
+            excluded_ranges.push((html_tag.byte_offset, html_tag.byte_end));
         }
 
         // HTML comments: <!-- url -->
@@ -153,11 +158,11 @@ impl MD034NoBareUrls {
         excluded_ranges.sort_by_key(|r| r.0);
         let mut merged: Vec<(usize, usize)> = Vec::new();
         for (start, end) in excluded_ranges {
-            if let Some((_, last_end)) = merged.last_mut() {
-                if *last_end >= start {
-                    *last_end = (*last_end).max(end);
-                    continue;
-                }
+            if let Some((_, last_end)) = merged.last_mut()
+                && *last_end >= start
+            {
+                *last_end = (*last_end).max(end);
+                continue;
             }
             merged.push((start, end));
         }
@@ -196,6 +201,17 @@ impl MD034NoBareUrls {
                     continue;
                 }
 
+                // Skip custom protocols that aren't standard web protocols
+                // Check if there's a custom protocol pattern before this match
+                if start_in_line > 0 {
+                    // Look back to see if this is part of a custom protocol URL
+                    let prefix_start = start_in_line.saturating_sub(20); // Look back up to 20 chars
+                    let prefix = &line_content[prefix_start..start_in_line];
+                    if CUSTOM_PROTOCOL_PATTERN.is_match(prefix) {
+                        continue;
+                    }
+                }
+
                 let global_start = line_info.byte_offset + start_in_line;
                 let global_end = line_info.byte_offset + end_in_line;
                 all_matches.push((global_start, global_end, false));
@@ -237,27 +253,29 @@ impl MD034NoBareUrls {
             }
 
             // Manual boundary check: not part of a larger word
-            let before = if match_start == 0 {
+            // Use bytes for ASCII checks (more efficient)
+            let bytes = content.as_bytes();
+            let before_byte = if match_start == 0 {
                 None
             } else {
-                content.get(match_start - 1..match_start)
+                bytes.get(match_start - 1).copied()
             };
-            let after = content.get(match_end..match_end + 1);
+            let after_byte = bytes.get(match_end).copied();
 
             let is_valid_boundary = if is_email {
-                before.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
-                    && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
+                before_byte.is_none_or(|b| !b.is_ascii_alphanumeric() && b != b'_' && b != b'.')
+                    && after_byte.is_none_or(|b| !b.is_ascii_alphanumeric() && b != b'_' && b != b'.')
             } else {
-                before.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
-                    && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
+                before_byte.is_none_or(|b| !b.is_ascii_alphanumeric() && b != b'_')
+                    && after_byte.is_none_or(|b| !b.is_ascii_alphanumeric() && b != b'_')
             };
 
             if !is_valid_boundary {
                 continue;
             }
 
-            // Skip if this is within a code span (code blocks already checked)
-            if ctx.is_in_code_block_or_span(match_start) {
+            // Skip if this is within any skip context (code blocks, MkDocs snippets, etc.)
+            if crate::utils::skip_context::is_in_skip_context(ctx, match_start) {
                 continue;
             }
 
@@ -276,12 +294,11 @@ impl MD034NoBareUrls {
             let (line_num, col_num) = ctx.offset_to_line_col(match_start);
 
             // Skip reference definitions for URLs
-            if !is_email {
-                if let Some(line_info) = ctx.line_info(line_num) {
-                    if REFERENCE_DEF_RE.is_match(&line_info.content) {
-                        continue;
-                    }
-                }
+            if !is_email
+                && let Some(line_info) = ctx.line_info(line_num)
+                && REFERENCE_DEF_RE.is_match(&line_info.content)
+            {
+                continue;
             }
 
             let matched_text = &content[match_start..match_end];
@@ -656,7 +673,7 @@ mod tests {
 [![(Runtime) Build and Test](https://github.com/facebook/react/actions/workflows/runtime_build_and_test.yml/badge.svg)](https://github.com/facebook/react/actions/workflows/runtime_build_and_test.yml) \
 [![(Compiler) TypeScript](https://github.com/facebook/react/actions/workflows/compiler_typescript.yml/badge.svg?branch=main)](https://github.com/facebook/react/actions/workflows/compiler_typescript.yml) \
 [![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](https://legacy.reactjs.org/docs/how-to-contribute.html#your-first-pull-request)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         if !result.is_empty() {
             log::debug!("MD034 warnings: {result:#?}");
@@ -671,7 +688,7 @@ mod tests {
     fn test_bare_urls() {
         let rule = MD034NoBareUrls;
         let content = "This is a bare URL: https://example.com/foobar";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Bare URLs should be flagged");
         assert_eq!(result[0].line, 1);
@@ -716,7 +733,7 @@ mod tests {
         );
 
         let rule = MD034NoBareUrls;
-        let ctx = LintContext::new(&content);
+        let ctx = LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
 
         // Warm up
         let _ = rule.check(&ctx).unwrap();
