@@ -6,7 +6,18 @@ use crate::utils::document_structure::{DocumentStructure, DocumentStructureExten
 use crate::utils::emphasis_utils::{
     EmphasisSpan, find_emphasis_markers, find_emphasis_spans, has_doc_patterns, replace_inline_code,
 };
+use crate::utils::kramdown_utils::has_span_ial;
 use crate::utils::regex_cache::UNORDERED_LIST_MARKER_REGEX;
+use crate::utils::skip_context::{is_in_html_comment, is_in_math_context, is_in_table_cell};
+use lazy_static::lazy_static;
+use regex::Regex;
+
+lazy_static! {
+    // Reference definition pattern - matches [ref]: url "title"
+    static ref REF_DEF_REGEX: Regex = Regex::new(
+        r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#
+    ).unwrap();
+}
 
 /// Check if an emphasis span has spacing issues that should be flagged
 #[inline]
@@ -24,6 +35,34 @@ impl Default for MD037NoSpaceInEmphasis {
     }
 }
 
+impl MD037NoSpaceInEmphasis {
+    /// Check if a byte position is within a link (inline links, reference links, or reference definitions)
+    fn is_in_link(&self, ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
+        // Check inline and reference links
+        for link in &ctx.links {
+            if link.byte_offset <= byte_pos && byte_pos < link.byte_end {
+                return true;
+            }
+        }
+
+        // Check images (which use similar syntax)
+        for image in &ctx.images {
+            if image.byte_offset <= byte_pos && byte_pos < image.byte_end {
+                return true;
+            }
+        }
+
+        // Check reference definitions [ref]: url "title" using regex pattern
+        for m in REF_DEF_REGEX.find_iter(ctx.content) {
+            if m.start() <= byte_pos && byte_pos < m.end() {
+                return true;
+            }
+        }
+
+        false
+    }
+}
+
 impl Rule for MD037NoSpaceInEmphasis {
     fn name(&self) -> &'static str {
         "MD037"
@@ -76,14 +115,38 @@ impl Rule for MD037NoSpaceInEmphasis {
                 continue;
             }
 
-            // Replace inline code with placeholders to avoid false positives
-            let line_no_code = replace_inline_code(line);
-
-            // Use the optimized emphasis parsing logic
-            self.check_line_for_emphasis_issues_fast(&line_no_code, line_num + 1, &mut warnings);
+            // Check for emphasis issues on the original line
+            self.check_line_for_emphasis_issues_fast(line, line_num + 1, &mut warnings);
         }
 
-        Ok(warnings)
+        // Filter out warnings for emphasis markers that are inside links, HTML comments, or math
+        let mut filtered_warnings = Vec::new();
+        let mut line_start_pos = 0;
+
+        for (line_idx, line) in content.lines().enumerate() {
+            let line_num = line_idx + 1;
+
+            // Find warnings for this line
+            for warning in &warnings {
+                if warning.line == line_num {
+                    // Calculate byte position of the warning
+                    let byte_pos = line_start_pos + (warning.column - 1);
+
+                    // Skip if inside links, HTML comments, math contexts, or tables
+                    if !self.is_in_link(ctx, byte_pos)
+                        && !is_in_html_comment(content, byte_pos)
+                        && !is_in_math_context(ctx, byte_pos)
+                        && !is_in_table_cell(ctx, line_num, warning.column)
+                    {
+                        filtered_warnings.push(warning.clone());
+                    }
+                }
+            }
+
+            line_start_pos += line.len() + 1; // +1 for newline
+        }
+
+        Ok(filtered_warnings)
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
@@ -194,22 +257,22 @@ impl MD037NoSpaceInEmphasis {
         if (line.starts_with(' ') || line.starts_with('*') || line.starts_with('+') || line.starts_with('-'))
             && UNORDERED_LIST_MARKER_REGEX.is_match(line)
         {
-            if let Some(caps) = UNORDERED_LIST_MARKER_REGEX.captures(line) {
-                if let Some(full_match) = caps.get(0) {
-                    let list_marker_end = full_match.end();
-                    if list_marker_end < line.len() {
-                        let remaining_content = &line[list_marker_end..];
+            if let Some(caps) = UNORDERED_LIST_MARKER_REGEX.captures(line)
+                && let Some(full_match) = caps.get(0)
+            {
+                let list_marker_end = full_match.end();
+                if list_marker_end < line.len() {
+                    let remaining_content = &line[list_marker_end..];
 
-                        if self.is_likely_list_item_fast(remaining_content) {
-                            self.check_line_content_for_emphasis_fast(
-                                remaining_content,
-                                line_num,
-                                list_marker_end,
-                                warnings,
-                            );
-                        } else {
-                            self.check_line_content_for_emphasis_fast(line, line_num, 0, warnings);
-                        }
+                    if self.is_likely_list_item_fast(remaining_content) {
+                        self.check_line_content_for_emphasis_fast(
+                            remaining_content,
+                            line_num,
+                            list_marker_end,
+                            warnings,
+                        );
+                    } else {
+                        self.check_line_content_for_emphasis_fast(line, line_num, 0, warnings);
                     }
                 }
             }
@@ -258,14 +321,17 @@ impl MD037NoSpaceInEmphasis {
         offset: usize,
         warnings: &mut Vec<LintWarning>,
     ) {
+        // Replace inline code to avoid false positives with emphasis markers inside backticks
+        let processed_content = replace_inline_code(content);
+
         // Find all emphasis markers using optimized parsing
-        let markers = find_emphasis_markers(content);
+        let markers = find_emphasis_markers(&processed_content);
         if markers.is_empty() {
             return;
         }
 
         // Find valid emphasis spans
-        let spans = find_emphasis_spans(content, markers);
+        let spans = find_emphasis_spans(&processed_content, markers);
 
         // Check each span for spacing issues
         for span in spans {
@@ -275,6 +341,16 @@ impl MD037NoSpaceInEmphasis {
                 let full_end = span.closing.end_pos();
                 let full_text = &content[full_start..full_end];
 
+                // Skip if this emphasis has a Kramdown span IAL immediately after it
+                // (no space between emphasis and IAL)
+                if full_end < content.len() {
+                    let remaining = &content[full_end..];
+                    // Check if IAL starts immediately after the emphasis (no whitespace)
+                    if remaining.starts_with('{') && has_span_ial(remaining.split_whitespace().next().unwrap_or("")) {
+                        continue;
+                    }
+                }
+
                 // Create the marker string efficiently
                 let marker_char = span.opening.as_char();
                 let marker_str = if span.opening.count == 1 {
@@ -346,25 +422,128 @@ mod tests {
         // Test with no spaces inside emphasis - should pass
         let content = "This is *correct* emphasis and **strong emphasis**";
         let structure = DocumentStructure::new(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         assert!(result.is_empty(), "No warnings expected for correct emphasis");
 
         // Test with actual spaces inside emphasis - use content that should warn
         let content = "This is * text with spaces * and more content";
         let structure = DocumentStructure::new(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         assert!(!result.is_empty(), "Expected warnings for spaces in emphasis");
 
         // Test with code blocks - emphasis in code should be ignored
         let content = "This is *correct* emphasis\n```\n* incorrect * in code block\n```\nOutside block with * spaces in emphasis *";
         let structure = DocumentStructure::new(content);
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check_with_structure(&ctx, &structure).unwrap();
         assert!(
             !result.is_empty(),
             "Expected warnings for spaces in emphasis outside code block"
         );
     }
+
+    #[test]
+    fn test_emphasis_in_links_not_flagged() {
+        let rule = MD037NoSpaceInEmphasis;
+        let content = r#"Check this [* spaced asterisk *](https://example.com/*test*) link.
+
+This has * real spaced emphasis * that should be flagged."#;
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Test passed - emphasis inside links are filtered out correctly
+
+        // Only the real emphasis outside links should be flagged
+        assert_eq!(
+            result.len(),
+            1,
+            "Expected exactly 1 warning, but got: {:?}",
+            result.len()
+        );
+        assert!(result[0].message.contains("Spaces inside emphasis markers"));
+        // Should flag "* real spaced emphasis *" but not emphasis patterns inside links
+        assert!(result[0].line == 3); // Line with "* real spaced emphasis *"
+    }
+
+    #[test]
+    fn test_emphasis_in_links_vs_outside_links() {
+        let rule = MD037NoSpaceInEmphasis;
+        let content = r#"Check [* spaced *](https://example.com/*test*) and inline * real spaced * text.
+
+[* link *]: https://example.com/*path*"#;
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Only the actual emphasis outside links should be flagged
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("Spaces inside emphasis markers"));
+        // Should be the "* real spaced *" text on line 1
+        assert!(result[0].line == 1);
+    }
+
+    #[test]
+    fn test_issue_49_asterisk_in_inline_code() {
+        // Test for issue #49 - Asterisk within backticks identified as for emphasis
+        let rule = MD037NoSpaceInEmphasis;
+
+        // Test case from issue #49
+        let content = "The `__mul__` method is needed for left-hand multiplication (`vector * 3`) and `__rmul__` is needed for right-hand multiplication (`3 * vector`).";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag asterisks inside inline code as emphasis (issue #49). Got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_issue_28_inline_code_in_emphasis() {
+        // Test for issue #28 - MD037 should not flag inline code inside emphasis as spaces
+        let rule = MD037NoSpaceInEmphasis;
+
+        // Test case 1: inline code with single backticks inside bold emphasis
+        let content = "Though, we often call this an **inline `if`** because it looks sort of like an `if`-`else` statement all in *one line* of code.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Should not flag inline code inside emphasis as spaces (issue #28). Got: {result:?}"
+        );
+
+        // Test case 2: multiple inline code snippets inside emphasis
+        let content2 = "The **`foo` and `bar`** methods are important.";
+        let ctx2 = LintContext::new(content2, crate::config::MarkdownFlavor::Standard);
+        let result2 = rule.check(&ctx2).unwrap();
+        assert!(
+            result2.is_empty(),
+            "Should not flag multiple inline code snippets inside emphasis. Got: {result2:?}"
+        );
+
+        // Test case 3: inline code with underscores for emphasis
+        let content3 = "This is __inline `code`__ with underscores.";
+        let ctx3 = LintContext::new(content3, crate::config::MarkdownFlavor::Standard);
+        let result3 = rule.check(&ctx3).unwrap();
+        assert!(
+            result3.is_empty(),
+            "Should not flag inline code with underscore emphasis. Got: {result3:?}"
+        );
+
+        // Test case 4: single asterisk emphasis with inline code
+        let content4 = "This is *inline `test`* with single asterisks.";
+        let ctx4 = LintContext::new(content4, crate::config::MarkdownFlavor::Standard);
+        let result4 = rule.check(&ctx4).unwrap();
+        assert!(
+            result4.is_empty(),
+            "Should not flag inline code with single asterisk emphasis. Got: {result4:?}"
+        );
+
+        // Test case 5: actual spaces that should be flagged
+        let content5 = "This has * real spaces * that should be flagged.";
+        let ctx5 = LintContext::new(content5, crate::config::MarkdownFlavor::Standard);
+        let result5 = rule.check(&ctx5).unwrap();
+        assert!(!result5.is_empty(), "Should still flag actual spaces in emphasis");
+        assert!(result5[0].message.contains("Spaces inside emphasis markers"));
+    }
 }
