@@ -369,7 +369,7 @@ mod tests {
     fn test_valid_links() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[link](url) and [another link](url) here";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -378,7 +378,7 @@ mod tests {
     fn test_spaces_both_ends() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[ link ](url) and [ another link ](url) here";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -389,7 +389,7 @@ mod tests {
     fn test_space_at_start() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[ link](url) and [ another link](url) here";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -400,7 +400,7 @@ mod tests {
     fn test_space_at_end() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[link ](url) and [another link ](url) here";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -414,7 +414,7 @@ mod tests {
 [ link ](url)
 ```
 [ link ](url)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         let fixed = rule.fix(&ctx).unwrap();
@@ -431,7 +431,7 @@ mod tests {
     fn test_multiple_links() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[ link ](url) and [ another ](url) in one line";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -442,7 +442,7 @@ mod tests {
     fn test_link_with_internal_spaces() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[this is link](url) and [ this is also link ](url)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
         let fixed = rule.fix(&ctx).unwrap();
@@ -453,7 +453,7 @@ mod tests {
     fn test_link_with_punctuation() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[ link! ](url) and [ link? ](url) here";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2);
         let fixed = rule.fix(&ctx).unwrap();
@@ -464,7 +464,7 @@ mod tests {
     fn test_parity_only_whitespace_and_newlines_minimal() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[   \n  ](url) and [\t\n\t](url)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // markdownlint removes all whitespace, resulting in empty link text
         assert_eq!(fixed, "[](url) and [](url)");
@@ -474,7 +474,7 @@ mod tests {
     fn test_parity_internal_newlines_minimal() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[link\ntext](url) and [ another\nlink ](url)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // markdownlint trims only leading/trailing whitespace, preserves internal newlines
         assert_eq!(fixed, "[link\ntext](url) and [another\nlink](url)");
@@ -484,7 +484,7 @@ mod tests {
     fn test_parity_escaped_brackets_minimal() {
         let rule = MD039NoSpaceInLinks::new();
         let content = "[link\\]](url) and [link\\[]](url)";
-        let ctx = crate::lint_context::LintContext::new(content);
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // markdownlint does not trim or remove escapes, so output should be unchanged
         assert_eq!(fixed, "[link\\]](url) and [link\\[]](url)");
@@ -520,7 +520,7 @@ mod tests {
             content.lines().count()
         );
 
-        let ctx = crate::lint_context::LintContext::new(&content);
+        let ctx = crate::lint_context::LintContext::new(&content, crate::config::MarkdownFlavor::Standard);
 
         // Warm up
         let _ = rule.check(&ctx).unwrap();
