@@ -35,15 +35,15 @@ impl Rule for MD040FencedCodeLanguage {
             let trimmed = line.trim();
 
             // Update disabled state incrementally
-            if let Some(rules) = crate::rule::parse_disable_comment(trimmed) {
-                if rules.is_empty() || rules.contains(&self.name()) {
-                    is_disabled = true;
-                }
+            if let Some(rules) = crate::rule::parse_disable_comment(trimmed)
+                && (rules.is_empty() || rules.contains(&self.name()))
+            {
+                is_disabled = true;
             }
-            if let Some(rules) = crate::rule::parse_enable_comment(trimmed) {
-                if rules.is_empty() || rules.contains(&self.name()) {
-                    is_disabled = false;
-                }
+            if let Some(rules) = crate::rule::parse_enable_comment(trimmed)
+                && (rules.is_empty() || rules.contains(&self.name()))
+            {
+                is_disabled = false;
             }
 
             // Skip processing if rule is disabled
@@ -92,7 +92,14 @@ impl Rule for MD040FencedCodeLanguage {
                     // We're outside a code block, this opens one
                     // Check if language is specified
                     let after_fence = trimmed[fence_marker.len()..].trim();
-                    if after_fence.is_empty() {
+
+                    // Check if it has MkDocs title attribute but no language
+                    // Pattern: ``` title="Title" (missing language)
+                    // Valid: ```python title="Title" or ```py title="Title"
+                    let has_title_only =
+                        ctx.flavor == crate::config::MarkdownFlavor::MkDocs && after_fence.starts_with("title=");
+
+                    if after_fence.is_empty() || has_title_only {
                         // Calculate precise character range for the entire fence line that needs a language
                         let (start_line, start_col, end_line, end_col) = calculate_line_range(i + 1, line);
 
@@ -178,9 +185,9 @@ impl Rule for MD040FencedCodeLanguage {
                         || after_indent.starts_with("* ")
                         || after_indent.starts_with("+ ")
                         || (after_indent.len() > 2
-                            && after_indent.chars().nth(0).unwrap_or(' ').is_ascii_digit()
-                            && after_indent.chars().nth(1).unwrap_or(' ') == '.'
-                            && after_indent.chars().nth(2).unwrap_or(' ') == ' ')
+                            && after_indent.as_bytes().first().is_some_and(|&b| b.is_ascii_digit())
+                            && after_indent.as_bytes().get(1) == Some(&b'.')
+                            && after_indent.as_bytes().get(2) == Some(&b' '))
                     {
                         return true;
                     }
@@ -201,15 +208,15 @@ impl Rule for MD040FencedCodeLanguage {
             let trimmed = line.trim();
 
             // Update disabled state incrementally
-            if let Some(rules) = crate::rule::parse_disable_comment(trimmed) {
-                if rules.is_empty() || rules.contains(&self.name()) {
-                    is_disabled = true;
-                }
+            if let Some(rules) = crate::rule::parse_disable_comment(trimmed)
+                && (rules.is_empty() || rules.contains(&self.name()))
+            {
+                is_disabled = true;
             }
-            if let Some(rules) = crate::rule::parse_enable_comment(trimmed) {
-                if rules.is_empty() || rules.contains(&self.name()) {
-                    is_disabled = false;
-                }
+            if let Some(rules) = crate::rule::parse_enable_comment(trimmed)
+                && (rules.is_empty() || rules.contains(&self.name()))
+            {
+                is_disabled = false;
             }
 
             // Skip processing if rule is disabled, preserve the line as-is
@@ -278,18 +285,33 @@ impl Rule for MD040FencedCodeLanguage {
 
                     // Add 'text' as default language for opening fence if no language specified
                     let after_fence = trimmed[fence_marker.len()..].trim();
-                    if after_fence.is_empty() {
+
+                    // Check if it has MkDocs title attribute but no language
+                    let has_title_only =
+                        ctx.flavor == crate::config::MarkdownFlavor::MkDocs && after_fence.starts_with("title=");
+
+                    if after_fence.is_empty() || has_title_only {
                         // Decide whether to preserve indentation based on context
                         let should_preserve_indent = is_in_nested_context(i);
 
                         if should_preserve_indent {
                             // Preserve indentation for nested contexts
                             original_indent = line_indent;
-                            result.push_str(&format!("{original_indent}{fence_marker}text\n"));
+                            if has_title_only {
+                                // Insert language before title attribute
+                                result.push_str(&format!("{original_indent}{fence_marker}text {after_fence}\n"));
+                            } else {
+                                result.push_str(&format!("{original_indent}{fence_marker}text\n"));
+                            }
                         } else {
                             // Remove indentation for standalone code blocks
                             original_indent = String::new();
-                            result.push_str(&format!("{fence_marker}text\n"));
+                            if has_title_only {
+                                // Insert language before title attribute
+                                result.push_str(&format!("{fence_marker}text {after_fence}\n"));
+                            } else {
+                                result.push_str(&format!("{fence_marker}text\n"));
+                            }
                         }
                         fence_needs_language = true;
                     } else {
@@ -364,13 +386,13 @@ mod tests {
 
     fn run_check(content: &str) -> LintResult {
         let rule = MD040FencedCodeLanguage;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.check(&ctx)
     }
 
     fn run_fix(content: &str) -> Result<String, LintError> {
         let rule = MD040FencedCodeLanguage;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         rule.fix(&ctx)
     }
 
@@ -410,7 +432,7 @@ print("Hello, world!")
         // Test with spaces after the fence
         let content = r#"# Test
 
-```   
+```
 print("Hello, world!")
 ```
 "#;
@@ -564,7 +586,7 @@ console.log("test");
     ```javascript
     console.log("deeply nested");
     ```
-  
+
   - Another nested
     ```
     no language
@@ -794,19 +816,19 @@ console.log(`template string with backticks`);
         let rule = MD040FencedCodeLanguage;
 
         // Document without code fences should skip
-        let ctx = LintContext::new("# Just a header\n\nSome text");
+        let ctx = LintContext::new("# Just a header\n\nSome text", crate::config::MarkdownFlavor::Standard);
         assert!(rule.should_skip(&ctx));
 
         // Document with backtick fences should not skip
-        let ctx = LintContext::new("```\ncode\n```");
+        let ctx = LintContext::new("```\ncode\n```", crate::config::MarkdownFlavor::Standard);
         assert!(!rule.should_skip(&ctx));
 
         // Document with tilde fences should not skip
-        let ctx = LintContext::new("~~~\ncode\n~~~");
+        let ctx = LintContext::new("~~~\ncode\n~~~", crate::config::MarkdownFlavor::Standard);
         assert!(!rule.should_skip(&ctx));
 
         // Empty document should skip
-        let ctx = LintContext::new("");
+        let ctx = LintContext::new("", crate::config::MarkdownFlavor::Standard);
         assert!(rule.should_skip(&ctx));
     }
 }
