@@ -3,6 +3,15 @@ use crate::utils::regex_cache::{BOLD_ASTERISK_REGEX, BOLD_UNDERSCORE_REGEX};
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rules::strong_style::StrongStyle;
+use lazy_static::lazy_static;
+use regex::Regex;
+
+lazy_static! {
+    // Reference definition pattern - matches [ref]: url "title"
+    static ref REF_DEF_REGEX: Regex = Regex::new(
+        r#"(?m)^[ ]{0,3}\[([^\]]+)\]:\s*([^\s]+)(?:\s+(?:"([^"]*)"|'([^']*)'))?$"#
+    ).unwrap();
+}
 
 mod md050_config;
 use md050_config::MD050Config;
@@ -28,13 +37,101 @@ impl MD050StrongStyle {
         Self { config }
     }
 
+    /// Check if a byte position is within a link (inline links, reference links, or reference definitions)
+    fn is_in_link(&self, ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
+        // Check inline and reference links
+        for link in &ctx.links {
+            if link.byte_offset <= byte_pos && byte_pos < link.byte_end {
+                return true;
+            }
+        }
+
+        // Check images (which use similar syntax)
+        for image in &ctx.images {
+            if image.byte_offset <= byte_pos && byte_pos < image.byte_end {
+                return true;
+            }
+        }
+
+        // Check reference definitions [ref]: url "title" using regex pattern
+        for m in REF_DEF_REGEX.find_iter(ctx.content) {
+            if m.start() <= byte_pos && byte_pos < m.end() {
+                return true;
+            }
+        }
+
+        false
+    }
+
+    /// Check if a byte position is within an HTML tag
+    fn is_in_html_tag(&self, ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
+        // Check HTML tags
+        for html_tag in ctx.html_tags().iter() {
+            // Only consider the position inside the tag if it's between the < and >
+            // Don't include positions after the tag ends
+            if html_tag.byte_offset <= byte_pos && byte_pos < html_tag.byte_end {
+                return true;
+            }
+        }
+        false
+    }
+
+    /// Check if a byte position is within HTML code tags (<code>...</code>)
+    /// This is separate from is_in_html_tag because we need to check the content between tags
+    fn is_in_html_code_content(&self, ctx: &crate::lint_context::LintContext, byte_pos: usize) -> bool {
+        let html_tags = ctx.html_tags();
+        let mut open_code_pos: Option<usize> = None;
+
+        for tag in html_tags.iter() {
+            // If we've passed our position, check if we're in an open code block
+            if tag.byte_offset > byte_pos {
+                return open_code_pos.is_some();
+            }
+
+            if tag.tag_name == "code" {
+                if tag.is_self_closing {
+                    // Self-closing tags don't create a code context
+                    continue;
+                } else if !tag.is_closing {
+                    // Opening <code> tag
+                    open_code_pos = Some(tag.byte_end);
+                } else if tag.is_closing && open_code_pos.is_some() {
+                    // Closing </code> tag
+                    if let Some(open_pos) = open_code_pos
+                        && byte_pos >= open_pos
+                        && byte_pos < tag.byte_offset
+                    {
+                        // We're between <code> and </code>
+                        return true;
+                    }
+                    open_code_pos = None;
+                }
+            }
+        }
+
+        // Check if we're still in an unclosed code tag
+        open_code_pos.is_some() && byte_pos >= open_code_pos.unwrap()
+    }
+
     fn detect_style(&self, ctx: &crate::lint_context::LintContext) -> Option<StrongStyle> {
         let content = ctx.content;
 
-        // Find the first occurrence of either style that's not in a code block
+        // Find the first occurrence of either style that's not in a code block, link, HTML tag, or front matter
         let mut first_asterisk = None;
         for m in BOLD_ASTERISK_REGEX.find_iter(content) {
-            if !ctx.is_in_code_block_or_span(m.start()) {
+            // Skip matches in front matter
+            let (line_num, _) = ctx.offset_to_line_col(m.start());
+            let in_front_matter = ctx
+                .line_info(line_num)
+                .map(|info| info.in_front_matter)
+                .unwrap_or(false);
+
+            if !in_front_matter
+                && !ctx.is_in_code_block_or_span(m.start())
+                && !self.is_in_link(ctx, m.start())
+                && !self.is_in_html_tag(ctx, m.start())
+                && !self.is_in_html_code_content(ctx, m.start())
+            {
                 first_asterisk = Some(m);
                 break;
             }
@@ -42,7 +139,19 @@ impl MD050StrongStyle {
 
         let mut first_underscore = None;
         for m in BOLD_UNDERSCORE_REGEX.find_iter(content) {
-            if !ctx.is_in_code_block_or_span(m.start()) {
+            // Skip matches in front matter
+            let (line_num, _) = ctx.offset_to_line_col(m.start());
+            let in_front_matter = ctx
+                .line_info(line_num)
+                .map(|info| info.in_front_matter)
+                .unwrap_or(false);
+
+            if !in_front_matter
+                && !ctx.is_in_code_block_or_span(m.start())
+                && !self.is_in_link(ctx, m.start())
+                && !self.is_in_html_tag(ctx, m.start())
+                && !self.is_in_html_code_content(ctx, m.start())
+            {
                 first_underscore = Some(m);
                 break;
             }
@@ -70,10 +179,11 @@ impl MD050StrongStyle {
 
         let mut backslash_count = 0;
         let mut i = pos;
+        let bytes = text.as_bytes();
         while i > 0 {
             i -= 1;
-            let c = text.chars().nth(i).unwrap_or(' ');
-            if c != '\\' {
+            // Safe for ASCII backslash
+            if i < bytes.len() && bytes[i] != b'\\' {
                 break;
             }
             backslash_count += 1;
@@ -116,12 +226,37 @@ impl Rule for MD050StrongStyle {
         let mut byte_pos = 0;
 
         for (line_num, line) in content.lines().enumerate() {
+            // Skip if this line is in front matter
+            if let Some(line_info) = ctx.line_info(line_num + 1)
+                && line_info.in_front_matter
+            {
+                byte_pos += line.len() + 1; // +1 for newline
+                continue;
+            }
+
             for m in strong_regex.find_iter(line) {
                 // Calculate the byte position of this match in the document
                 let match_byte_pos = byte_pos + m.start();
 
-                // Skip if this strong text is inside a code block or code span
-                if ctx.is_in_code_block_or_span(match_byte_pos) {
+                // Skip if this strong text is inside a code block, code span, link, or HTML code content
+                if ctx.is_in_code_block_or_span(match_byte_pos)
+                    || self.is_in_link(ctx, match_byte_pos)
+                    || self.is_in_html_code_content(ctx, match_byte_pos)
+                {
+                    continue;
+                }
+
+                // Only skip HTML tag content if we're actually inside the tag (between < and >)
+                // not just on the same line as a tag
+                let mut inside_html_tag = false;
+                for tag in ctx.html_tags().iter() {
+                    // The emphasis must start after < and before >
+                    if tag.byte_offset < match_byte_pos && match_byte_pos < tag.byte_end - 1 {
+                        inside_html_tag = true;
+                        break;
+                    }
+                }
+                if inside_html_tag {
                     continue;
                 }
 
@@ -194,7 +329,19 @@ impl Rule for MD050StrongStyle {
 
         let matches: Vec<(usize, usize)> = strong_regex
             .find_iter(content)
-            .filter(|m| !ctx.is_in_code_block_or_span(m.start()))
+            .filter(|m| {
+                // Skip matches in front matter
+                let (line_num, _) = ctx.offset_to_line_col(m.start());
+                if let Some(line_info) = ctx.line_info(line_num)
+                    && line_info.in_front_matter
+                {
+                    return false;
+                }
+                !ctx.is_in_code_block_or_span(m.start())
+                    && !self.is_in_link(ctx, m.start())
+                    && !self.is_in_html_tag(ctx, m.start())
+                    && !self.is_in_html_code_content(ctx, m.start())
+            })
             .filter(|m| !self.is_escaped(content, m.start()))
             .map(|m| (m.start(), m.end()))
             .collect();
@@ -254,7 +401,7 @@ mod tests {
     fn test_asterisk_style_with_asterisks() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "This is **strong text** here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -264,7 +411,7 @@ mod tests {
     fn test_asterisk_style_with_underscores() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "This is __strong text__ here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -281,7 +428,7 @@ mod tests {
     fn test_underscore_style_with_underscores() {
         let rule = MD050StrongStyle::new(StrongStyle::Underscore);
         let content = "This is __strong text__ here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -291,7 +438,7 @@ mod tests {
     fn test_underscore_style_with_asterisks() {
         let rule = MD050StrongStyle::new(StrongStyle::Underscore);
         let content = "This is **strong text** here.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -306,7 +453,7 @@ mod tests {
     fn test_consistent_style_first_asterisk() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
         let content = "First **strong** then __also strong__.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // First strong is **, so __ should be flagged
@@ -322,7 +469,7 @@ mod tests {
     fn test_consistent_style_first_underscore() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
         let content = "First __strong__ then **also strong**.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // First strong is __, so ** should be flagged
@@ -337,7 +484,7 @@ mod tests {
     #[test]
     fn test_detect_style_asterisk() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
-        let ctx = LintContext::new("This has **strong** text.");
+        let ctx = LintContext::new("This has **strong** text.", crate::config::MarkdownFlavor::Standard);
         let style = rule.detect_style(&ctx);
 
         assert_eq!(style, Some(StrongStyle::Asterisk));
@@ -346,7 +493,7 @@ mod tests {
     #[test]
     fn test_detect_style_underscore() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
-        let ctx = LintContext::new("This has __strong__ text.");
+        let ctx = LintContext::new("This has __strong__ text.", crate::config::MarkdownFlavor::Standard);
         let style = rule.detect_style(&ctx);
 
         assert_eq!(style, Some(StrongStyle::Underscore));
@@ -355,7 +502,7 @@ mod tests {
     #[test]
     fn test_detect_style_none() {
         let rule = MD050StrongStyle::new(StrongStyle::Consistent);
-        let ctx = LintContext::new("No strong text here.");
+        let ctx = LintContext::new("No strong text here.", crate::config::MarkdownFlavor::Standard);
         let style = rule.detect_style(&ctx);
 
         assert_eq!(style, None);
@@ -365,7 +512,7 @@ mod tests {
     fn test_strong_in_code_block() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "```\n__strong__ in code\n```\n__strong__ outside";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only the strong outside code block should be flagged
@@ -377,7 +524,7 @@ mod tests {
     fn test_strong_in_inline_code() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "Text with `__strong__` in code and __strong__ outside.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only the strong outside inline code should be flagged
@@ -388,7 +535,7 @@ mod tests {
     fn test_escaped_strong() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "This is \\__not strong\\__ but __this is__.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Only the unescaped strong should be flagged
@@ -401,7 +548,7 @@ mod tests {
     fn test_fix_asterisks_to_underscores() {
         let rule = MD050StrongStyle::new(StrongStyle::Underscore);
         let content = "This is **strong** text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, "This is __strong__ text.");
@@ -411,7 +558,7 @@ mod tests {
     fn test_fix_underscores_to_asterisks() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "This is __strong__ text.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, "This is **strong** text.");
@@ -421,7 +568,7 @@ mod tests {
     fn test_fix_multiple_strong() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "First __strong__ and second __also strong__.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, "First **strong** and second **also strong**.");
@@ -431,7 +578,7 @@ mod tests {
     fn test_fix_preserves_code_blocks() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "```\n__strong__ in code\n```\n__strong__ outside";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
         assert_eq!(fixed, "```\n__strong__ in code\n```\n**strong** outside");
@@ -441,7 +588,7 @@ mod tests {
     fn test_multiline_content() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "Line 1 with __strong__\nLine 2 with __another__\nLine 3 normal";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 2);
@@ -453,7 +600,7 @@ mod tests {
     fn test_nested_emphasis() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "This has __strong with *emphasis* inside__.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -463,7 +610,7 @@ mod tests {
     fn test_empty_content() {
         let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
         let content = "";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -475,4 +622,86 @@ mod tests {
         let (name, _config) = rule.default_config_section().unwrap();
         assert_eq!(name, "MD050");
     }
+
+    #[test]
+    fn test_strong_in_links_not_flagged() {
+        let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
+        let content = r#"Instead of assigning to `self.value`, we're relying on the [`__dict__`][__dict__] in our object to hold that value instead.
+
+Hint:
+
+- [An article on something](https://blog.yuo.be/2018/08/16/__init_subclass__-a-simpler-way-to-implement-class-registries-in-python/ "Some details on using `__init_subclass__`")
+
+
+[__dict__]: https://www.pythonmorsels.com/where-are-attributes-stored/"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // None of the __ patterns in links should be flagged
+        assert_eq!(result.len(), 0);
+    }
+
+    #[test]
+    fn test_strong_in_links_vs_outside_links() {
+        let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
+        let content = r#"We're doing this because generator functions return a generator object which [is an iterator][generators are iterators] and **we need `__iter__` to return an [iterator][]**.
+
+Instead of assigning to `self.value`, we're relying on the [`__dict__`][__dict__] in our object to hold that value instead.
+
+This is __real strong text__ that should be flagged.
+
+[__dict__]: https://www.pythonmorsels.com/where-are-attributes-stored/"#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Only the real strong text should be flagged, not the __ in links
+        assert_eq!(result.len(), 1);
+        assert!(
+            result[0]
+                .message
+                .contains("Strong emphasis should use ** instead of __")
+        );
+        // The flagged text should be "real strong text"
+        assert!(result[0].line > 4); // Should be on the line with "real strong text"
+    }
+
+    #[test]
+    fn test_front_matter_not_flagged() {
+        let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
+        let content = "---\ntitle: What's __init__.py?\nother: __value__\n---\n\nThis __should be flagged__.";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Only the strong text outside front matter should be flagged
+        assert_eq!(result.len(), 1);
+        assert_eq!(result[0].line, 6);
+        assert!(
+            result[0]
+                .message
+                .contains("Strong emphasis should use ** instead of __")
+        );
+    }
+
+    #[test]
+    fn test_html_tags_not_flagged() {
+        let rule = MD050StrongStyle::new(StrongStyle::Asterisk);
+        let content = r#"# Test
+
+This has HTML with underscores:
+
+<iframe src="https://example.com/__init__/__repr__"> </iframe>
+
+This __should be flagged__ as inconsistent."#;
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Only the strong text outside HTML tags should be flagged
+        assert_eq!(result.len(), 1);
+        assert_eq!(result[0].line, 7);
+        assert!(
+            result[0]
+                .message
+                .contains("Strong emphasis should use ** instead of __")
+        );
+    }
 }
