@@ -1,4 +1,4 @@
-use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
+use crate::rule::{LintError, LintResult, LintWarning, Rule, Severity};
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::DocumentStructure;
 use crate::utils::range_utils::calculate_line_range;
@@ -15,9 +15,11 @@ lazy_static! {
     // Image reference format: ![text][reference]
     // REMOVED: static ref IMAGE_REFERENCE_REGEX: FancyRegex = FancyRegex::new(r"!\[([^\]]*)\]\s*\[([^\]]*)\]").unwrap();
 
-    // Shortcut reference links: [reference] - must not be followed by a colon to avoid matching definitions
+    // Shortcut reference links: [reference] - must not be followed by another bracket
+    // Allow references followed by punctuation like colon, period, comma (e.g., "[reference]:", "[reference].")
+    // Don't exclude references followed by ": " in the middle of a line (only at start of line)
     static ref SHORTCUT_REFERENCE_REGEX: FancyRegex =
-        FancyRegex::new(r"(?<!\!)\[([^\]]+)\](?!\s*[\[(:])").unwrap();
+        FancyRegex::new(r"(?<!\!)\[([^\]]+)\](?!\[)").unwrap();
 
     // REMOVED: Empty reference links: [text][] or ![text][]
     // static ref EMPTY_LINK_REFERENCE_REGEX: Regex = Regex::new(r"\[([^\]]+)\]\s*\[\s*\]").unwrap();
@@ -30,9 +32,9 @@ lazy_static! {
     // Multi-line reference definition continuation pattern
     static ref CONTINUATION_REGEX: Regex = Regex::new(r"^\s+(.+)$").unwrap();
 
-    // Code block regex
-    static ref CODE_BLOCK_START_REGEX: Regex = Regex::new(r"^```").unwrap();
-    static ref CODE_BLOCK_END_REGEX: Regex = Regex::new(r"^```\s*$").unwrap();
+    // Code block regex - support indented code blocks for MkDocs tabs
+    static ref CODE_BLOCK_START_REGEX: Regex = Regex::new(r"^(\s*)(`{3,}|~{3,})").unwrap();
+    static ref CODE_BLOCK_END_REGEX: Regex = Regex::new(r"^(\s*)(`{3,}|~{3,})\s*$").unwrap();
 }
 
 /// Configuration for MD053 rule
@@ -109,9 +111,8 @@ impl RuleConfig for MD053Config {
 ///
 /// ## Fix Behavior
 ///
-/// When fixing issues, this rule removes unused reference definitions while preserving
-/// the document's structure, including handling proper blank line formatting around
-/// the removed definitions.
+/// This rule does not provide automatic fixes. Unused references must be manually reviewed
+/// and removed, as they may be intentionally kept for future use or as templates.
 #[derive(Clone)]
 pub struct MD053LinkImageReferenceDefinitions {
     config: MD053Config,
@@ -130,6 +131,45 @@ impl MD053LinkImageReferenceDefinitions {
         Self { config }
     }
 
+    /// Check if a pattern is likely NOT a markdown reference
+    /// Returns true if this pattern should be skipped
+    fn is_likely_not_reference(text: &str) -> bool {
+        // Don't skip pure numeric patterns - they could be footnote references like [1]
+        // Only skip numeric ranges like [1:3], [0:10], etc.
+        if text.contains(':') && text.chars().all(|c| c.is_ascii_digit() || c == ':') {
+            return true;
+        }
+
+        // Skip glob/wildcard patterns like [*], [...], [**]
+        if text == "*" || text == "..." || text == "**" {
+            return true;
+        }
+
+        // Skip patterns that are just punctuation or operators
+        if text.chars().all(|c| !c.is_alphanumeric() && c != ' ') {
+            return true;
+        }
+
+        // Skip very short non-word patterns (likely operators or syntax)
+        // But allow single digits (could be footnotes) and single letters
+        if text.len() <= 2 && !text.chars().all(|c| c.is_alphanumeric()) {
+            return true;
+        }
+
+        // Skip descriptive patterns with colon like [default: the project root]
+        // But allow simple numeric ranges which are handled above
+        if text.contains(':') && text.contains(' ') {
+            return true;
+        }
+
+        // Skip alert/admonition patterns like [!WARN], [!NOTE], etc.
+        if text.starts_with('!') {
+            return true;
+        }
+
+        false
+    }
+
     /// Unescape a reference string by removing backslashes before special characters.
     ///
     /// This allows matching references like `[example\-reference]` with definitions like
@@ -187,12 +227,11 @@ impl MD053LinkImageReferenceDefinitions {
                     let normalized_id = Self::unescape_reference(ref_id).to_lowercase();
 
                     // Update the end line for this definition
-                    if let Some(ranges) = definitions.get_mut(&normalized_id) {
-                        if let Some(last_range) = ranges.last_mut() {
-                            if last_range.0 == def_start {
-                                last_range.1 = i;
-                            }
-                        }
+                    if let Some(ranges) = definitions.get_mut(&normalized_id)
+                        && let Some(last_range) = ranges.last_mut()
+                        && last_range.0 == def_start
+                    {
+                        last_range.1 = i;
                     }
                 }
             }
@@ -214,24 +253,24 @@ impl MD053LinkImageReferenceDefinitions {
 
         // 1. Add usages from cached reference links in LintContext
         for link in &ctx.links {
-            if link.is_reference {
-                if let Some(ref_id) = &link.reference_id {
-                    // Ensure the link itself is not inside a code block line
-                    if !doc_structure.is_in_code_block(link.line) {
-                        usages.insert(Self::unescape_reference(ref_id).to_lowercase());
-                    }
+            if link.is_reference
+                && let Some(ref_id) = &link.reference_id
+            {
+                // Ensure the link itself is not inside a code block line
+                if !doc_structure.is_in_code_block(link.line) {
+                    usages.insert(Self::unescape_reference(ref_id).to_lowercase());
                 }
             }
         }
 
         // 2. Add usages from cached reference images in LintContext
         for image in &ctx.images {
-            if image.is_reference {
-                if let Some(ref_id) = &image.reference_id {
-                    // Ensure the image itself is not inside a code block line
-                    if !doc_structure.is_in_code_block(image.line) {
-                        usages.insert(Self::unescape_reference(ref_id).to_lowercase());
-                    }
+            if image.is_reference
+                && let Some(ref_id) = &image.reference_id
+            {
+                // Ensure the image itself is not inside a code block line
+                if !doc_structure.is_in_code_block(image.line) {
+                    usages.insert(Self::unescape_reference(ref_id).to_lowercase());
                 }
             }
         }
@@ -249,18 +288,27 @@ impl MD053LinkImageReferenceDefinitions {
                 continue;
             }
 
+            // Skip lines that are reference definitions (start with [ref]: at beginning)
+            if REFERENCE_DEFINITION_REGEX.is_match(&line_info.content) {
+                continue;
+            }
+
             // Find potential shortcut references
             for caps in SHORTCUT_REFERENCE_REGEX.captures_iter(&line_info.content).flatten() {
-                if let Some(full_match) = caps.get(0) {
-                    if let Some(ref_id_match) = caps.get(1) {
-                        // Check if the match is within a code span
-                        let match_byte_offset = line_info.byte_offset + full_match.start();
-                        let in_code_span = code_spans
-                            .iter()
-                            .any(|span| match_byte_offset >= span.byte_offset && match_byte_offset < span.byte_end);
+                if let Some(full_match) = caps.get(0)
+                    && let Some(ref_id_match) = caps.get(1)
+                {
+                    // Check if the match is within a code span
+                    let match_byte_offset = line_info.byte_offset + full_match.start();
+                    let in_code_span = code_spans
+                        .iter()
+                        .any(|span| match_byte_offset >= span.byte_offset && match_byte_offset < span.byte_end);
 
-                        if !in_code_span {
-                            let ref_id = ref_id_match.as_str().trim();
+                    if !in_code_span {
+                        let ref_id = ref_id_match.as_str().trim();
+
+                        // Skip patterns that are likely not markdown references
+                        if !Self::is_likely_not_reference(ref_id) {
                             let normalized_id = Self::unescape_reference(ref_id).to_lowercase();
                             usages.insert(normalized_id);
                         }
@@ -307,37 +355,6 @@ impl MD053LinkImageReferenceDefinitions {
             .iter()
             .any(|ignored| ignored.eq_ignore_ascii_case(definition_id))
     }
-
-    /// Clean up multiple consecutive blank lines that might be created after removing references
-    fn clean_up_blank_lines(&self, content: &str) -> String {
-        let lines: Vec<&str> = content.lines().collect();
-        let mut result_lines = Vec::new();
-        let mut consecutive_blanks = 0;
-
-        for line in lines {
-            if line.trim().is_empty() {
-                consecutive_blanks += 1;
-                if consecutive_blanks <= 1 {
-                    // Allow up to 1 consecutive blank line
-                    result_lines.push(line);
-                }
-            } else {
-                consecutive_blanks = 0;
-                result_lines.push(line);
-            }
-        }
-
-        // Remove leading and trailing blank lines
-        while !result_lines.is_empty() && result_lines[0].trim().is_empty() {
-            result_lines.remove(0);
-        }
-        while !result_lines.is_empty() && result_lines[result_lines.len() - 1].trim().is_empty() {
-            result_lines.pop();
-        }
-
-        // Don't add trailing newlines - let the content determine its own ending
-        result_lines.join("\n")
-    }
 }
 
 impl Default for MD053LinkImageReferenceDefinitions {
@@ -355,7 +372,7 @@ impl Rule for MD053LinkImageReferenceDefinitions {
         "Link and image reference definitions should be needed"
     }
 
-    /// Check the content for unused link/image reference definitions.
+    /// Check the content for unused and duplicate link/image reference definitions.
     ///
     /// This implementation uses caching for improved performance on large documents.
     fn check(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
@@ -372,6 +389,75 @@ impl Rule for MD053LinkImageReferenceDefinitions {
 
         let mut warnings = Vec::new();
 
+        // Check for duplicate definitions (case-insensitive per CommonMark spec)
+        let mut seen_definitions: HashMap<String, (String, usize)> = HashMap::new(); // lowercase -> (original, first_line)
+
+        for (definition_id, ranges) in &definitions {
+            // Skip ignored definitions for duplicate checking
+            if self.is_ignored_definition(definition_id) {
+                continue;
+            }
+
+            if ranges.len() > 1 {
+                // Multiple definitions with exact same ID (already lowercase)
+                for (i, &(start_line, _)) in ranges.iter().enumerate() {
+                    if i > 0 {
+                        // Skip the first occurrence, report all others
+                        let line_num = start_line + 1;
+                        let line_content = ctx.lines.get(start_line).map(|l| l.content.as_str()).unwrap_or("");
+                        let (start_line_1idx, start_col, end_line, end_col) =
+                            calculate_line_range(line_num, line_content);
+
+                        warnings.push(LintWarning {
+                            rule_name: Some(self.name()),
+                            line: start_line_1idx,
+                            column: start_col,
+                            end_line,
+                            end_column: end_col,
+                            message: format!("Duplicate link or image reference definition: [{definition_id}]"),
+                            severity: Severity::Warning,
+                            fix: None,
+                        });
+                    }
+                }
+            }
+
+            // Track for case-variant duplicates
+            if let Some(&(start_line, _)) = ranges.first() {
+                // Find the original case version from the line
+                if let Some(line_info) = ctx.lines.get(start_line)
+                    && let Some(caps) = REFERENCE_DEFINITION_REGEX.captures(&line_info.content)
+                {
+                    let original_id = caps.get(1).unwrap().as_str().trim();
+                    let lower_id = original_id.to_lowercase();
+
+                    if let Some((first_original, first_line)) = seen_definitions.get(&lower_id) {
+                        // Found a case-variant duplicate
+                        if first_original != original_id {
+                            let line_num = start_line + 1;
+                            let line_content = &line_info.content;
+                            let (start_line_1idx, start_col, end_line, end_col) =
+                                calculate_line_range(line_num, line_content);
+
+                            warnings.push(LintWarning {
+                                    rule_name: Some(self.name()),
+                                    line: start_line_1idx,
+                                    column: start_col,
+                                    end_line,
+                                    end_column: end_col,
+                                    message: format!("Duplicate link or image reference definition: [{}] (conflicts with [{}] on line {})",
+                                                   original_id, first_original, first_line + 1),
+                                    severity: Severity::Warning,
+                                    fix: None,
+                                });
+                        }
+                    } else {
+                        seen_definitions.insert(lower_id, (original_id.to_string(), start_line));
+                    }
+                }
+            }
+        }
+
         // Create warnings for unused references
         for (definition, start, _end) in unused_refs {
             let line_num = start + 1; // 1-indexed line numbers
@@ -388,76 +474,17 @@ impl Rule for MD053LinkImageReferenceDefinitions {
                 end_column: end_col,
                 message: format!("Unused link/image reference: [{definition}]"),
                 severity: Severity::Warning,
-                fix: Some(Fix {
-                    // Remove the entire line including the newline
-                    range: {
-                        let line_start = ctx.line_to_byte_offset(line_num).unwrap_or(0);
-                        let line_end = if line_num < ctx.lines.len() {
-                            ctx.line_to_byte_offset(line_num + 1).unwrap_or(content.len())
-                        } else {
-                            content.len()
-                        };
-                        line_start..line_end
-                    },
-                    replacement: String::new(), // Remove the line
-                }),
+                fix: None, // MD053 is warning-only, no automatic fixes
             });
         }
 
         Ok(warnings)
     }
 
-    /// Fix the content by removing unused link/image reference definitions.
-    ///
-    /// This implementation uses caching for improved performance on large documents.
-    /// It optimizes the process by:
-    /// 1. Using cached definitions to avoid re-parsing the document
-    /// 2. Preserving document structure while removing unused references
-    /// 3. Cleaning up any formatting issues created by the removals
+    /// MD053 does not provide automatic fixes
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
-        let content = ctx.content;
-        let doc_structure = DocumentStructure::new(content);
-
-        // Find definitions and usages using DocumentStructure
-        let definitions = self.find_definitions(ctx, &doc_structure);
-        let usages = self.find_usages(&doc_structure, ctx);
-
-        // Get unused references by comparing definitions and usages
-        let unused_refs = self.get_unused_references(&definitions, &usages);
-
-        // If no unused references, return original content
-        if unused_refs.is_empty() {
-            return Ok(content.to_string());
-        }
-
-        // Collect all line ranges to remove (sort by start line descending)
-        let mut lines_to_remove: Vec<(usize, usize)> =
-            unused_refs.iter().map(|(_, start, end)| (*start, *end)).collect();
-        lines_to_remove.sort_by(|a, b| b.0.cmp(&a.0)); // Sort descending by start line
-
-        // Remove lines from end to beginning to preserve line numbers
-        let lines: Vec<&str> = ctx.lines.iter().map(|l| l.content.as_str()).collect();
-        let mut result_lines: Vec<&str> = lines.clone();
-
-        for (start_line, end_line) in lines_to_remove {
-            // Remove lines from start_line to end_line (inclusive)
-            if start_line < result_lines.len() && end_line < result_lines.len() {
-                result_lines.drain(start_line..=end_line);
-            }
-        }
-
-        // Join the remaining lines
-        let mut result = result_lines.join("\n");
-
-        // Preserve original ending (with or without newline)
-        if content.ends_with('\n') && !result.ends_with('\n') {
-            result.push('\n');
-        }
-
-        // Clean up multiple consecutive blank lines that might have been created
-        let cleaned = self.clean_up_blank_lines(&result);
-
-        Ok(cleaned)
+        // This rule is warning-only, no automatic fixes provided
+        Ok(ctx.content.to_string())
     }
 
     /// Check if this rule should be skipped for performance
@@ -503,7 +530,7 @@ mod tests {
     fn test_used_reference_link() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[text][ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -513,7 +540,7 @@ mod tests {
     fn test_unused_reference_definition() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -524,7 +551,7 @@ mod tests {
     fn test_used_reference_image() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "![alt][img]\n\n[img]: image.jpg";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -534,7 +561,7 @@ mod tests {
     fn test_case_insensitive_matching() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[Text][REF]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -544,7 +571,7 @@ mod tests {
     fn test_shortcut_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -554,7 +581,7 @@ mod tests {
     fn test_collapsed_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref][]\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -564,7 +591,7 @@ mod tests {
     fn test_multiple_unused_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused1]: url1\n[unused2]: url2\n[unused3]: url3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 3);
@@ -580,7 +607,7 @@ mod tests {
     fn test_mixed_used_and_unused() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[used]\n\n[used]: url1\n[unused]: url2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1);
@@ -591,7 +618,7 @@ mod tests {
     fn test_multiline_definition() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]: https://example.com\n  \"Title on next line\"";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 1); // Still unused
@@ -601,7 +628,7 @@ mod tests {
     fn test_reference_in_code_block() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "```\n[ref]\n```\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Reference used only in code block is still considered unused
@@ -612,7 +639,7 @@ mod tests {
     fn test_reference_in_inline_code() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "`[ref]`\n\n[ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Reference in inline code is not a usage
@@ -623,7 +650,7 @@ mod tests {
     fn test_escaped_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[example\\-ref]\n\n[example-ref]: https://example.com";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should match despite escaping
@@ -634,50 +661,51 @@ mod tests {
     fn test_duplicate_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref]: url1\n[ref]: url2\n\n[ref]";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
-        // Both definitions are used (Markdown uses the first one)
-        assert_eq!(result.len(), 0);
+        // Should flag the duplicate definition even though it's used (matches markdownlint)
+        assert_eq!(result.len(), 1);
     }
 
     #[test]
-    fn test_fix_removes_unused_definition() {
+    fn test_fix_returns_original() {
+        // MD053 is warning-only, fix should return original content
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[used]\n\n[used]: url1\n[unused]: url2\n\nMore content";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
-        assert!(fixed.contains("[used]: url1"));
-        assert!(!fixed.contains("[unused]: url2"));
-        assert!(fixed.contains("More content"));
+        assert_eq!(fixed, content);
     }
 
     #[test]
-    fn test_fix_preserves_blank_lines() {
+    fn test_fix_preserves_content() {
+        // MD053 is warning-only, fix should preserve all content
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "Content\n\n[unused]: url\n\nMore content";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
-        assert_eq!(fixed, "Content\n\nMore content");
+        assert_eq!(fixed, content);
     }
 
     #[test]
-    fn test_fix_multiple_consecutive_definitions() {
+    fn test_fix_does_not_remove() {
+        // MD053 is warning-only, fix should not remove anything
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[unused1]: url1\n[unused2]: url2\n[unused3]: url3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
-        assert_eq!(fixed, "");
+        assert_eq!(fixed, content);
     }
 
     #[test]
     fn test_special_characters_in_reference() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref-with_special.chars]\n\n[ref-with_special.chars]: url";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         assert_eq!(result.len(), 0);
@@ -687,7 +715,7 @@ mod tests {
     fn test_find_definitions() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[ref1]: url1\n[ref2]: url2\nSome text\n[ref3]: url3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let doc = DocumentStructure::new(content);
         let defs = rule.find_definitions(&ctx, &doc);
 
@@ -701,7 +729,7 @@ mod tests {
     fn test_find_usages() {
         let rule = MD053LinkImageReferenceDefinitions::new();
         let content = "[text][ref1] and [ref2] and ![img][ref3]";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let doc = DocumentStructure::new(content);
         let usages = rule.find_usages(&doc, &ctx);
 
@@ -710,17 +738,6 @@ mod tests {
         assert!(usages.contains("ref3"));
     }
 
-    #[test]
-    fn test_clean_up_blank_lines() {
-        let rule = MD053LinkImageReferenceDefinitions::new();
-
-        // Test multiple consecutive blank lines
-        assert_eq!(rule.clean_up_blank_lines("text\n\n\n\nmore text"), "text\n\nmore text");
-
-        // Test leading/trailing blank lines
-        assert_eq!(rule.clean_up_blank_lines("\n\ntext\n\n"), "text");
-    }
-
     #[test]
     fn test_ignored_definitions_config() {
         // Test with ignored definitions
@@ -730,7 +747,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[todo]: https://example.com/todo\n[draft]: https://example.com/draft\n[unused]: https://example.com/unused";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag "unused", not "todo" or "draft"
@@ -749,7 +766,7 @@ mod tests {
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[todo]: https://example.com/todo\n[unused]: https://example.com/unused";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // Should only flag "unused", not "todo" (matches "TODO" case-insensitively)
@@ -777,20 +794,98 @@ mod tests {
     }
 
     #[test]
-    fn test_fix_respects_ignored_definitions() {
-        // Test that fix respects ignored definitions
+    fn test_fix_with_ignored_definitions() {
+        // MD053 is warning-only, fix should not remove anything even with ignored definitions
         let config = MD053Config {
             ignored_definitions: vec!["template".to_string()],
         };
         let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
 
         let content = "[template]: https://example.com/template\n[unused]: https://example.com/unused\n\nSome content.";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
 
-        // Should keep template but remove unused
-        assert!(fixed.contains("[template]: https://example.com/template"));
-        assert!(!fixed.contains("[unused]: https://example.com/unused"));
-        assert!(fixed.contains("Some content."));
+        // Should keep everything since MD053 doesn't fix
+        assert_eq!(fixed, content);
+    }
+
+    #[test]
+    fn test_duplicate_definitions_exact_case() {
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content = "[ref]: url1\n[ref]: url2\n[ref]: url3";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should have 2 duplicate warnings (for the 2nd and 3rd definitions)
+        // Plus 1 unused warning
+        let duplicate_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Duplicate")).collect();
+        assert_eq!(duplicate_warnings.len(), 2);
+        assert_eq!(duplicate_warnings[0].line, 2);
+        assert_eq!(duplicate_warnings[1].line, 3);
+    }
+
+    #[test]
+    fn test_duplicate_definitions_case_variants() {
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content =
+            "[method resolution order]: url1\n[Method Resolution Order]: url2\n[METHOD RESOLUTION ORDER]: url3";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should have 2 duplicate warnings (for the 2nd and 3rd definitions)
+        // Note: These are treated as exact duplicates since they normalize to the same ID
+        let duplicate_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Duplicate")).collect();
+        assert_eq!(duplicate_warnings.len(), 2);
+
+        // The exact duplicate messages don't include "conflicts with"
+        // Only case-variant duplicates with different normalized forms would
+        assert_eq!(duplicate_warnings[0].line, 2);
+        assert_eq!(duplicate_warnings[1].line, 3);
+    }
+
+    #[test]
+    fn test_duplicate_and_unused() {
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content = "[used]\n[used]: url1\n[used]: url2\n[unused]: url3";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should have 1 duplicate warning and 1 unused warning
+        let duplicate_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Duplicate")).collect();
+        let unused_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Unused")).collect();
+
+        assert_eq!(duplicate_warnings.len(), 1);
+        assert_eq!(unused_warnings.len(), 1);
+        assert_eq!(duplicate_warnings[0].line, 3); // Second [used] definition
+        assert_eq!(unused_warnings[0].line, 4); // [unused] definition
+    }
+
+    #[test]
+    fn test_duplicate_with_usage() {
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        // Even if used, duplicates should still be reported
+        let content = "[ref]\n\n[ref]: url1\n[ref]: url2";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should have 1 duplicate warning (no unused since it's referenced)
+        let duplicate_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Duplicate")).collect();
+        let unused_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Unused")).collect();
+
+        assert_eq!(duplicate_warnings.len(), 1);
+        assert_eq!(unused_warnings.len(), 0);
+        assert_eq!(duplicate_warnings[0].line, 4);
+    }
+
+    #[test]
+    fn test_no_duplicate_different_ids() {
+        let rule = MD053LinkImageReferenceDefinitions::new();
+        let content = "[ref1]: url1\n[ref2]: url2\n[ref3]: url3";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should have no duplicate warnings, only unused warnings
+        let duplicate_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("Duplicate")).collect();
+        assert_eq!(duplicate_warnings.len(), 0);
     }
 }
