@@ -2,6 +2,7 @@
 //! Shared utilities for rumdl, including document structure analysis, code block handling, regex helpers, and string extensions.
 //! Provides reusable traits and functions for rule implementations and core linter logic.
 
+pub mod anchor_styles;
 pub mod ast_utils;
 pub mod code_block_utils;
 pub mod document_structure;
@@ -9,9 +10,22 @@ pub mod early_returns;
 pub mod element_cache;
 pub mod emphasis_utils;
 pub mod fix_utils;
+pub mod header_id_utils;
+pub mod kramdown_utils;
+pub mod line_ending;
 pub mod markdown_elements;
+pub mod mkdocs_admonitions;
+pub mod mkdocs_common;
+pub mod mkdocs_critic;
+pub mod mkdocs_footnotes;
+pub mod mkdocs_patterns;
+pub mod mkdocs_snippets;
+pub mod mkdocs_tabs;
+pub mod mkdocs_test_utils;
+pub mod mkdocstrings_refs;
 pub mod range_utils;
 pub mod regex_cache;
+pub mod skip_context;
 pub mod string_interner;
 pub mod table_utils;
 pub mod text_reflow;
@@ -19,15 +33,11 @@ pub mod text_reflow;
 pub use ast_utils::AstCache;
 pub use code_block_utils::CodeBlockUtils;
 pub use document_structure::DocumentStructure;
+pub use line_ending::{
+    LineEnding, detect_line_ending, detect_line_ending_enum, ensure_consistent_line_endings, get_line_ending_str,
+    normalize_line_ending,
+};
 pub use markdown_elements::{ElementQuality, ElementType, MarkdownElement, MarkdownElements};
-
-/// Detect the predominant line ending style in content
-pub fn detect_line_ending(content: &str) -> &'static str {
-    let crlf_count = content.matches("\r\n").count();
-    let lf_count = content.matches('\n').count() - crlf_count;
-
-    if crlf_count > lf_count { "\r\n" } else { "\n" }
-}
 pub use range_utils::LineIndex;
 
 /// Trait for string-related extensions
