@@ -41,20 +41,41 @@ impl TableUtils {
 
         // Check if it looks like a table row by having reasonable content between pipes
         let mut valid_parts = 0;
+        let mut total_non_empty_parts = 0;
+
         for part in &parts {
             let part_trimmed = part.trim();
             // Skip empty parts (from leading/trailing pipes)
             if part_trimmed.is_empty() {
                 continue;
             }
-            // Count parts that look like table cells (not too long, reasonable content)
-            if part_trimmed.len() <= 100 && !part_trimmed.contains('\n') {
+            total_non_empty_parts += 1;
+
+            // Count parts that look like table cells (reasonable content, no newlines)
+            if !part_trimmed.contains('\n') {
                 valid_parts += 1;
             }
         }
 
-        // Must have at least 2 valid cell-like parts
-        valid_parts >= 2
+        // All non-empty parts must be valid (no newlines) for the row to be valid
+        if total_non_empty_parts == 0 {
+            return false;
+        }
+
+        if valid_parts != total_non_empty_parts {
+            // Some cells contain newlines, not a valid table row
+            return false;
+        }
+
+        // GFM allows single-column tables, so >= 1 valid part is enough
+        // when the line has proper table formatting (pipes)
+        if trimmed.starts_with('|') && trimmed.ends_with('|') {
+            // Properly formatted table row with pipes on both ends
+            valid_parts >= 1
+        } else {
+            // For rows without proper pipe formatting, require at least 2 cells
+            valid_parts >= 2
+        }
     }
 
     /// Check if a line is a table delimiter row (e.g., |---|---|)
@@ -162,9 +183,12 @@ impl TableUtils {
             return 0;
         }
 
+        // Users shouldn't have to escape pipes in regex patterns, etc.
+        let masked_row = Self::mask_pipes_in_inline_code(trimmed);
+
         // Handle case with leading/trailing pipes
         let mut cell_count = 0;
-        let parts: Vec<&str> = trimmed.split('|').collect();
+        let parts: Vec<&str> = masked_row.split('|').collect();
 
         for (i, part) in parts.iter().enumerate() {
             // Skip first part if it's empty and there's a leading pipe
@@ -183,6 +207,74 @@ impl TableUtils {
         cell_count
     }
 
+    /// Mask pipes inside inline code blocks with a placeholder character
+    fn mask_pipes_in_inline_code(text: &str) -> String {
+        let mut result = String::new();
+        let chars: Vec<char> = text.chars().collect();
+        let mut i = 0;
+
+        while i < chars.len() {
+            if chars[i] == '`' {
+                // Count consecutive backticks at start
+                let start = i;
+                let mut backtick_count = 0;
+                while i < chars.len() && chars[i] == '`' {
+                    backtick_count += 1;
+                    i += 1;
+                }
+
+                // Look for matching closing backticks
+                let mut found_closing = false;
+                let mut j = i;
+
+                while j < chars.len() {
+                    if chars[j] == '`' {
+                        // Count potential closing backticks
+                        let close_start = j;
+                        let mut close_count = 0;
+                        while j < chars.len() && chars[j] == '`' {
+                            close_count += 1;
+                            j += 1;
+                        }
+
+                        if close_count == backtick_count {
+                            // Found matching closing backticks
+                            found_closing = true;
+
+                            // Valid inline code - add with pipes masked
+                            result.extend(chars[start..i].iter());
+
+                            for &ch in chars.iter().take(close_start).skip(i) {
+                                if ch == '|' {
+                                    result.push('_'); // Mask pipe with underscore
+                                } else {
+                                    result.push(ch);
+                                }
+                            }
+
+                            result.extend(chars[close_start..j].iter());
+                            i = j;
+                            break;
+                        }
+                        // If not matching, continue searching (j is already past these backticks)
+                    } else {
+                        j += 1;
+                    }
+                }
+
+                if !found_closing {
+                    // No matching closing found, treat as regular text
+                    result.extend(chars[start..i].iter());
+                }
+            } else {
+                result.push(chars[i]);
+                i += 1;
+            }
+        }
+
+        result
+    }
+
     /// Determine the pipe style of a table row
     pub fn determine_pipe_style(line: &str) -> Option<&'static str> {
         let trimmed = line.trim();
@@ -213,7 +305,7 @@ mod tests {
         assert!(TableUtils::is_potential_table_row("| Header 1 | Header 2 |"));
         assert!(TableUtils::is_potential_table_row("| Cell 1 | Cell 2 |"));
         assert!(TableUtils::is_potential_table_row("Cell 1 | Cell 2"));
-        assert!(!TableUtils::is_potential_table_row("| Cell |")); // Only 1 cell, not a table
+        assert!(TableUtils::is_potential_table_row("| Cell |")); // Single-column tables are valid in GFM
 
         // Multiple cells
         assert!(TableUtils::is_potential_table_row("| A | B | C | D | E |"));
@@ -238,9 +330,9 @@ mod tests {
         assert!(!TableUtils::is_potential_table_row("Just one |"));
         assert!(!TableUtils::is_potential_table_row("| Just one"));
 
-        // Very long cells (>100 chars)
-        let long_cell = "a".repeat(101);
-        assert!(!TableUtils::is_potential_table_row(&format!("| {long_cell} | b |")));
+        // Very long cells are valid in tables (no length limit for cell content)
+        let long_cell = "a".repeat(150);
+        assert!(TableUtils::is_potential_table_row(&format!("| {long_cell} | b |")));
 
         // Cells with newlines
         assert!(!TableUtils::is_potential_table_row("| Cell with\nnewline | Other |"));
@@ -318,6 +410,34 @@ mod tests {
         assert_eq!(TableUtils::count_cells("|   A   |   B   |"), 2);
     }
 
+    #[test]
+    fn test_count_cells_with_inline_code() {
+        // Test the user's actual example from Issue #34
+        assert_eq!(TableUtils::count_cells("| Challenge | Solution |"), 2);
+        assert_eq!(
+            TableUtils::count_cells("| Hour:minute:second formats | `^([0-1]?\\d|2[0-3]):[0-5]\\d:[0-5]\\d$` |"),
+            2
+        );
+
+        // Test basic inline code with pipes
+        assert_eq!(TableUtils::count_cells("| Command | `echo | grep` |"), 2);
+        assert_eq!(TableUtils::count_cells("| A | `code | with | pipes` | B |"), 3);
+
+        // Test escaped pipes (correct GFM)
+        assert_eq!(TableUtils::count_cells("| Command | `echo \\| grep` |"), 2);
+
+        // Test multiple inline code blocks
+        assert_eq!(TableUtils::count_cells("| `code | one` | `code | two` |"), 2);
+
+        // Test edge cases
+        assert_eq!(TableUtils::count_cells("| Empty inline | `` | cell |"), 3);
+        assert_eq!(TableUtils::count_cells("| `single|pipe` |"), 1);
+
+        // Test that basic table structure still works
+        assert_eq!(TableUtils::count_cells("| A | B | C |"), 3);
+        assert_eq!(TableUtils::count_cells("| One | Two |"), 2);
+    }
+
     #[test]
     fn test_determine_pipe_style() {
         // All pipe styles
@@ -366,7 +486,7 @@ mod tests {
 | Cell 1    | Cell 2    |
 | Cell 3    | Cell 4    |";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1);
@@ -393,7 +513,7 @@ More text
 |----------|-------|
 | Data 2   | Data  |";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 2);
@@ -420,7 +540,7 @@ More text
 
 Next paragraph";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1);
@@ -443,7 +563,7 @@ Next paragraph";
 |------|-------|
 | Data | Here  |";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1); // Only the table outside code block
@@ -460,7 +580,7 @@ No tables here
 - List item with | pipe
 * Another list item";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 0);
@@ -476,7 +596,7 @@ But no delimiter row
 |---------|-------|
 | Data    | Here  |";
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
 
         let tables = TableUtils::find_table_blocks(content, &ctx);
         assert_eq!(tables.len(), 1); // Only the proper table
@@ -502,9 +622,13 @@ But no delimiter row
         assert!(!TableUtils::is_delimiter_row("|"));
         assert_eq!(TableUtils::count_cells("|"), 0); // Need at least 2 parts
 
-        // Test very long lines
-        let long_line = format!("| {} |", "a".repeat(200));
-        assert!(!TableUtils::is_potential_table_row(&long_line)); // Too long
+        // Test very long lines are valid table rows (no length limit)
+        // Test both single-column and multi-column long lines
+        let long_single = format!("| {} |", "a".repeat(200));
+        assert!(TableUtils::is_potential_table_row(&long_single)); // Single-column table with long content
+
+        let long_multi = format!("| {} | {} |", "a".repeat(200), "b".repeat(200));
+        assert!(TableUtils::is_potential_table_row(&long_multi)); // Multi-column table with long content
 
         // Test unicode
         assert!(TableUtils::is_potential_table_row("| 你好 | 世界 |"));
