@@ -28,12 +28,22 @@ impl VsCodeExtension {
 
     /// Check if a command exists and works
     fn command_exists(cmd: &str) -> bool {
-        Command::new("which").arg(cmd).output().is_ok()
-            && Command::new(cmd)
-                .arg("--version")
-                .output()
-                .map(|output| output.status.success())
-                .unwrap_or(false)
+        // First, try to run the command directly with --version
+        // This is more reliable than using which/where
+        if let Ok(output) = Command::new(cmd).arg("--version").output()
+            && output.status.success()
+        {
+            return true;
+        }
+
+        // Fallback: use platform-appropriate command lookup
+        let lookup_cmd = if cfg!(windows) { "where" } else { "which" };
+
+        Command::new(lookup_cmd)
+            .arg(cmd)
+            .output()
+            .map(|output| output.status.success())
+            .unwrap_or(false)
     }
 
     fn find_code_command() -> Result<String, String> {
@@ -496,6 +506,21 @@ mod tests {
         // The actual behavior depends on the system
     }
 
+    #[test]
+    fn test_command_exists_cross_platform() {
+        // Test that the function handles the direct execution approach
+        // This tests our fix for Windows PATH detection
+
+        // Test with a command that definitely doesn't exist
+        assert!(!VsCodeExtension::command_exists("definitely-nonexistent-command-12345"));
+
+        // Test that it tries the direct approach first
+        // We can't test positive cases reliably in CI, but we can verify
+        // the function doesn't panic and follows expected logic
+        let _result = VsCodeExtension::command_exists("code");
+        // Result depends on system, but should not panic
+    }
+
     #[test]
     fn test_find_all_editors() {
         // This test verifies the function runs without panicking
@@ -518,10 +543,16 @@ mod tests {
     fn test_current_editor_from_env() {
         // Save current TERM_PROGRAM if it exists
         let original_term = std::env::var("TERM_PROGRAM").ok();
+        let original_editor = std::env::var("EDITOR").ok();
+        let original_visual = std::env::var("VISUAL").ok();
 
         unsafe {
-            // Test with no TERM_PROGRAM set
+            // Clear all environment variables that could affect the test
             std::env::remove_var("TERM_PROGRAM");
+            std::env::remove_var("EDITOR");
+            std::env::remove_var("VISUAL");
+
+            // Test with no TERM_PROGRAM set
             assert!(VsCodeExtension::current_editor_from_env().is_none());
 
             // Test with VS Code TERM_PROGRAM (but command might not exist)
@@ -548,12 +579,18 @@ mod tests {
             let _mixed_case_result = VsCodeExtension::current_editor_from_env();
             // Result should be same as lowercase version
 
-            // Restore original TERM_PROGRAM
+            // Restore original environment variables
             if let Some(term) = original_term {
                 std::env::set_var("TERM_PROGRAM", term);
             } else {
                 std::env::remove_var("TERM_PROGRAM");
             }
+            if let Some(editor) = original_editor {
+                std::env::set_var("EDITOR", editor);
+            }
+            if let Some(visual) = original_visual {
+                std::env::set_var("VISUAL", visual);
+            }
         }
     }
 
