@@ -1,6 +1,6 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::{
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::{
     MD036NoEmphasisAsHeading, MD037NoSpaceInEmphasis, MD049EmphasisStyle, MD050StrongStyle,
     emphasis_style::EmphasisStyle, strong_style::StrongStyle,
 };
@@ -23,16 +23,13 @@ __مرحبا بالعالم__
 
 _Привет мир_";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 4, "Should detect all Unicode emphasis as headings");
 
-    // Verify fixes work with Unicode
+    // MD036 no longer provides automatic fixes
     let fixed = rule.fix(&ctx).unwrap();
-    assert!(fixed.contains("## Hello 👋 World"));
-    assert!(fixed.contains("# 你好世界"));
-    assert!(fixed.contains("## مرحبا بالعالم"));
-    assert!(fixed.contains("# Привет мир"));
+    assert_eq!(fixed, content, "Content should remain unchanged");
 }
 
 #[test]
@@ -54,7 +51,7 @@ fn test_md036_punctuation_edge_cases() {
 
 *No punctuation*";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // With punctuation allowed, these should be ignored except the last one
     assert_eq!(result.len(), 1, "Should only detect emphasis without punctuation");
@@ -81,7 +78,7 @@ fn test_md036_toc_labels() {
 
 **Custom Heading**";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // With empty punctuation, MD036 detects more emphasis as headings
     // TOC labels are only ignored when punctuation is configured
@@ -119,7 +116,7 @@ fn test_md036_complex_contexts() {
 |-----------|----------|
 | **Cell**  | *Data*   |";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Only the first line should be detected
     assert_eq!(result.len(), 1, "Should only detect standalone emphasis");
@@ -148,7 +145,7 @@ Not **standalone** emphasis
 
 **Multiple** **emphasis** **markers**";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Empty emphasis and mixed should not be detected
     // Only line 9 with triple asterisks might be detected
@@ -173,7 +170,7 @@ __ Привет __
 
 *\u{00A0}Non-breaking space\u{00A0}*";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Should detect ASCII spaces, not sure about Unicode spaces
     assert!(result.len() >= 4, "Should detect spaces in emphasis");
@@ -209,7 +206,7 @@ spaces
 
 ** nested * space * **";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.len() >= 5, "Should detect various spacing issues");
 }
@@ -226,7 +223,7 @@ Mix of * good* and *bad * emphasis * markers *
 
 ** Bold ** with _ italic _ and __more bold __";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Should detect all instances with spaces
     assert!(result.len() >= 8, "Should detect all spacing issues");
@@ -266,7 +263,7 @@ fn test_md037_edge_patterns() {
 * code block *
 ```";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Empty emphasis and escaped content might behave differently
     assert!(!result.is_empty(), "Should detect some spacing issues");
@@ -290,7 +287,7 @@ This is *inline 你好* emphasis
 
 Another _inline مرحبا_ style";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Asterisk styles should be flagged
     assert_eq!(result.len(), 3, "Should detect asterisk emphasis");
@@ -318,7 +315,7 @@ _This underscore should be flagged_
 
 _Another incorrect_";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Underscore styles should be flagged
     assert_eq!(result.len(), 2, "Should detect inconsistent underscore emphasis");
@@ -331,7 +328,7 @@ _First style is underscore_
 
 _Correct style_";
 
-    let ctx2 = LintContext::new(content2);
+    let ctx2 = LintContext::new(content2, rumdl_lib::config::MarkdownFlavor::Standard);
     let result2 = rule.check(&ctx2).unwrap();
     assert_eq!(result2.len(), 1, "Should detect inconsistent asterisk emphasis");
 }
@@ -352,7 +349,7 @@ Email: user_name@company_domain.com
 
 But _this emphasis_ should be fixed";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Should only detect emphasis, not URLs");
 
@@ -381,10 +378,15 @@ Link with [*emphasis*](url) inside
 
 Image with ![*alt text*](img.png) emphasis";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
-    // Should detect asterisk emphasis
-    assert!(result.len() >= 3, "Should detect nested emphasis");
+    // With link filtering, should detect only standalone asterisk emphasis (not in links/images)
+    // Only the asterisk emphasis outside of links should be flagged
+    assert_eq!(
+        result.len(),
+        2,
+        "Should detect 2 standalone asterisk emphasis (not in links)"
+    );
 }
 
 #[test]
@@ -405,7 +407,7 @@ This is **inline 你好** emphasis
 
 Another __inline مرحبا__ style";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Double asterisk styles should be flagged
     assert_eq!(result.len(), 3, "Should detect double asterisk emphasis");
@@ -433,7 +435,7 @@ __This underscore should be flagged__
 
 __Another incorrect__";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Double underscore styles should be flagged
     assert_eq!(result.len(), 2, "Should detect inconsistent strong emphasis");
@@ -455,7 +457,7 @@ __Real strong emphasis__
 
 __Should be \\*\\*fixed\\*\\* to asterisks__";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     // Should only detect real emphasis
     assert_eq!(result.len(), 2, "Should only detect unescaped emphasis");
@@ -478,7 +480,7 @@ This has * spaces * and *wrong style*
 
 More __bold __ with spaces";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Each rule should detect its issues
     let result036 = md036.check(&ctx).unwrap();
@@ -518,10 +520,14 @@ fn test_emphasis_in_special_constructs() {
 
 <div>HTML with * spaces *</div>";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = md037.check(&ctx).unwrap();
-    // Should detect spaces in all contexts except HTML
-    assert!(result.len() >= 5, "Should detect spaces in various contexts");
+    // Should detect spaces in blockquotes, lists, and HTML tags (not in links, tables, or comments)
+    assert_eq!(
+        result.len(),
+        3,
+        "Should detect spaces in blockquotes, lists, and HTML tags"
+    );
 }
 
 #[test]
@@ -532,13 +538,13 @@ fn test_emphasis_performance_edge_cases() {
     let long_text = "a".repeat(500);
     let content = format!("* {long_text} *\n\n** {long_text} **");
 
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = md037.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Should handle long lines");
 
     // Test with many emphasis markers
     let many_emphasis = "* text * ".repeat(50);
-    let ctx2 = LintContext::new(&many_emphasis);
+    let ctx2 = LintContext::new(&many_emphasis, rumdl_lib::config::MarkdownFlavor::Standard);
     let result2 = md037.check(&ctx2).unwrap();
     assert_eq!(result2.len(), 50, "Should handle many emphasis markers");
 }
@@ -552,9 +558,9 @@ fn test_emphasis_line_endings() {
     let content_crlf = "* spaces *\r\n* more *";
     let content_no_ending = "* spaces *";
 
-    let ctx_lf = LintContext::new(content_lf);
-    let ctx_crlf = LintContext::new(content_crlf);
-    let ctx_no_ending = LintContext::new(content_no_ending);
+    let ctx_lf = LintContext::new(content_lf, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx_crlf = LintContext::new(content_crlf, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx_no_ending = LintContext::new(content_no_ending, rumdl_lib::config::MarkdownFlavor::Standard);
 
     assert_eq!(md037.check(&ctx_lf).unwrap().len(), 2);
     assert_eq!(md037.check(&ctx_crlf).unwrap().len(), 2);
@@ -580,7 +586,7 @@ _b_
 
 _ _";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result036 = md036.check(&ctx).unwrap();
     let result037 = md037.check(&ctx).unwrap();
 
@@ -605,7 +611,7 @@ fn test_emphasis_html_entities() {
 
 *&lt;tag&gt;*";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = md037.check(&ctx).unwrap();
     // Should detect spaces around entities
     assert_eq!(result.len(), 3, "Should detect spaces around HTML entities");
@@ -626,7 +632,7 @@ emphasis: *also not*
 
 Normal content";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = md036.check(&ctx).unwrap();
     // Should only detect emphasis outside front matter
     assert_eq!(result.len(), 1, "Should ignore front matter");
@@ -652,7 +658,7 @@ __bold___italic_
 
 ___both___";
 
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result049 = md049.check(&ctx).unwrap();
     let result050 = md050.check(&ctx).unwrap();
 
