@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD007ULIndent;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD007ULIndent;
 
 #[test]
 fn test_valid_list_indent() {
     let rule = MD007ULIndent::default();
     let content = "* Item 1\n  * Item 2\n    * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -19,7 +19,7 @@ fn test_valid_list_indent() {
 fn test_invalid_list_indent() {
     let rule = MD007ULIndent::default();
     let content = "* Item 1\n   * Item 2\n      * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("test_invalid_list_indent: result.len() = {}", result.len());
     for (i, w) in result.iter().enumerate() {
@@ -36,7 +36,7 @@ fn test_invalid_list_indent() {
 fn test_mixed_indentation() {
     let rule = MD007ULIndent::default();
     let content = "* Item 1\n  * Item 2\n   * Item 3\n  * Item 4";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     println!("test_mixed_indentation: result.len() = {}", result.len());
     for (i, w) in result.iter().enumerate() {
@@ -51,7 +51,7 @@ fn test_mixed_indentation() {
 fn test_fix_indentation() {
     let rule = MD007ULIndent::default();
     let content = "* Item 1\n   * Item 2\n      * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.fix(&ctx).unwrap();
     let expected = "* Item 1\n  * Item 2\n     * Item 3";
     assert_eq!(result, expected);
@@ -67,7 +67,7 @@ repos:
     hooks:
     -   id: rumdl-check
 ```"#;
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -79,7 +79,7 @@ repos:
 fn test_blockquoted_list_indent() {
     let rule = MD007ULIndent::default();
     let content = "> * Item 1\n>   * Item 2\n>     * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -91,7 +91,7 @@ fn test_blockquoted_list_indent() {
 fn test_blockquoted_list_invalid_indent() {
     let rule = MD007ULIndent::default();
     let content = "> * Item 1\n>    * Item 2\n>       * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -106,7 +106,7 @@ fn test_blockquoted_list_invalid_indent() {
 fn test_nested_blockquote_list_indent() {
     let rule = MD007ULIndent::default();
     let content = "> > * Item 1\n> >   * Item 2\n> >     * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -118,7 +118,7 @@ fn test_nested_blockquote_list_indent() {
 fn test_blockquote_list_with_code_block() {
     let rule = MD007ULIndent::default();
     let content = "> * Item 1\n>   * Item 2\n>   ```\n>   code\n>   ```\n>   * Item 3";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -128,9 +128,9 @@ fn test_blockquote_list_with_code_block() {
 
 // Additional comprehensive tests for MD007
 mod comprehensive_tests {
-    use rumdl::lint_context::LintContext;
-    use rumdl::rule::Rule;
-    use rumdl::rules::MD007ULIndent;
+    use rumdl_lib::lint_context::LintContext;
+    use rumdl_lib::rule::Rule;
+    use rumdl_lib::rules::MD007ULIndent;
 
     // 1. Properly indented lists (should pass)
     #[test]
@@ -147,7 +147,7 @@ mod comprehensive_tests {
         ];
 
         for content in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert!(
                 result.is_empty(),
@@ -171,7 +171,7 @@ mod comprehensive_tests {
         ];
 
         for (content, expected_warnings, line) in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert_eq!(
                 result.len(),
@@ -196,7 +196,7 @@ mod comprehensive_tests {
         ];
 
         for (content, expected_warnings, line) in test_cases {
-            let ctx = LintContext::new(content);
+            let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
             let result = rule.check(&ctx).unwrap();
             assert_eq!(
                 result.len(),
@@ -222,7 +222,7 @@ mod comprehensive_tests {
   * Level 2 again
 * Level 1 again"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Expected no warnings for correctly nested list");
     }
@@ -238,7 +238,7 @@ mod comprehensive_tests {
   * Level 2 (correct)
       * Level 3 (wrong)"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Expected 2 warnings for incorrectly nested list");
 
@@ -258,7 +258,7 @@ mod comprehensive_tests {
     fn test_custom_indent_2_spaces() {
         let rule = MD007ULIndent::new(2); // Default
         let content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -269,7 +269,7 @@ mod comprehensive_tests {
         let rule = MD007ULIndent::new(3);
 
         let content = "* Item 1\n   * Item 2\n      * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With dynamic alignment, Item 2 should align with Item 1's text (2 spaces)
         // and Item 3 should align with Item 2's text (4 spaces), not fixed increments
@@ -278,13 +278,13 @@ mod comprehensive_tests {
         // Test that dynamic alignment works correctly
         // Item 3 should align with Item 2's text content (4 spaces)
         let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(correct_content);
+        let ctx = LintContext::new(correct_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test that 2-space indentation fails with 3-space config
         let wrong_content = "* Item 1\n  * Item 2";
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With dynamic alignment, this is actually correct (2 spaces aligns with text)
         assert_eq!(result.len(), 0);
@@ -299,7 +299,7 @@ mod comprehensive_tests {
         // Test dynamic alignment behavior (default start_indented=false)
         let rule = MD007ULIndent::new(4);
         let content = "* Item 1\n    * Item 2\n        * Item 3";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // With dynamic alignment, should expect 2 spaces and 6 spaces, not 4 and 8
         assert!(!result.is_empty()); // Should have warnings due to alignment
@@ -307,13 +307,13 @@ mod comprehensive_tests {
         // Test correct dynamic alignment
         // Item 3 should align with Item 2's text content (4 spaces)
         let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(correct_content);
+        let ctx = LintContext::new(correct_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
         // Test fix with wrong indentation - dynamic alignment means no fix needed
         let wrong_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         // Dynamic alignment makes this correct
         assert!(result.is_empty());
@@ -328,7 +328,7 @@ mod comprehensive_tests {
 
         // Single tab
         let content = "* Item 1\n\t* Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Tab indentation should trigger warning");
 
@@ -338,7 +338,7 @@ mod comprehensive_tests {
 
         // Multiple tabs
         let content_multi = "* Item 1\n\t* Item 2\n\t\t* Item 3";
-        let ctx = LintContext::new(content_multi);
+        let ctx = LintContext::new(content_multi, rumdl_lib::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2 at correct position
         assert_eq!(fixed, "* Item 1\n  * Item 2\n   * Item 3");
@@ -346,7 +346,7 @@ mod comprehensive_tests {
         // Mixed tabs and spaces
         // TODO: Tab handling may not be consistent
         let content_mixed = "* Item 1\n \t* Item 2\n\t * Item 3";
-        let ctx = LintContext::new(content_mixed);
+        let ctx = LintContext::new(content_mixed, rumdl_lib::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2 at correct position
         assert_eq!(fixed, "* Item 1\n  * Item 2\n    * Item 3");
@@ -366,7 +366,7 @@ mod comprehensive_tests {
   1. Ordered sub-item
   * Unordered sub-item"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "Only unordered list indentation should be checked");
         assert_eq!(result[0].line, 2, "Error should be on line 2");
@@ -389,12 +389,12 @@ mod comprehensive_tests {
 
         // Single level blockquote with proper indentation
         let content1 = "> * Item 1\n>   * Item 2\n>     * Item 3";
-        let ctx = LintContext::new(content1);
+        let ctx = LintContext::new(content1, rumdl_lib::config::MarkdownFlavor::Standard);
         assert!(rule.check(&ctx).unwrap().is_empty());
 
         // Single level blockquote with improper indentation
         let content2 = "> * Item 1\n>    * Item 2\n>      * Item 3";
-        let ctx = LintContext::new(content2);
+        let ctx = LintContext::new(content2, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2); // Detects the indentation issues
 
@@ -404,12 +404,12 @@ mod comprehensive_tests {
 
         // Nested blockquotes
         let content3 = "> > * Item 1\n> >   * Item 2\n> >     * Item 3";
-        let ctx = LintContext::new(content3);
+        let ctx = LintContext::new(content3, rumdl_lib::config::MarkdownFlavor::Standard);
         assert!(rule.check(&ctx).unwrap().is_empty());
 
         // Mixed blockquote and regular lists
         let content4 = "* Regular item\n> * Blockquote item\n>   * Nested in blockquote\n* Another regular";
-        let ctx = LintContext::new(content4);
+        let ctx = LintContext::new(content4, rumdl_lib::config::MarkdownFlavor::Standard);
         assert!(rule.check(&ctx).unwrap().is_empty());
     }
 
@@ -428,7 +428,7 @@ mod comprehensive_tests {
     fn test_empty_list_items() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1\n* \n  * Item 2";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -445,7 +445,7 @@ mod comprehensive_tests {
   ```
   * Item 2
     * Item 3"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
     }
@@ -460,7 +460,7 @@ tags:
 ---
 * Item 1
   * Item 2"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Lists in YAML front matter should be ignored");
     }
@@ -469,7 +469,7 @@ tags:
     fn test_fix_preserves_content() {
         let rule = MD007ULIndent::default();
         let content = "* Item 1 with **bold** and *italic*\n   * Item 2 with `code`\n     * Item 3 with [link](url)";
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let fixed = rule.fix(&ctx).unwrap();
         // With dynamic alignment: Item 3 aligns with Item 2's text (2 + 2 + 1 = 5 spaces)
         let expected = "* Item 1 with **bold** and *italic*\n  * Item 2 with `code`\n     * Item 3 with [link](url)";
@@ -485,7 +485,7 @@ tags:
       * L4
         * L5
           * L6"#;
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty());
 
@@ -496,7 +496,7 @@ tags:
       * L4
          * L5
             * L6"#;
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Deep nesting errors should be detected");
     }
@@ -513,7 +513,7 @@ tags:
 + Plus
   + Nested plus"#;
 
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -528,22 +528,22 @@ tags:
 + Plus
     + Wrong plus"#;
 
-        let ctx = LintContext::new(wrong_content);
+        let ctx = LintContext::new(wrong_content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 3, "All marker types should be checked for indentation");
     }
 }
 
 mod parity_with_markdownlint {
-    use rumdl::lint_context::LintContext;
-    use rumdl::rule::Rule;
-    use rumdl::rules::MD007ULIndent;
+    use rumdl_lib::lint_context::LintContext;
+    use rumdl_lib::rule::Rule;
+    use rumdl_lib::rules::MD007ULIndent;
 
     #[test]
     fn parity_flat_list_default_indent() {
         let input = "* Item 1\n* Item 2\n* Item 3";
         let expected = "* Item 1\n* Item 2\n* Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -554,7 +554,7 @@ mod parity_with_markdownlint {
     fn parity_nested_list_default_indent() {
         let input = "* Item 1\n  * Nested 1\n    * Nested 2";
         let expected = "* Item 1\n  * Nested 1\n    * Nested 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -565,7 +565,7 @@ mod parity_with_markdownlint {
     fn parity_nested_list_incorrect_indent() {
         let input = "* Item 1\n * Nested 1\n   * Nested 2";
         let expected = "* Item 1\n  * Nested 1\n   * Nested 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -577,7 +577,7 @@ mod parity_with_markdownlint {
     fn parity_mixed_markers() {
         let input = "* Item 1\n  - Nested 1\n    + Nested 2";
         let expected = "* Item 1\n  - Nested 1\n    + Nested 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -588,7 +588,7 @@ mod parity_with_markdownlint {
     fn parity_blockquote_list() {
         let input = "> * Item 1\n>   * Nested";
         let expected = "> * Item 1\n>   * Nested";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -599,7 +599,7 @@ mod parity_with_markdownlint {
     fn parity_tabs_for_indent() {
         let input = "* Item 1\n\t* Nested";
         let expected = "* Item 1\n  * Nested";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -609,7 +609,7 @@ mod parity_with_markdownlint {
     fn parity_code_block_ignored() {
         let input = "```\n* Not a list\n  * Not a nested list\n```\n* Item 1";
         let expected = "```\n* Not a list\n  * Not a nested list\n```\n* Item 1";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -620,7 +620,7 @@ mod parity_with_markdownlint {
     fn parity_custom_indent_4() {
         let input = "* Item 1\n  * Nested 1\n    * Nested 2";
         let expected = "* Item 1\n  * Nested 1\n    * Nested 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::new(4);
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -630,7 +630,7 @@ mod parity_with_markdownlint {
     fn parity_empty_input() {
         let input = "";
         let expected = "";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -641,7 +641,7 @@ mod parity_with_markdownlint {
     fn parity_no_lists() {
         let input = "# Heading\nSome text";
         let expected = "# Heading\nSome text";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -652,7 +652,7 @@ mod parity_with_markdownlint {
     fn parity_list_with_blank_lines_between_items() {
         let input = "* Item 1\n\n* Item 2\n\n  * Nested item 1\n\n  * Nested item 2\n* Item 3";
         let expected = "* Item 1\n\n* Item 2\n\n  * Nested item 1\n\n  * Nested item 2\n* Item 3";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(
@@ -665,7 +665,7 @@ mod parity_with_markdownlint {
     fn parity_list_items_with_trailing_whitespace() {
         let input = "* Item 1   \n  * Nested item 1   \n* Item 2   ";
         let expected = "* Item 1   \n  * Nested item 1   \n* Item 2   ";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -675,7 +675,7 @@ mod parity_with_markdownlint {
     fn parity_deeply_nested_blockquotes_with_lists() {
         let input = "> > * Item 1\n> >   * Nested item 1\n> >     * Nested item 2\n> > * Item 2";
         let expected = "> > * Item 1\n> >   * Nested item 1\n> >     * Nested item 2\n> > * Item 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -685,7 +685,7 @@ mod parity_with_markdownlint {
     fn parity_inconsistent_marker_styles_different_nesting() {
         let input = "* Item 1\n  - Nested item 1\n    + Nested item 2\n* Item 2";
         let expected = "* Item 1\n  - Nested item 1\n    + Nested item 2\n* Item 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
@@ -695,7 +695,7 @@ mod parity_with_markdownlint {
     fn parity_mixed_tabs_and_spaces_in_indentation() {
         let input = "* Item 1\n\t* Nested item 1\n  \t* Nested item 2\n* Item 2";
         let expected = "* Item 1\n  * Nested item 1\n   * Nested item 2\n* Item 2";
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let rule = MD007ULIndent::default();
         let fixed = rule.fix(&ctx).unwrap();
         assert_eq!(fixed, expected);
