@@ -1,12 +1,12 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD034NoBareUrls;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD034NoBareUrls;
 
 #[test]
 fn test_ipv6_url_basic() {
     let rule = MD034NoBareUrls;
     let content = "Visit https://[::1]:8080 for local testing";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "IPv6 URL should be flagged as bare URL");
     assert_eq!(result[0].line, 1);
@@ -19,7 +19,7 @@ fn test_ipv6_url_basic() {
 fn test_ipv6_url_full_address() {
     let rule = MD034NoBareUrls;
     let content = "Server at http://[2001:db8::8a2e:370:7334]/path";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "Full IPv6 URL should be flagged");
 
@@ -39,7 +39,7 @@ fn test_ipv6_localhost_variations() {
     ];
 
     for (input, expected) in test_cases {
-        let ctx = LintContext::new(input);
+        let ctx = LintContext::new(input, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1, "IPv6 URL '{input}' should be flagged");
 
@@ -52,7 +52,7 @@ fn test_ipv6_localhost_variations() {
 fn test_ipv6_with_zone_id() {
     let rule = MD034NoBareUrls;
     let content = "Connect to https://[fe80::1%eth0]:8080";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "IPv6 with zone ID should be flagged");
 
@@ -64,7 +64,7 @@ fn test_ipv6_with_zone_id() {
 fn test_ipv6_mixed_with_ipv4() {
     let rule = MD034NoBareUrls;
     let content = "Try http://127.0.0.1 or https://[::1]:8080 or http://localhost";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3, "All three URLs should be flagged");
 
@@ -79,7 +79,7 @@ fn test_ipv6_mixed_with_ipv4() {
 fn test_ipv6_in_markdown_link() {
     let rule = MD034NoBareUrls;
     let content = "[IPv6 Server](https://[2001:db8::1]:8080) is already linked";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty(), "IPv6 URL in markdown link should not be flagged");
 }
@@ -88,7 +88,7 @@ fn test_ipv6_in_markdown_link() {
 fn test_ipv6_in_angle_brackets() {
     let rule = MD034NoBareUrls;
     let content = "Already wrapped: <https://[::1]:8080>";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -102,7 +102,7 @@ fn test_ipv6_edge_cases() {
 
     // Test compressed zeros
     let content = "Visit http://[2001:db8:0:0:0:0:0:1] or http://[2001:db8::1]";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Both IPv6 formats should be flagged");
 
@@ -114,7 +114,7 @@ fn test_ipv6_edge_cases() {
 fn test_ipv6_with_path_query_fragment() {
     let rule = MD034NoBareUrls;
     let content = "API at https://[2001:db8::1]:8080/api/v1?param=value#section";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "IPv6 URL with full path should be flagged");
 
@@ -126,7 +126,7 @@ fn test_ipv6_with_path_query_fragment() {
 fn test_ipv6_trailing_punctuation() {
     let rule = MD034NoBareUrls;
     let content = "Visit https://[::1]:8080.";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "IPv6 URL with trailing period should be flagged");
 
@@ -138,7 +138,7 @@ fn test_ipv6_trailing_punctuation() {
 fn test_ipv6_ftp_protocol() {
     let rule = MD034NoBareUrls;
     let content = "FTP server at ftp://[2001:db8::ftp]:21";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "FTP IPv6 URL should be flagged");
 
@@ -150,7 +150,7 @@ fn test_ipv6_ftp_protocol() {
 fn test_ipv6_multiple_on_line() {
     let rule = MD034NoBareUrls;
     let content = "Primary: https://[2001:db8::1] Secondary: https://[2001:db8::2]";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Both IPv6 URLs should be flagged");
 
@@ -165,7 +165,7 @@ fn test_ipv6_multiple_on_line() {
 fn test_ipv6_in_reference_definition() {
     let rule = MD034NoBareUrls;
     let content = "[ref]: https://[::1]:8080";
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -185,7 +185,7 @@ fn test_ipv6_invalid_formats_not_flagged() {
     ];
 
     for content in test_cases {
-        let ctx = LintContext::new(content);
+        let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Invalid format '{content}' should not be flagged");
     }
