@@ -1,10 +1,14 @@
-use rumdl::lint_context::LintContext;
-use rumdl::rule::Rule;
-use rumdl::rules::MD051LinkFragments;
+use rumdl_lib::lint_context::LintContext;
+use rumdl_lib::rule::Rule;
+use rumdl_lib::rules::MD051LinkFragments;
+use rumdl_lib::utils::anchor_styles::AnchorStyle;
 
 #[test]
 fn test_valid_link_fragment() {
-    let ctx = LintContext::new("# Test Heading\n\nThis is a [link](somepath#test-heading) to the heading.");
+    let ctx = LintContext::new(
+        "# Test Heading\n\nThis is a [link](somepath#test-heading) to the heading.",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
@@ -12,7 +16,10 @@ fn test_valid_link_fragment() {
 
 #[test]
 fn test_invalid_link_fragment() {
-    let ctx = LintContext::new("# Test Heading\n\nThis is a [link](somepath#wrong-heading) to the heading.");
+    let ctx = LintContext::new(
+        "# Test Heading\n\nThis is a [link](somepath#wrong-heading) to the heading.",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
@@ -22,6 +29,7 @@ fn test_invalid_link_fragment() {
 fn test_multiple_headings() {
     let ctx = LintContext::new(
         "# First Heading\n\n## Second Heading\n\n[Link 1](somepath#first-heading)\n[Link 2](somepath#second-heading)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
@@ -30,15 +38,23 @@ fn test_multiple_headings() {
 
 #[test]
 fn test_special_characters() {
-    let ctx = LintContext::new("# Test & Heading!\n\nThis is a [link](somepath#test-heading) to the heading.");
+    let ctx = LintContext::new(
+        "# Test & Heading!\n\nThis is a [link](somepath#test--heading) to the heading.",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
+    // "Test & Heading!" should become "test--heading" (& becomes -- per GitHub spec, ! removed)
+    // So the link to #test--heading should be VALID and no warnings should be generated
+    assert_eq!(result.len(), 0);
 }
 
 #[test]
 fn test_no_fragments() {
-    let ctx = LintContext::new("# Test Heading\n\nThis is a [link](https://example.com) without fragment.");
+    let ctx = LintContext::new(
+        "# Test Heading\n\nThis is a [link](https://example.com) without fragment.",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
@@ -46,7 +62,7 @@ fn test_no_fragments() {
 
 #[test]
 fn test_empty_content() {
-    let ctx = LintContext::new("");
+    let ctx = LintContext::new("", rumdl_lib::config::MarkdownFlavor::Standard);
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
@@ -54,7 +70,10 @@ fn test_empty_content() {
 
 #[test]
 fn test_multiple_invalid_fragments() {
-    let ctx = LintContext::new("# Test Heading\n\n[Link 1](somepath#wrong1)\n[Link 2](somepath#wrong2)");
+    let ctx = LintContext::new(
+        "# Test Heading\n\n[Link 1](somepath#wrong1)\n[Link 2](somepath#wrong2)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
@@ -69,6 +88,7 @@ fn test_case_sensitivity() {
 [Valid Link](#my-heading)
 [Valid Link Different Case](#MY-HEADING)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -87,6 +107,7 @@ fn test_case_sensitivity() {
 fn test_complex_heading_structures() {
     let ctx = LintContext::new(
         "# Heading 1\n\nSome text\n\nHeading 2\n-------\n\n### Heading 3\n\n[Link to 1](somepath#heading-1)\n[Link to 2](somepath#heading-2)\n[Link to 3](somepath#heading-3)\n[Link to missing](somepath#heading-4)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let rule = MD051LinkFragments::new();
 
@@ -97,7 +118,8 @@ fn test_complex_heading_structures() {
 
     // Test with special characters in headings/links
     let ctx = LintContext::new(
-        "# Heading & Special! Characters\n\n[Link](somepath#heading-special-characters)\n[Bad Link](somepath#heading--special-characters)",
+        "# Heading & Special! Characters\n\n[Link](somepath#heading--special-characters)\n[Bad Link](somepath#heading-special-characters-bad)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let result = rule.check(&ctx).unwrap();
 
@@ -115,6 +137,7 @@ fn test_heading_id_generation() {
 [Link with underscore](#heading-1)
 [Link with multiple hyphens](#heading-1)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -129,19 +152,29 @@ fn test_heading_id_generation() {
 
 #[test]
 fn test_heading_to_fragment_edge_cases() {
-    let ctx = LintContext::new("# Heading\n\n# Heading\n\n[Link 1](somepath#heading)\n[Link 2](somepath#heading-1)");
+    let ctx = LintContext::new(
+        "# Heading\n\n# Heading\n\n[Link 1](somepath#heading)\n[Link 2](somepath#heading-1)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let rule = MD051LinkFragments::new();
 
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
+    // Cross-file links should be ignored, so no warnings expected
+    assert_eq!(result.len(), 0);
 
     // Test headings with only special characters
-    let ctx = LintContext::new("# @#$%^\n\n[Link](somepath#)");
+    let ctx = LintContext::new(
+        "# @#$%^\n\n[Link](somepath#)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 
     // Test mixed internal/external links
-    let ctx = LintContext::new("# Heading\n\n[Internal](somepath#heading)\n[External](https://example.com#heading)");
+    let ctx = LintContext::new(
+        "# Heading\n\n[Internal](somepath#heading)\n[External](https://example.com#heading)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 }
@@ -150,6 +183,7 @@ fn test_heading_to_fragment_edge_cases() {
 fn test_fragment_in_code_blocks() {
     let ctx = LintContext::new(
         "# Real Heading\n\n```markdown\n# Fake Heading\n[Link](somepath#fake-heading)\n```\n\n[Link](somepath#real-heading)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let rule = MD051LinkFragments::new();
 
@@ -163,7 +197,10 @@ fn test_fragment_in_code_blocks() {
     assert_eq!(result.len(), 0);
 
     // Test headings in code blocks (should be ignored)
-    let ctx = LintContext::new("```markdown\n# Code Heading\n```\n\n[Link](somepath#code-heading)");
+    let ctx = LintContext::new(
+        "```markdown\n# Code Heading\n```\n\n[Link](#code-heading)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
     let result = rule.check(&ctx).unwrap();
     println!("Second test has {} warnings", result.len());
     for (i, warning) in result.iter().enumerate() {
@@ -182,6 +219,7 @@ fn test_fragment_with_complex_content() {
 
 [Link to heading](#heading-with-bold-and-italic)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -206,6 +244,7 @@ fn test_nested_formatting_in_fragments() {
 
 [Link to heading](#heading-with-bold-italic-text)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -229,6 +268,7 @@ fn test_multiple_formatting_styles() {
 
 [Link to heading](#heading-with-underscores-and-asterisks-mixed)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -252,9 +292,10 @@ fn test_complex_nested_formatting() {
 
 [Link to heading](#bold-with-italic-and-code-and-link)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
-    let rule = MD051LinkFragments::new();
+    let rule = MD051LinkFragments::with_anchor_style(AnchorStyle::KramdownGfm);
     let result = rule.check(&ctx);
     assert!(result.is_ok());
     let warnings = result.unwrap();
@@ -269,9 +310,10 @@ fn test_formatting_edge_cases() {
         r#"
 # Heading with a**partial**bold and *italic with **nested** formatting*
 
-[Link to partial bold](#heading-with-apartialbolda-and-italic-with-nested-formatting)
+[Link to partial bold](#heading-with-apartialbold-and-italic-with-nested-formatting)
 [Link to nested formatting](#heading-with-apartialbold-and-italic-with-nested-formatting)
 "#,
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
 
     let rule = MD051LinkFragments::new();
@@ -321,7 +363,7 @@ fn test_performance_md051() {
     // Measure performance
     let start = std::time::Instant::now();
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
     let duration = start.elapsed();
 
@@ -341,6 +383,7 @@ fn test_performance_md051() {
 fn test_inline_code_spans() {
     let ctx = LintContext::new(
         "# Real Heading\n\nThis is a real link: [Link](somepath#real-heading)\n\nThis is a code example: `[Example](#missing-section)`",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let rule = MD051LinkFragments::new();
 
@@ -352,6 +395,7 @@ fn test_inline_code_spans() {
     // Test with multiple code spans and mix of valid and invalid links
     let ctx = LintContext::new(
         "# Heading One\n\n`[Invalid](#missing)` and [Valid](#heading-one) and `[Another Invalid](#nowhere)`",
+        rumdl_lib::config::MarkdownFlavor::Standard,
     );
     let result = rule.check(&ctx).unwrap();
 
@@ -359,7 +403,10 @@ fn test_inline_code_spans() {
     assert_eq!(result.len(), 0, "Only links outside code spans should be checked");
 
     // Test with a fragment link in inline code followed by a real invalid link
-    let ctx = LintContext::new("# Heading One\n\n`[Example](#missing-section)` and [Invalid Link](#section-two)");
+    let ctx = LintContext::new(
+        "# Heading One\n\n`[Example](#missing-section)` and [Invalid Link](#section-two)",
+        rumdl_lib::config::MarkdownFlavor::Standard,
+    );
 
     // Debug: Let's check what the LintContext contains
     println!("=== Test 3 Debug ===");
@@ -406,7 +453,7 @@ fn test_readme_fragments_debug() {
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     // Test the actual rule
     println!("\nRunning MD051 check on README-like content:");
@@ -439,9 +486,9 @@ fn test_md051_fragment_generation_regression() {
         ("Simple Heading", "simple-heading"),
         ("1. Numbered Heading", "1-numbered-heading"),
         ("Heading with Spaces", "heading-with-spaces"),
-        // Ampersand cases (the main bug)
+        // Ampersand cases (& becomes -- per GitHub spec)
         ("Test & Example", "test--example"),
-        ("A&B", "a--b"),
+        ("A&B", "ab"), // Fixed: & without spaces is removed
         ("A & B", "a--b"),
         ("Multiple & Ampersands & Here", "multiple--ampersands--here"),
         // Special characters
@@ -461,18 +508,18 @@ fn test_md051_fragment_generation_regression() {
             "Heading with (Parentheses) & [Brackets]",
             "heading-with-parentheses--brackets",
         ),
-        ("Special Characters: @#$%^&*()", "special-characters"),
+        ("Special Characters: @#$%^&*()", "special-characters-"),
         // Edge cases
         ("Only!!! Symbols!!!", "only-symbols"),
         ("   Spaces   ", "spaces"), // Leading/trailing spaces
         ("Already-hyphenated", "already-hyphenated"),
-        ("Multiple---hyphens", "multiple-hyphens"),
+        ("Multiple---hyphens", "multiple---hyphens"), // GitHub preserves consecutive hyphens
     ];
 
     for (heading, expected_fragment) in test_cases {
         // Create a test document with the heading and a link to it
-        let content = format!("# {heading}\n\n[Link](#{expected_fragment}))");
-        let ctx = LintContext::new(&content);
+        let content = format!("# {heading}\n\n[Link](#{expected_fragment})");
+        let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
         let result = rule.check(&ctx).unwrap();
 
         // If the fragment generation is correct, there should be no warnings
@@ -512,7 +559,7 @@ fn test_md051_real_world_scenarios() {
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // All links should be valid with the fixed algorithm
@@ -533,20 +580,20 @@ fn test_md051_ampersand_variations() {
 [Link 1](#test--example)
 
 # A&B
-[Link 2](#a--b)
+[Link 2](#ab)
 
 # Multiple & Symbols & Here
 [Link 3](#multiple--symbols--here)
 
 # Test&End
-[Link 4](#test--end)
+[Link 4](#testend)
 
 # &Start
 [Link 5](#start)
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // All ampersand cases should be handled correctly
@@ -586,7 +633,7 @@ And some cross-file links that should be ignored by MD051:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only have one warning for the missing internal fragment
@@ -634,7 +681,7 @@ Test various link types:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the invalid fragment-only link
@@ -685,7 +732,7 @@ Fragment-only links (should be validated):
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the invalid fragment-only link
@@ -733,7 +780,7 @@ Fragment-only tests:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag the invalid fragment-only link plus the ambiguous paths without extensions
@@ -779,7 +826,7 @@ Fragment-only (should be validated):
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag ambiguous paths without extensions plus the invalid fragment
@@ -827,7 +874,7 @@ Fragment validation:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the invalid fragment-only link
@@ -855,7 +902,7 @@ fn test_performance_stress_case() {
     content.push_str("- [Invalid](#missing)\n");
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the one invalid fragment
@@ -887,21 +934,23 @@ Ambiguous paths (treated as fragment-only):
 - [Spaces no extension](my file#section)
 
 Fragment tests:
-- [Valid unicode](#café-restaurant)
+- [Valid unicode](#café--restaurant)
 - [Valid heading](#test-heading)
 - [Invalid](#missing-heading)
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
-    // Should flag ambiguous paths + invalid fragments = 5 warnings
-    // 3 ambiguous paths (#section) + 1 invalid unicode fragment + 1 missing fragment
+    // Should flag ambiguous paths + invalid fragment = 4 warnings
+    // 3 ambiguous paths (#section) + 1 missing fragment
+    // Note: #café--restaurant should NOT be flagged as it matches "Café & Restaurant" heading
+    // (& becomes -- per GitHub spec)
     assert_eq!(
         result.len(),
-        5,
-        "Expected 5 warnings: 3 ambiguous paths + 2 invalid fragments"
+        4,
+        "Expected 4 warnings: 3 ambiguous paths + 1 invalid fragment"
     );
 
     let warning_messages: Vec<&str> = result.iter().map(|w| w.message.as_str()).collect();
@@ -912,8 +961,8 @@ Fragment tests:
     assert_eq!(contains_section, 3, "Should have 3 warnings about #section fragment");
     assert!(contains_missing, "Should warn about #missing-heading fragment");
     assert!(
-        contains_cafe,
-        "Should warn about #café-restaurant fragment (doesn't match heading)"
+        !contains_cafe,
+        "Should NOT warn about #café-restaurant fragment (matches heading per GitHub spec)"
     );
 }
 
@@ -951,7 +1000,7 @@ Fragment-only validation tests:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag only 1 invalid fragment - ambiguous paths are now treated as cross-file links
@@ -985,7 +1034,7 @@ Fragment-only tests:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the invalid fragment
@@ -1013,14 +1062,14 @@ Fragment tests with normalization:
 - [Valid basic](#test-heading)
 - [Valid special](#special-characters--symbols)
 - [Valid code](#code-inline-example)
-- [Valid spaces](#multiple-spaces)
+- [Valid spaces](#multiple---spaces)
 - [Valid case insensitive](#Test-Heading)
 - [Invalid symbols](#special-characters-&-symbols)
 - [Invalid spacing](#multiple   spaces)
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag the invalid fragment variations (case-insensitive matching is correct)
@@ -1057,7 +1106,7 @@ Fragment-only (should be validated):
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the invalid fragment
@@ -1089,7 +1138,7 @@ Malformed and edge case links:
 "#;
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(content);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
     let result = rule.check(&ctx).unwrap();
 
     // Should flag the invalid fragment and potentially malformed links
@@ -1118,7 +1167,7 @@ fn test_performance_with_many_links() {
     content.push_str("- [Invalid](#nonexistent)\n");
 
     let rule = MD051LinkFragments::new();
-    let ctx = LintContext::new(&content);
+    let ctx = LintContext::new(&content, rumdl_lib::config::MarkdownFlavor::Standard);
 
     let start = std::time::Instant::now();
     let result = rule.check(&ctx).unwrap();
@@ -1144,3 +1193,605 @@ fn test_performance_with_many_links() {
         ctx.links.len()
     );
 }
+
+#[test]
+fn test_custom_header_id_formats() {
+    // Test all supported custom header ID formats
+    let content = r#"# Kramdown Style {#kramdown-id}
+
+Some content here.
+
+## Python-markdown with spaces { #spaced-id }
+
+More content.
+
+### Python-markdown with colon {:#colon-id}
+
+Even more content.
+
+#### Python-markdown full format {: #full-format }
+
+Final content.
+
+Links to test all formats:
+- [Link to kramdown](#kramdown-id)
+- [Link to spaced](#spaced-id)
+- [Link to colon](#colon-id)
+- [Link to full format](#full-format)
+
+Links that should fail:
+- [Link to nonexistent](#nonexistent-id)
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let rule = MD051LinkFragments::new();
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only flag the nonexistent fragment
+    assert_eq!(result.len(), 1, "Expected 1 warning for nonexistent fragment");
+    assert!(
+        result[0].message.contains("nonexistent-id"),
+        "Warning should be about nonexistent fragment, got: {}",
+        result[0].message
+    );
+
+    // All valid custom ID formats should be recognized
+    for warning in &result {
+        assert!(
+            !warning.message.contains("kramdown-id")
+                && !warning.message.contains("spaced-id")
+                && !warning.message.contains("colon-id")
+                && !warning.message.contains("full-format"),
+            "Valid custom ID format should not be flagged as missing: {}",
+            warning.message
+        );
+    }
+}
+
+#[test]
+fn test_extended_attr_list_support() {
+    // Test attr-list with classes and other attributes alongside IDs
+    let content = r#"# Simple ID { #simple-id }
+
+## ID with single class {: #with-class .highlight }
+
+### ID with multiple classes {: #multi-class .class1 .class2 }
+
+#### ID with key-value attributes {: #with-attrs data-test="value" style="color: red" }
+
+##### Complex combination {: #complex .highlight .important data-role="button" title="Test" }
+
+###### Edge case with quotes {: #quotes title="Has \"nested\" quotes" }
+
+Links to test extended attr-list support:
+- [Simple ID](#simple-id)
+- [With class](#with-class)
+- [Multiple classes](#multi-class)
+- [With attributes](#with-attrs)
+- [Complex](#complex)
+- [Quotes](#quotes)
+
+Links that should fail:
+- [Nonexistent](#nonexistent)
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let rule = MD051LinkFragments::new();
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only flag the nonexistent fragment
+    assert_eq!(result.len(), 1, "Expected 1 warning for nonexistent fragment");
+    assert!(
+        result[0].message.contains("nonexistent"),
+        "Warning should be about nonexistent fragment, got: {}",
+        result[0].message
+    );
+
+    // All valid attr-list IDs should be recognized
+    for warning in &result {
+        assert!(
+            !warning.message.contains("simple-id")
+                && !warning.message.contains("with-class")
+                && !warning.message.contains("multi-class")
+                && !warning.message.contains("with-attrs")
+                && !warning.message.contains("complex")
+                && !warning.message.contains("quotes"),
+            "Valid attr-list ID should not be flagged as missing: {}",
+            warning.message
+        );
+    }
+}
+
+#[test]
+fn test_jekyll_kramdown_next_line_attr_list() {
+    // Test Jekyll/kramdown style attr-list on the line following the header
+    let content = r#"# Main Title
+
+## ATX Header
+{#atx-next-line}
+
+### Another ATX
+{ #atx-spaced }
+
+#### ATX with Class
+{: #atx-with-class .highlight}
+
+##### ATX Complex
+{: #atx-complex .class1 .class2 data-test="value"}
+
+Links to test next-line attr-list:
+- [ATX Next Line](#atx-next-line)
+- [ATX Spaced](#atx-spaced)
+- [ATX with Class](#atx-with-class)
+- [ATX Complex](#atx-complex)
+
+Links that should fail:
+- [Nonexistent](#nonexistent-next-line)
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let rule = MD051LinkFragments::new();
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only flag the nonexistent fragment
+    assert_eq!(result.len(), 1, "Expected 1 warning for nonexistent fragment");
+    assert!(
+        result[0].message.contains("nonexistent-next-line"),
+        "Warning should be about nonexistent fragment, got: {}",
+        result[0].message
+    );
+
+    // All valid next-line attr-list IDs should be recognized
+    for warning in &result {
+        assert!(
+            !warning.message.contains("atx-next-line")
+                && !warning.message.contains("atx-spaced")
+                && !warning.message.contains("atx-with-class")
+                && !warning.message.contains("atx-complex"),
+            "Valid next-line attr-list ID should not be flagged as missing: {}",
+            warning.message
+        );
+    }
+}
+
+#[test]
+fn test_mixed_inline_and_next_line_attr_list() {
+    // Test mixing inline and next-line attr-list in the same document
+    let content = r#"# Mixed Styles
+
+## Inline Style {#inline-id}
+
+### Next Line Style
+{#next-line-id}
+
+#### Inline with Class {: #inline-class .highlight }
+
+##### Next Line with Class
+{: #next-line-class .important }
+
+Links:
+- [Inline](#inline-id)
+- [Next Line](#next-line-id)
+- [Inline Class](#inline-class)
+- [Next Line Class](#next-line-class)
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let rule = MD051LinkFragments::new();
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no warnings - all IDs should be found
+    assert_eq!(result.len(), 0, "Expected no warnings, got: {result:?}");
+}
+
+#[test]
+fn debug_issue_39_fragment_generation() {
+    // Debug test to see what fragments are actually generated
+    let content = r#"
+# Testing & Coverage
+
+## cbrown --> sbrown: --unsafe-paths
+
+## cbrown -> sbrown
+
+## The End - yay
+
+## API Reference: Methods & Properties
+
+Links for testing:
+- [Testing coverage](#testing--coverage)
+- [Complex path](#cbrown----sbrown---unsafe-paths)
+- [Simple arrow](#cbrown---sbrown)
+- [API ref](#api-reference-methods--properties)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    println!("Number of errors: {}", result.len());
+    for warning in &result {
+        println!("Warning: {}", warning.message);
+    }
+
+    // If we fixed it correctly, we should have 0 errors
+    if result.is_empty() {
+        println!("SUCCESS: All fragments now match!");
+    } else {
+        println!("STILL BROKEN: Fragment generation needs more work");
+    }
+}
+
+/// Regression tests for Issue #39: Two bugs in Links [MD051]
+/// These tests ensure that the complex punctuation handling bugs are fixed and won't regress
+
+#[test]
+fn test_issue_39_duplicate_headings() {
+    // Test case from issue 39: links to the second of repeated headers
+    let content = r#"
+# Title
+
+## Section
+
+This is a [reference](#section-1) to the second section.
+
+## Section
+
+There will be another section.
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - link to second section should work
+    assert_eq!(result.len(), 0, "Link to duplicate heading should work");
+}
+
+#[test]
+fn test_issue_39_complex_punctuation_arrows() {
+    // Test case from issue 39: complex arrow punctuation patterns
+    let content = r#"
+## cbrown --> sbrown: --unsafe-paths
+
+## cbrown -> sbrown
+
+## Arrow Test <-> bidirectional
+
+## Double Arrow ==> Test
+
+Links to test:
+- [Complex unsafe](#cbrown----sbrown---unsafe-paths)
+- [Simple arrow](#cbrown---sbrown)
+- [Bidirectional](#arrow-test---bidirectional)
+- [Double arrow](#double-arrow--test)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - all complex punctuation should be handled correctly
+    assert_eq!(
+        result.len(),
+        0,
+        "Complex arrow patterns should work: {:?}",
+        result.iter().map(|r| &r.message).collect::<Vec<_>>()
+    );
+}
+
+#[test]
+fn test_issue_39_ampersand_and_colons() {
+    // Test case from issue 39: headers with ampersands and colons
+    let content = r#"
+# Testing & Coverage
+
+## API Reference: Methods & Properties
+
+## Config: Database & Cache Settings
+
+Links to test:
+- [Testing coverage](#testing--coverage)
+- [API reference](#api-reference-methods--properties)
+- [Config settings](#config-database--cache-settings)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - ampersands and colons should be handled correctly
+    assert_eq!(
+        result.len(),
+        0,
+        "Ampersand and colon patterns should work: {:?}",
+        result.iter().map(|r| &r.message).collect::<Vec<_>>()
+    );
+}
+
+#[test]
+fn test_issue_39_mixed_punctuation_clusters() {
+    // Test edge cases with multiple types of punctuation in clusters
+    let content = r#"
+## Step 1: Setup (Prerequisites)
+
+## Error #404 - Not Found!
+
+## FAQ: What's Next?
+
+## Version 2.0.1 - Release Notes
+
+Links to test:
+- [Setup guide](#step-1-setup-prerequisites)
+- [Error page](#error-404---not-found)
+- [FAQ section](#faq-whats-next)
+- [Release notes](#version-201---release-notes)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - mixed punctuation should be handled correctly
+    assert_eq!(
+        result.len(),
+        0,
+        "Mixed punctuation clusters should work: {:?}",
+        result.iter().map(|r| &r.message).collect::<Vec<_>>()
+    );
+}
+
+#[test]
+fn test_issue_39_consecutive_hyphens_and_spaces() {
+    // Test that consecutive hyphens are collapsed properly
+    let content = r#"
+## Test --- Multiple Hyphens
+
+## Test  --  Spaced Hyphens
+
+## Test - Single - Hyphen
+
+Links to test:
+- [Multiple](#test-----multiple-hyphens)
+- [Spaced](#test------spaced-hyphens)
+- [Single](#test---single---hyphen)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - consecutive hyphens should be collapsed
+    assert_eq!(
+        result.len(),
+        0,
+        "Consecutive hyphens should be collapsed: {:?}",
+        result.iter().map(|r| &r.message).collect::<Vec<_>>()
+    );
+}
+
+#[test]
+fn test_issue_39_edge_cases_from_comments() {
+    // Test specific patterns mentioned in issue 39 comments
+    let content = r#"
+### PHP $_REQUEST
+
+### sched_debug
+
+#### Add ldap_monitor to delegator$
+
+### cbrown --> sbrown: --unsafe-paths
+
+Links to test:
+- [PHP request](#php-_request)
+- [Sched debug](#sched_debug)
+- [LDAP monitor](#add-ldap_monitor-to-delegator)
+- [Complex path](#cbrown----sbrown---unsafe-paths)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have no errors - all edge cases should work
+    assert_eq!(
+        result.len(),
+        0,
+        "Edge cases from issue comments should work: {:?}",
+        result.iter().map(|r| &r.message).collect::<Vec<_>>()
+    );
+}
+
+#[test]
+fn test_html_anchor_tags() {
+    // Test HTML anchor tags with id attribute
+    let content = r#"# Regular Heading
+
+## Heading with anchor<a id="custom-id"></a>
+
+## Another heading<a name="old-style"></a>
+
+Links to test:
+- [Regular heading](#regular-heading) - should work
+- [Custom ID](#custom-id) - should work
+- [Old style name](#old-style) - should work
+- [Missing anchor](#missing) - should fail
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only have 1 error for #missing
+    assert_eq!(result.len(), 1, "Should only flag missing anchor");
+    assert!(result[0].message.contains("#missing"));
+}
+
+#[test]
+fn test_html_span_div_anchors() {
+    // Test various HTML elements with id attributes
+    let content = r#"# Document Title
+
+## Section with span <span id="span-anchor">text</span>
+
+<div id="div-anchor">
+Some content in a div
+</div>
+
+<section id="section-anchor">
+A section element
+</section>
+
+<h3 id="h3-anchor">HTML heading</h3>
+
+Links to test:
+- [Span anchor](#span-anchor) - should work
+- [Div anchor](#div-anchor) - should work
+- [Section anchor](#section-anchor) - should work
+- [H3 anchor](#h3-anchor) - should work
+- [Non-existent](#does-not-exist) - should fail
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only have 1 error for #does-not-exist
+    assert_eq!(result.len(), 1, "Should only flag non-existent anchor");
+    assert!(result[0].message.contains("#does-not-exist"));
+}
+
+#[test]
+fn test_html_anchors_in_code_blocks() {
+    // HTML anchors in code blocks should be ignored
+    let content = r#"# Test Document
+
+```html
+<a id="code-anchor">This is in a code block</a>
+```
+
+Links to test:
+- [Code anchor](#code-anchor) - should fail (anchor is in code block)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have 1 error - anchors in code blocks don't count
+    assert_eq!(result.len(), 1, "Anchors in code blocks should be ignored");
+}
+
+#[test]
+fn test_multiple_ids_on_same_element() {
+    // Test edge case: multiple id attributes (only first should be used per HTML spec)
+    let content = r#"# Test Document
+
+<div id="first-id" id="second-id">Content</div>
+
+Links to test:
+- [First ID](#first-id) - should work
+- [Second ID](#second-id) - should fail (HTML only uses first id)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have 1 error for second-id
+    assert_eq!(result.len(), 1, "Only first id attribute should be recognized");
+    assert!(result[0].message.contains("#second-id"));
+}
+
+#[test]
+fn test_mixed_markdown_and_html_anchors() {
+    // Test document with both Markdown headings and HTML anchors
+    let content = r#"# Main Title
+
+## Regular Markdown Heading
+
+## Heading with custom ID {#custom-markdown-id}
+
+## Heading with HTML anchor<a id="html-anchor"></a>
+
+<div id="standalone-div">Content</div>
+
+Links to test:
+- [Main title](#main-title) - Markdown auto-generated
+- [Regular heading](#regular-markdown-heading) - Markdown auto-generated
+- [Custom Markdown ID](#custom-markdown-id) - Markdown custom ID
+- [HTML anchor](#html-anchor) - HTML anchor on heading
+- [Div anchor](#standalone-div) - Standalone HTML element
+- [Wrong link](#wrong) - Should fail
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should only have 1 error for #wrong
+    assert_eq!(result.len(), 1, "Should support both Markdown and HTML anchors");
+    assert!(result[0].message.contains("#wrong"));
+}
+
+#[test]
+fn test_case_sensitivity_html_anchors() {
+    // HTML id attributes are case-sensitive, links should match exactly
+    let content = r#"# Test Document
+
+<div id="CamelCase">Content</div>
+<span id="lowercase">Content</span>
+
+Links to test:
+- [Exact match CamelCase](#CamelCase) - should work
+- [Wrong case camelcase](#camelcase) - should fail
+- [Exact match lowercase](#lowercase) - should work
+- [Wrong case LOWERCASE](#LOWERCASE) - should fail
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should have 2 errors for wrong case
+    assert_eq!(result.len(), 2, "HTML anchors should be case-sensitive");
+}
+
+#[test]
+fn test_html_anchors_parity_with_markdownlint() {
+    // This test ensures parity with markdownlint-cli behavior
+    // Based on actual test case from ruff repository
+    let content = r#"# Getting Started<a id="getting-started"></a>
+
+## Configuration<a id="configuration"></a>
+
+## Rules<a id="rules"></a>
+
+## Contributing<a id="contributing"></a>
+
+## Support<a id="support"></a>
+
+## Acknowledgements<a id="acknowledgements"></a>
+
+## Who's Using Ruff?<a id="whos-using-ruff"></a>
+
+## License<a id="license"></a>
+
+Table of contents:
+1. [Getting Started](#getting-started)
+1. [Configuration](#configuration)
+1. [Rules](#rules)
+1. [Contributing](#contributing)
+1. [Support](#support)
+1. [Acknowledgements](#acknowledgements)
+1. [Who's Using Ruff?](#whos-using-ruff)
+1. [License](#license)
+"#;
+
+    let rule = MD051LinkFragments::new();
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let result = rule.check(&ctx).unwrap();
+
+    // All links should be valid - no errors
+    assert_eq!(result.len(), 0, "All HTML anchor links should be valid");
+}
